@@ -17,16 +17,15 @@
 #include "coordit.h"
 #include "env.h"
 #include "fprop.h"
+#include "godconduct.h"
 #include "libutil.h"
 #include "losglobal.h"
 #include "mon-behv.h"
-#include "mon-stuff.h"
 #include "mon-util.h"
 #include "monster.h"
 #include "player.h"
 #include "religion.h"
-#include "godconduct.h"
-#include "stuff.h"
+#include "stepdown.h"
 #include "terrain.h"
 #include "traps.h"
 #include "travel.h"
@@ -44,7 +43,10 @@ enum areaprop_flag
     APROP_QUAD          = (1 << 8),
     APROP_DISJUNCTION   = (1 << 9),
     APROP_SOUL_AURA     = (1 << 10),
+#if TAG_MAJOR_VERSION == 34
     APROP_HOT           = (1 << 11),
+#endif
+    APROP_GOLD          = (1 << 12),
 };
 
 struct area_centre
@@ -87,7 +89,10 @@ void areas_actor_moved(const actor* act, const coord_def& oldpos)
         (you.entering_level
          || act->halo_radius2() > -1 || act->silence_radius2() > -1
          || act->liquefying_radius2() > -1 || act->umbra_radius2() > -1
-         || act->heat_radius2() > -1))
+#if TAG_MAJOR_VERSION == 34
+         || act->heat_radius2() > -1
+#endif
+         ))
     {
         // Not necessarily new, but certainly potentially interesting.
         invalidate_agrid(true);
@@ -141,6 +146,7 @@ static void _actor_areas(actor *a)
         no_areas = false;
     }
 
+#if TAG_MAJOR_VERSION == 34
     if ((r = a->heat_radius2()) >= 0)
     {
         _agrid_centres.push_back(area_centre(AREA_HOT, a->pos(), r));
@@ -149,6 +155,7 @@ static void _actor_areas(actor *a)
             _set_agrid_flag(*ri, APROP_HOT);
         no_areas = false;
     }
+#endif
 }
 
 /**
@@ -174,6 +181,26 @@ static void _update_agrid()
     for (monster_iterator mi; mi; ++mi)
         _actor_areas(*mi);
 
+    if (you_worship(GOD_GOZAG))
+    {
+        const int r = 2;
+        for (rectangle_iterator ri(0); ri; ++ri)
+        {
+            // ASSUMPTION: gold will always be on the top of the pile.
+            if (igrd(*ri) != NON_ITEM && mitm[igrd(*ri)].base_type == OBJ_GOLD
+                && mitm[igrd(*ri)].special > 0)
+            {
+                no_areas = false;
+                _agrid_centres.push_back(area_centre(AREA_GOLD, *ri, r));
+                for (radius_iterator rdi(*ri, r, C_CIRCLE, LOS_NO_TRANS);
+                     rdi; ++rdi)
+                {
+                    _set_agrid_flag(*rdi, APROP_GOLD);
+                }
+            }
+        }
+    }
+
     if (player_has_orb() && !you.pos().origin())
     {
         const int r = 5;
@@ -230,8 +257,10 @@ static area_centre_type _get_first_area(const coord_def& f)
         return AREA_SANCTUARY;
     if (a & APROP_SILENCE)
         return AREA_SILENCE;
+#if TAG_MAJOR_VERSION == 34
     if (a & APROP_HOT)
         return AREA_HOT;
+#endif
     if (a & APROP_HALO)
         return AREA_HALO;
     if (a & APROP_UMBRA)
@@ -598,10 +627,6 @@ int monster::halo_radius2() const
         return 50;
     case MONS_OPHAN:
         return 65; // highest rank among sentient ones
-    case MONS_SHEDU:
-        return 10;
-    case MONS_SILVER_STAR:
-        return 40; // dumb but with an immense power
     case MONS_HOLY_SWINE:
         return 2;  // only notionally holy
     case MONS_MENNAS:
@@ -747,6 +772,7 @@ int monster::umbra_radius2() const
     }
 }
 
+#if TAG_MAJOR_VERSION == 34
 /////////////
 // Heat aura (lava orcs).
 
@@ -783,3 +809,18 @@ bool actor::heated() const
 {
     return ::heated(pos());
 }
+#endif
+
+/////////////
+// Gold aura (Gozag).
+
+bool golden(const coord_def& p)
+{
+    if (!map_bounds(p))
+        return false;
+
+    if (!_agrid_valid)
+        _update_agrid();
+
+    return _check_agrid_flag(p, APROP_GOLD);
+}
