@@ -1,3 +1,6 @@
+static spell_type spellbook_template_array[][SPELLBOOK_SIZE] =
+{
+
 {   // Book of Minor Magic
     SPELL_MAGIC_DART,
     SPELL_BLINK,
@@ -45,16 +48,15 @@
 {   // Book of Summonings
     SPELL_ABJURATION,
     SPELL_RECALL,
-    SPELL_SUMMON_ELEMENTAL,
     SPELL_SHADOW_CREATURES,
     SPELL_SUMMON_DEMON,
+    SPELL_SUMMON_FOREST,
     SPELL_MONSTROUS_MENAGERIE,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
 },
 
 {   // Book of Fire
-    SPELL_FIRE_BRAND,
     SPELL_IGNITE_POISON,
     SPELL_FIREBALL,
     SPELL_BOLT_OF_FIRE,
@@ -62,10 +64,10 @@
     SPELL_RING_OF_FLAMES,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
 },
 
 {   // Book of Ice
-    SPELL_FREEZING_AURA,
     SPELL_ENGLACIATION,
     SPELL_OZOCUBUS_REFRIGERATION,
     SPELL_BOLT_OF_COLD,
@@ -73,6 +75,7 @@
     SPELL_SIMULACRUM,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
 },
 
 {   // Book of Spatial Translocations
@@ -87,9 +90,9 @@
 },
 
 {   // Book of Enchantments
+    SPELL_TUKIMAS_DANCE,
     SPELL_CAUSE_FEAR,
     SPELL_SILENCE,
-    SPELL_TUKIMAS_DANCE,
     SPELL_DEFLECT_MISSILES,
     SPELL_HASTE,
     SPELL_DISCORD,
@@ -162,17 +165,19 @@
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
 },
-
+#if TAG_MAJOR_VERSION == 34
 {   // Book of War Chants
-    SPELL_FIRE_BRAND,
-    SPELL_FREEZING_AURA,
-    SPELL_SHROUD_OF_GOLUBRIA,
-    SPELL_REPEL_MISSILES,
-    SPELL_POISON_WEAPON,
-    SPELL_REGENERATION,
+    SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
 },
+#endif
+
 #if TAG_MAJOR_VERSION > 34
 {   // Book of Battle
     SPELL_INFUSION,
@@ -199,12 +204,12 @@
 {   // Book of Necromancy
     SPELL_PAIN,
     SPELL_ANIMATE_SKELETON,
-    SPELL_LETHAL_INFUSION,
     SPELL_VAMPIRIC_DRAINING,
     SPELL_REGENERATION,
     SPELL_ANIMATE_DEAD,
     SPELL_CONTROL_UNDEAD,
     SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
 },
 
 {   // Book of Callings
@@ -223,8 +228,8 @@
     SPELL_SURE_BLADE,
     SPELL_HIBERNATION,
     SPELL_CONFUSE,
+    SPELL_DAZZLING_SPRAY,
     SPELL_ENSLAVEMENT,
-    SPELL_INVISIBILITY,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
 },
@@ -255,22 +260,22 @@
     SPELL_CONTROL_TELEPORT,
     SPELL_PHASE_SHIFT,
     SPELL_WARP_BRAND,
-    SPELL_SUMMON_FOREST,
     SPELL_DISPERSAL,
     SPELL_CONTROLLED_BLINK,
     SPELL_DISJUNCTION,
     SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
 },
 
 {   // Book of Envenomations
     SPELL_SPIDER_FORM,
-    SPELL_POISON_WEAPON,
     SPELL_INTOXICATE,
     SPELL_OLGREBS_TOXIC_RADIANCE,
     SPELL_POISONOUS_CLOUD,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
 },
 
 {   // Book of Unlife
@@ -331,9 +336,9 @@
 },
 
 {   // Book of Wizardry
-    SPELL_SUMMON_ELEMENTAL,
     SPELL_AGONY,
     SPELL_FORCE_LANCE,
+    SPELL_DISPERSAL,
     SPELL_HASTE,
     SPELL_INVISIBILITY,
     SPELL_SPELLFORGED_SERVITOR,
@@ -353,7 +358,7 @@
 },
 
 {   // Book of Cantrips
-    SPELL_CONFUSING_TOUCH,
+    SPELL_CORONA,
     SPELL_ANIMATE_SKELETON,
     SPELL_SUMMON_SMALL_MAMMAL,
     SPELL_APPORTATION,
@@ -367,8 +372,8 @@
     SPELL_SUMMON_BUTTERFLIES,
     SPELL_APPORTATION,
     SPELL_BLINK,
-    SPELL_INTOXICATE,
     SPELL_TUKIMAS_DANCE,
+    SPELL_INTOXICATE,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
@@ -410,11 +415,11 @@
 },
 
 {   // Book of Burglary
-    SPELL_APPORTATION,
     SPELL_SWIFTNESS,
     SPELL_PASSWALL,
     SPELL_GOLUBRIAS_PASSAGE,
     SPELL_LRD,
+    SPELL_INVISIBILITY,
     SPELL_DARKNESS,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
@@ -432,8 +437,8 @@
 },
 
 {   // Book of Alchemy
-    SPELL_LETHAL_INFUSION,
     SPELL_SUBLIMATION_OF_BLOOD,
+    SPELL_INTOXICATE,
     SPELL_CONDENSATION_SHIELD,
     SPELL_PETRIFY,
     SPELL_IGNITE_POISON,
@@ -467,12 +472,12 @@
 {   // Grand Grimoire
     SPELL_AURA_OF_ABJURATION,
     SPELL_FORCEFUL_DISMISSAL,
-    SPELL_HAUNT,
     SPELL_SUMMON_GREATER_DEMON,
     SPELL_MALIGN_GATEWAY,
     SPELL_SUMMON_HORRIBLE_THINGS,
     SPELL_NO_SPELL,
     SPELL_NO_SPELL,
+    SPELL_NO_SPELL,
 },
 
 {   // Necronomicon
@@ -601,3 +606,5 @@
     SPELL_NO_SPELL,
 },
 #endif
+
+};
