@@ -28,6 +28,7 @@
 #include "describe.h"
 #include "dgn-overview.h"
 #include "dungeon.h"
+#include "env.h"
 #include "fight.h"
 #include "files.h"
 #include "godprayer.h"
@@ -45,6 +46,7 @@
 #include "output.h"
 #include "place.h"
 #include "player.h"
+#include "prompt.h"
 #include "religion.h"
 #include "shopping.h"
 #include "showsymb.h"
@@ -54,8 +56,7 @@
 #include "spl-util.h"
 #include "stash.h"
 #include "state.h"
-#include "stuff.h"
-#include "env.h"
+#include "stringutil.h"
 #include "transform.h"
 #include "travel.h"
 #include "unicode.h"
@@ -70,7 +71,6 @@ static void _sdump_header(dump_params &);
 static void _sdump_stats(dump_params &);
 static void _sdump_location(dump_params &);
 static void _sdump_religion(dump_params &);
-static void _sdump_burden(dump_params &);
 static void _sdump_hunger(dump_params &);
 static void _sdump_transform(dump_params &);
 static void _sdump_visits(dump_params &);
@@ -125,7 +125,6 @@ static dump_section_handler dump_handlers[] =
     { "stats",          _sdump_stats         },
     { "location",       _sdump_location      },
     { "religion",       _sdump_religion      },
-    { "burden",         _sdump_burden        },
     { "hunger",         _sdump_hunger        },
     { "transform",      _sdump_transform     },
     { "visits",         _sdump_visits        },
@@ -218,23 +217,6 @@ static void _sdump_stats(dump_params &par)
     par.text += "\n\n";
 }
 
-static void _sdump_burden(dump_params &par)
-{
-    string verb = par.se? "were" : "are";
-
-    switch (you.burden_state)
-    {
-    case BS_OVERLOADED:
-        par.text += "You " + verb + " overloaded with stuff.\n";
-        break;
-    case BS_ENCUMBERED:
-        par.text += "You " + verb + " encumbered.\n";
-        break;
-    default:
-        break;
-    }
-}
-
 static void _sdump_hunger(dump_params &par)
 {
     if (par.se)
@@ -291,7 +273,8 @@ static void _sdump_transform(dump_params &par)
             else
             {
                 text += make_stringf("You %s grown temporary %s.",
-                                     par.se ? "had" : "have", appendage_name());
+                                     par.se ? "had" : "have",
+                                     mutation_name((mutation_type) you.attribute[ATTR_APPENDAGE]));
             }
             break;
         case TRAN_FUNGUS:
@@ -300,9 +283,11 @@ static void _sdump_transform(dump_params &par)
         case TRAN_TREE:
             text += "You " + verb + " an animated tree.";
             break;
+#if TAG_MAJOR_VERSION == 34
         case TRAN_JELLY:
             text += "You " + verb + " an acidic jelly.";
             break;
+#endif
         case TRAN_PORCUPINE:
             text += "You " + verb + " a porcupine.";
             break;
@@ -462,10 +447,17 @@ static void _sdump_gold(dump_params &par)
     if (you.attribute[ATTR_DONATIONS] > 0)
     {
         lines++;
-        text += make_stringf("You %sdonated %d gold pieces.\n", have,
+        text += make_stringf("You %sdonated %d gold pieces to Zin.\n", have,
                              you.attribute[ATTR_DONATIONS]);
     }
 
+    if (you.attribute[ATTR_GOZAG_GOLD_USED] > 0)
+    {
+        lines++;
+        text += make_stringf("You %spaid %d gold pieces to Gozag.\n", have,
+                             you.attribute[ATTR_GOZAG_GOLD_USED]);
+    }
+
     if (you.attribute[ATTR_MISC_SPENDING] > 0)
     {
         lines++;
@@ -482,7 +474,6 @@ static void _sdump_misc(dump_params &par)
 {
     _sdump_location(par);
     _sdump_religion(par);
-    _sdump_burden(par);
     _sdump_hunger(par);
     _sdump_transform(par);
     _sdump_visits(par);
@@ -1151,6 +1142,8 @@ static string _describe_action(caction_type type)
         return "  Use";
     case CACT_STAB:
         return " Stab";
+    case CACT_EAT:
+        return "  Eat";
     default:
         return "Error";
     }
@@ -1240,6 +1233,9 @@ static string _describe_action_subtype(caction_type type, int subtype)
         COMPILE_CHECK(ARRAYSZ(_stab_names) == NUM_STAB);
         ASSERT_RANGE(subtype, 1, NUM_STAB);
         return _stab_names[subtype];
+    case CACT_EAT:
+        return subtype >= 0 ? uppercase_first(food_type_name(subtype))
+                            : "Corpse";
     default:
         return "Error";
     }
@@ -1351,7 +1347,7 @@ static const char* thirst_names[] =
     "almost alive",
 };
 
-const char *hunger_level(void)
+const char *hunger_level()
 {
     COMPILE_CHECK(ARRAYSZ(hunger_names) == HS_ENGORGED + 1);
     COMPILE_CHECK(ARRAYSZ(thirst_names) == HS_ENGORGED + 1);
