@@ -119,6 +119,7 @@
 {'(', CMD_CYCLE_QUIVER_BACKWARD},
 {')', CMD_CYCLE_QUIVER_FORWARD},
 {CONTROL('V'), CMD_TOGGLE_VIEWPORT_MONSTER_HP},
+{CONTROL('T'), CMD_TOGGLE_VIEWPORT_WEAPONS},
 {'\\', CMD_DISPLAY_KNOWN_OBJECTS},
 {'}', CMD_DISPLAY_RUNES},
 {'\'', CMD_WEAPON_SWAP},
@@ -152,7 +153,6 @@
 {CONTROL('P'), CMD_REPLAY_MESSAGES},
 {CONTROL('Q'), CMD_QUIT},
 {CONTROL('R'), CMD_REDRAW_SCREEN},
-{CONTROL('T'), CMD_TOGGLE_FRIENDLY_PICKUP},
 {CONTROL('W'), CMD_FIX_WAYPOINT},
 {CONTROL('X'), CMD_FULL_VIEW},
 {CONTROL('Z'), CMD_SUSPEND_GAME},
@@ -331,6 +331,7 @@
 {',', CMD_MAP_GOTO_TARGET},
 {';', CMD_MAP_GOTO_TARGET},
 {'!', CMD_MAP_ANNOTATE_LEVEL},
+{'o', CMD_MAP_EXPLORE},
 {ESCAPE, CMD_MAP_EXIT_MAP},
 #ifdef CLUA_BINDINGS
 {CONTROL('I'), CMD_AUTOFIGHT},
