@@ -50,12 +50,15 @@ enum element_type
     ETC_WAVES,          // cyan, with regularly occurring lightcyan waves
     ETC_TREE,           // colour of trees on land
     ETC_RANDOM,         // any colour (except BLACK)
-    ETC_TORNADO,        // twisting swirls of gray
+    ETC_TORNADO,        // twisting swirls of grey
     ETC_LIQUEFIED,      // ripples of yellow and brown.
+#if TAG_MAJOR_VERSION == 34
     ETC_MANGROVE,       // colour of trees on water
+#endif
     ETC_ORB_GLOW,       // halo coming from the Orb of Zot
     ETC_DISJUNCTION,    // halo from Disjunction
     ETC_DITHMENOS,      // Dithmenos altar colours
+    ETC_ELEMENTAL,      // Cycling elemental colours
     ETC_DISCO = 96,
     ETC_FIRST_LUA = ETC_DISCO, // colour indices have to be <128
 
