@@ -19,6 +19,8 @@ void display_overview();
 bool unnotice_feature(const level_pos &pos);
 string overview_description_string(bool display);
 void enter_branch(branch_type branch, level_id from);
+void mark_offlevel_shop(level_id lid, shop_type type);
+void unmark_offlevel_shop(level_id lid);
 
 ///////////////////////////////////////////////////////////
 void set_level_exclusion_annotation(string str,
