@@ -148,7 +148,7 @@ RiverLayout::operator()(const coord_def &p, const uint32_t offset) const
         if (!(hash % 5))
             feat = DNGN_DEEP_WATER;
         if (!(hash % 23))
-            feat = DNGN_MANGROVE;
+            feat = DNGN_TREE;
         return ProceduralSample(p, feat, changepoint);
     }
     return layout(p, offset);
@@ -186,9 +186,11 @@ NewAbyssLayout::operator()(const coord_def &p, const uint32_t offset) const
 
 dungeon_feature_type sanitize_feature(dungeon_feature_type feature, bool strict)
 {
-    if (feat_is_gate(feature))
+    if (feat_is_gate(feature) || feature == DNGN_TELEPORTER)
         feature = DNGN_STONE_ARCH;
-    if (feat_is_stair(feature))
+    if (feature == DNGN_SEALED_DOOR)
+        feature = DNGN_CLOSED_DOOR;
+    if (feat_is_stair(feature) || feat_is_sealed(feature))
         feature = strict ? DNGN_FLOOR : DNGN_STONE_ARCH;
     if (feat_is_altar(feature))
         feature = DNGN_FLOOR;
@@ -207,8 +209,10 @@ dungeon_feature_type sanitize_feature(dungeon_feature_type feature, bool strict)
             break;
         case DNGN_SLIMY_WALL:
             feature = DNGN_GREEN_CRYSTAL_WALL;
+            break;
         case DNGN_UNSEEN:
             feature = DNGN_FLOOR;
+            break;
         default:
             // handle more terrain types.
             break;
@@ -394,7 +398,7 @@ UnderworldLayout::operator()(const coord_def &p, const uint32_t offset) const
 
     // TODO: The abyss doesn't support all of these yet but would be nice if:
     //  * Clusters of plants around water edge
-    //  * Hot and wet areas are "tropical" with plants/trees/mangroves (and steam)
+    //  * Hot and wet areas are "tropical" with plants/trees (and steam)
     //  * Extremely hot or cold areas should generate fire or ice clouds respectively.
     //    If an "ice" feature were ever created this would be a good place for it.
     //  * Wet cities have
@@ -467,7 +471,7 @@ UnderworldLayout::operator()(const coord_def &p, const uint32_t offset) const
             if (is_river)
             {
                 if (forest > 0.5 && wet > 0.5)
-                    feat = DNGN_MANGROVE;
+                    feat = DNGN_TREE;
             }
             else
                 feat = DNGN_TREE;
@@ -501,7 +505,9 @@ UnderworldLayout::operator()(const coord_def &p, const uint32_t offset) const
         {
             if ((lateral >= 0.3 && lateral < 0.4 || lateral >= 0.6 && lateral < 0.7)
                  || (lateral >= 0.4 && lateral < 0.6 && city < (city_outer_limit+city_wall_width)))
+            {
                 feat = city_wall;
+            }
             else if (lateral >= 0.4 && lateral < 0.6)
                 feat = DNGN_FLOOR;
         }
