@@ -23,7 +23,7 @@ struct crawl_environment
     colour_t floor_colour;
 
     FixedVector< item_def, MAX_ITEMS >       item;  // item list
-    FixedVector< monster, MAX_MONSTERS+1 >   mons;  // monster list, plus anon
+    FixedVector< monster, MAX_MONSTERS+2 >   mons;  // monster list, plus anon
 
     feature_grid                             grid;  // terrain grid
     FixedArray<terrain_property_t, GXM, GYM> pgrid; // terrain properties
@@ -46,10 +46,9 @@ struct crawl_environment
 
     unique_ptr<grid_heightmap>               heightmap;
 
+    map_bitmask                              map_seen;
     // Player-remembered terrain and LOS
     MapKnowledge                             map_knowledge;
-    // Previous map knowledge (last step)
-    MapKnowledge                             map_shadow;
     // Forgotten map knowledge (X^F)
     unique_ptr<MapKnowledge>                 map_forgotten;
     set<coord_def> visible;
