@@ -51,10 +51,11 @@
 #include "spl-clouds.h"
 #include "spl-util.h"
 #include "state.h"
-#include "stuff.h"
+#include "stringutil.h"
 #include "target.h"
 #include "terrain.h"
 #include "traps.h"
+#include "unicode.h"
 #include "view.h"
 #include "viewchar.h"
 #include "xom.h"
@@ -140,8 +141,7 @@ static bool _reaching_weapon_attack(const item_def& wpn)
     }
 
     // Calculate attack delay now in case we have to apply it.
-    melee_attack attk(&you, NULL);
-    const int attack_delay = attk.calc_attack_delay();
+    const int attack_delay = you.attack_delay(you.weapon());
 
     if (!feat_is_reachable_past(grd(first_middle))
         && !feat_is_reachable_past(grd(second_middle)))
@@ -241,10 +241,7 @@ static bool _reaching_weapon_attack(const item_def& wpn)
             you.turn_is_over = true;
         }
         else
-        {
-            canned_msg(MSG_OK);
             return false;
-        }
     }
 
     return true;
@@ -405,7 +402,6 @@ static void _fiery_explosion()
     beam.ex_size       = 2;
     beam.is_explosion  = true;
     beam.effect_known  = true;
-    beam.affects_items = true;
     beam.thrower       = KILL_YOU;
     beam.beam_source   = NON_MONSTER;
 
@@ -622,11 +618,10 @@ static const pop_entry pop_beasts[] =
   {  8, 18,  100, PEAK, MONS_HOG },
   { 10, 20,  100, PEAK, MONS_ICE_BEAST },
   { 10, 20,  100, PEAK, MONS_YAK },
-  { 10, 20,  100, PEAK, MONS_POLAR_BEAR },
   { 10, 20,  100, PEAK, MONS_WYVERN },
   { 10, 20,  100, PEAK, MONS_WOLF },
   { 11, 22,  100, PEAK, MONS_ALLIGATOR },
-  { 11, 22,  100, PEAK, MONS_GRIZZLY_BEAR },
+  { 11, 22,  200, PEAK, MONS_POLAR_BEAR },
   { 11, 22,  100, PEAK, MONS_WARG },
   { 13, 25,  100, PEAK, MONS_ELEPHANT },
   { 13, 25,  100, PEAK, MONS_GRIFFON },
@@ -741,45 +736,65 @@ static bool _sack_of_spiders(item_def &sack)
         return false;
     }
 
-    bool success = false;
-
-    if (!one_chance_in(5))
+    if (one_chance_in(5))
     {
-        int count = 1 + random2(3)
-                    + random2(div_rand_round(you.skill(SK_EVOCATIONS,10),40));
-        for (int n = 0; n < count; n++)
-        {
-            // Invoke mon-pick with our custom list
-            monster_type mon = pick_monster_from(pop_spiders,
-                                            max(1, you.skill(SK_EVOCATIONS)),
-                                            _box_of_beasts_veto_mon);
-            mgen_data mg = mgen_data(mon,
-                                     BEH_FRIENDLY, &you,
-                                     3 + random2(4), 0,
-                                     you.pos(),
-                                     MHITYOU, MG_AUTOFOE);
-            if (create_monster(mg))
-                success = true;
-        }
+        mpr("...but nothing happens.");
+        return false;
+    }
+
+    bool success = false;
+    int count = 1 + random2(3)
+        + random2(div_rand_round(you.skill(SK_EVOCATIONS, 10), 40));
+    for (int n = 0; n < count; n++)
+    {
+        // Invoke mon-pick with our custom list
+        monster_type mon = pick_monster_from(pop_spiders,
+                                             max(1, you.skill(SK_EVOCATIONS)),
+                                             _box_of_beasts_veto_mon);
+        mgen_data mg = mgen_data(mon,
+                                 BEH_FRIENDLY, &you,
+                                 3 + random2(4), 0,
+                                 you.pos(),
+                                 MHITYOU, MG_AUTOFOE);
+        if (create_monster(mg))
+            success = true;
     }
 
     if (success)
     {
-        // Also generate webs
+        mpr("...and things crawl out!");
+        // Also generate webs on hostile monsters and trap them.
         int rad = LOS_RADIUS / 2 + 2;
-        for (radius_iterator ri(you.pos(), rad, C_ROUND, LOS_SOLID, true); ri; ++ri)
+        for (monster_near_iterator mi(you.pos(), LOS_SOLID); mi; ++mi)
         {
-            if (grd(*ri) == DNGN_FLOOR)
+            trap_def *trap = find_trap((*mi)->pos());
+            // Don't destroy non-web traps or try to trap monsters
+            // currently caught by something.
+            if (you.pos().range((*mi)->pos()) > rad
+                || (!trap && grd((*mi)->pos()) != DNGN_FLOOR)
+                || (trap && trap->type != TRAP_WEB)
+                || (*mi)->friendly()
+                || (*mi)->caught())
             {
-                int chance = 100 - (100 * (you.pos().range(*ri) - 1) / rad)
-                             - 2 * (27 - you.skill(SK_EVOCATIONS));
-                if (x_chance_in_y(chance,100) && place_specific_trap(*ri, TRAP_WEB))
+                continue;
+            }
+
+            int chance = 100 - (100 * (you.pos().range((*mi)->pos()) - 1) / rad)
+                - 2 * (27 - you.skill(SK_EVOCATIONS));
+            if (x_chance_in_y(chance, 100))
+            {
+                if (trap && trap->type == TRAP_WEB)
+                    destroy_trap((*mi)->pos());
+
+                if (place_specific_trap((*mi)->pos(), TRAP_WEB))
+                {
                     // Reveal the trap
-                    grd(*ri) = DNGN_TRAP_WEB;
+                    grd((*mi)->pos()) = DNGN_TRAP_WEB;
+                    trap = find_trap((*mi)->pos());
+                    trap->trigger(**mi);
+                }
             }
         }
-        mpr("...and things crawl out!");
-        xom_is_stimulated(10);
         // Decrease charges
         sack.plus--;
         sack.plus2++;
@@ -791,7 +806,7 @@ static bool _sack_of_spiders(item_def &sack)
     return success;
 }
 
-static bool _ball_of_energy(void)
+static bool _ball_of_energy()
 {
     bool ret = false;
 
@@ -876,7 +891,9 @@ static vector<coord_def> _get_jitter_path(coord_def source, coord_def target,
             //Don't try to aim at targets in the opposite direction of main aim
             if ((abs(aim_dir.x - delta.sgn().x) + abs(aim_dir.y - delta.sgn().y) >= 2)
                  && !delta.origin())
+            {
                 continue;
+            }
 
             target = trace_beam.path_taken.back();
             break;
@@ -1419,7 +1436,7 @@ static bool _stone_of_tremors()
     // Destroy doors.
     for (unsigned int i = 0; i < door_pos.size(); ++i)
     {
-        nuke_wall(door_pos[i]);
+        destroy_wall(door_pos[i]);
         mpr("The door collapses!");
     }
 
@@ -1429,7 +1446,7 @@ static bool _stone_of_tremors()
     {
         if (_is_rock(grd(wall_pos[i])) && one_chance_in(3))
         {
-            nuke_wall(wall_pos[i]);
+            destroy_wall(wall_pos[i]);
             rubble_pos.push_back(wall_pos[i]);
         }
     }
@@ -1534,7 +1551,10 @@ static void _expend_xp_evoker(item_def &item)
 bool evoke_item(int slot, bool check_range)
 {
     if (you.form == TRAN_WISP)
-        return mpr("You cannot handle anything in this form."), false;
+    {
+        mpr("You cannot evoke items in this form.");
+        return false;
+    }
 
     if (you.berserk() && (slot == -1
                        || slot != you.equip[EQ_WEAPON]
@@ -1699,6 +1719,7 @@ bool evoke_item(int slot, bool check_range)
             wind_blast(&you, you.skill(SK_EVOCATIONS, 10), coord_def());
             _fan_of_gales_elementals();
             _expend_xp_evoker(item);
+            pract = 1;
             break;
 
         case MISC_LAMP_OF_FIRE:
@@ -1708,7 +1729,10 @@ bool evoke_item(int slot, bool check_range)
                 return false;
             }
             if (_lamp_of_fire())
+            {
                 _expend_xp_evoker(item);
+                pract = 1;
+            }
             else
                 return false;
 
@@ -1721,7 +1745,10 @@ bool evoke_item(int slot, bool check_range)
                 return false;
             }
             if (_stone_of_tremors())
+            {
                 _expend_xp_evoker(item);
+                pract = 1;
+            }
             else
                 return false;
             break;
@@ -1733,7 +1760,10 @@ bool evoke_item(int slot, bool check_range)
                 return false;
             }
             if (_phial_of_floods())
+            {
                 _expend_xp_evoker(item);
+                pract = 1;
+            }
             else
                 return false;
             break;
@@ -1745,7 +1775,10 @@ bool evoke_item(int slot, bool check_range)
                 return false;
             }
             if (_evoke_horn_of_geryon(item))
+            {
                 _expend_xp_evoker(item);
+                pract = 1;
+            }
             else
                 return false;
             break;
@@ -1769,7 +1802,7 @@ bool evoke_item(int slot, bool check_range)
 
         case MISC_DISC_OF_STORMS:
             if (disc_of_storms())
-                pract = (coinflip() ? 2 : 1);
+                pract = 1;
             break;
 
         case MISC_QUAD_DAMAGE:
