@@ -3,7 +3,6 @@
  * @brief Functions for using some of the wackier inventory items.
 **/
 
-
 #ifndef EVOKE_H
 #define EVOKE_H
 
@@ -18,7 +17,9 @@ void wind_blast(actor* agent, int pow, coord_def target);
 
 void tome_of_power(int slot);
 
-bool evoke_item(int slot = -1);
+bool can_flood_feature(dungeon_feature_type feat);
+
+bool evoke_item(int slot = -1, bool check_range = false);
 
 void shadow_lantern_effect();
 bool disc_of_storms(bool drac_breath = false);
