@@ -19,6 +19,7 @@
 #include "mon-util.h"
 #include "options.h"
 #include "env.h"
+#include "stringutil.h"
 #include "tags.h"
 #include "terrain.h"
 #include "travel.h"
@@ -30,6 +31,11 @@ extern set<pair<string, level_id> > auto_unique_annotations;
 
 static bool _mon_needs_auto_exclude(const monster* mon, bool sleepy = false)
 {
+    // These include the base monster's name in their name, but we don't
+    // want things in the auto_exclude option to match them.
+    if (mon->type == MONS_PILLAR_OF_SALT || mon->type == MONS_BLOCK_OF_ICE)
+        return false;
+
     if (mon->is_stationary())
         return !sleepy;
 
