@@ -25,13 +25,6 @@ enum exer_type
     EX_SHIELD_BLOCK,
     EX_DODGE_TRAP,
     EX_SHIELD_BEAM_FAIL,
-    EX_TRAP_DISARM,
-    EX_TRAP_DISARM_FAIL,
-    EX_TRAP_DISARM_TRIGGER,
-    EX_TRAP_FOUND,
-    EX_TRAP_PASSIVE,
-    EX_TRAP_TRIGGER,
-    EX_REMOVE_NET,
     EX_SNEAK,
     EX_SNEAK_INVIS,
     EX_DID_EVOKE_ITEM,
