@@ -10,34 +10,6 @@
 
 struct coord_def;
 
-struct VColour
-{
-    VColour() {}
-    VColour(unsigned char _r, unsigned char _g, unsigned char _b,
-            unsigned char _a = 255) : r(_r), g(_g), b(_b), a(_a) {}
-    VColour(const VColour &vc) : r(vc.r), g(vc.g), b(vc.b), a(vc.a) {}
-
-    inline void set(const VColour &in)
-    {
-        r = in.r;
-        g = in.g;
-        b = in.b;
-        a = in.a;
-    }
-
-    bool operator==(const VColour &vc) const;
-    bool operator!=(const VColour &vc) const;
-
-    unsigned char r;
-    unsigned char g;
-    unsigned char b;
-    unsigned char a;
-
-    static VColour white;
-    static VColour black;
-    static VColour transparent;
-};
-
 struct GLW_2VF
 {
     GLW_2VF() {}
@@ -174,7 +146,6 @@ public:
     virtual void fixup_gl_state() = 0;
 #endif
 
-
     // Texture-specific functinos
     virtual void delete_textures(size_t count, unsigned int *textures) = 0;
     virtual void generate_textures(size_t count, unsigned int *textures) = 0;
