@@ -16,12 +16,16 @@ bool is_unclean_item(const item_def& item);
 bool is_chaotic_item(const item_def& item);
 bool is_hasty_item(const item_def& item);
 bool is_poisoned_item(const item_def& item);
+bool is_illuminating_item(const item_def& item);
+bool is_fiery_item(const item_def& item);
 bool is_unholy_spell(spell_type spell);
 bool is_corpse_violating_spell(spell_type spell);
 bool is_evil_spell(spell_type spell);
 bool is_unclean_spell(spell_type spell);
 bool is_chaotic_spell(spell_type spell);
 bool is_hasty_spell(spell_type spell);
+bool is_illuminating_spell(spell_type spell);
+bool is_fiery_spell(spell_type spell);
 conduct_type good_god_hates_item_handling(const item_def &item);
 conduct_type god_hates_item_handling(const item_def &item);
 bool god_hates_item(const item_def &item);
