@@ -5,6 +5,8 @@
 #include <cmath>
 
 #include "artefact.h"
+#include "bloodspatter.h"
+#include "butcher.h"
 #include "coordit.h"
 #include "database.h"
 #include "effects.h"
@@ -21,17 +23,20 @@
 #include "player.h"
 #include "makeitem.h"
 #include "message.h"
-#include "misc.h"
 #include "monster.h"
 #include "notes.h"
 #include "options.h"
+#include "prompt.h"
 #include "random.h"
 #include "religion.h"
 #include "shopping.h"
 #include "skills2.h"
 #include "state.h"
-#include "stuff.h"
+#include "spl-wpnench.h"
+#include "stepdown.h"
+#include "stringutil.h"
 #include "terrain.h"
+#include "unwind.h"
 #include "view.h"
 
 static bool _offer_items();
@@ -82,7 +87,7 @@ string god_prayer_reaction()
 static bool _bless_weapon(god_type god, brand_type brand, int colour)
 {
     int item_slot = prompt_invent_item("Brand which weapon?", MT_INVLIST,
-                                       OSEL_BRANDABLE_WEAPON, true, true, false);
+                                       OSEL_BLESSABLE_WEAPON, true, true, false);
 
     if (item_slot == PROMPT_NOTHING || item_slot == PROMPT_ABORT)
         return false;
@@ -90,7 +95,7 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
     item_def& wpn(you.inv[item_slot]);
 
     // Only TSO allows blessing ranged weapons.
-    if (!is_brandable_weapon(wpn, brand == SPWPN_HOLY_WRATH))
+    if (!is_brandable_weapon(wpn, brand == SPWPN_HOLY_WRATH, true))
         return false;
 
     string prompt = "Do you wish to have " + wpn.name(DESC_YOUR)
@@ -109,7 +114,11 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
         return false;
     }
 
-    you.duration[DUR_WEAPON_BRAND] = 0;     // just in case
+    if (you.duration[DUR_WEAPON_BRAND]) // just in case
+    {
+        ASSERT(you.weapon());
+        end_weapon_brand(*you.weapon());
+    }
 
     string old_name = wpn.name(DESC_A);
     set_equip_desc(wpn, ISFLAG_GLOWING);
@@ -118,7 +127,8 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
 
     const bool is_cursed = wpn.cursed();
 
-    enchant_weapon(wpn, 1 + random2(2), 1 + random2(2), 0);
+    enchant_weapon(wpn, true);
+    enchant_weapon(wpn, true);
 
     if (is_cursed)
         do_uncurse_item(wpn, false);
@@ -132,16 +142,11 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
             origin_acquired(wpn, GOD_SHINING_ONE);
             wpn.flags |= ISFLAG_BLESSED_WEAPON;
         }
-
-        burden_change();
     }
     else if (is_evil_god(god))
     {
         convert2bad(wpn);
-
         wpn.flags &= ~ISFLAG_BLESSED_WEAPON;
-
-        burden_change();
     }
 
     you.wield_change = true;
@@ -197,7 +202,13 @@ static bool _bless_weapon(god_type god, brand_type brand, int colour)
     return true;
 }
 
-// Prayer at your god's altar.
+static bool _god_will_brand_weapon(god_type god)
+{
+   return you_worship(god) && !player_under_penance()
+          && you.piety >= piety_breakpoint(5)
+          && !you.one_time_ability_used[god];
+}
+
 static bool _altar_prayer()
 {
     // Different message from when first joining a religion.
@@ -205,38 +216,29 @@ static bool _altar_prayer()
 
     god_acting gdact;
 
-    bool did_something = false;
-
     // donate gold to gain piety distributed over time
     if (you_worship(GOD_ZIN))
-        did_something = _zin_donate_gold();
+        return _zin_donate_gold();
 
     // TSO blesses weapons with holy wrath, and long blades and demon
     // whips specially.
-    if (you_worship(GOD_SHINING_ONE) && !player_under_penance()
-        && you.piety >= piety_breakpoint(5)
-        && !you.one_time_ability_used[GOD_SHINING_ONE])
+    else if (_god_will_brand_weapon(GOD_SHINING_ONE))
     {
         simple_god_message(" will bless one of your weapons.");
         more();
-        did_something = _bless_weapon(GOD_SHINING_ONE, SPWPN_HOLY_WRATH,
-                                      YELLOW);
+        return _bless_weapon(GOD_SHINING_ONE, SPWPN_HOLY_WRATH, YELLOW);
     }
 
     // Lugonu blesses weapons with distortion.
-    if (you_worship(GOD_LUGONU) && !player_under_penance()
-        && you.piety >= piety_breakpoint(5)
-        && !you.one_time_ability_used[GOD_LUGONU])
+    else if (_god_will_brand_weapon(GOD_LUGONU))
     {
         simple_god_message(" will brand one of your weapons with the corruption of the Abyss.");
         more();
-        did_something = _bless_weapon(GOD_LUGONU, SPWPN_DISTORTION, MAGENTA);
+        return _bless_weapon(GOD_LUGONU, SPWPN_DISTORTION, MAGENTA);
     }
 
     // Kikubaaqudgha blesses weapons with pain, or gives you a Necronomicon.
-    if (you_worship(GOD_KIKUBAAQUDGHA) && !player_under_penance()
-        && you.piety >= piety_breakpoint(5)
-        && !you.one_time_ability_used[GOD_KIKUBAAQUDGHA])
+    else if (_god_will_brand_weapon(GOD_KIKUBAAQUDGHA))
     {
         if (you.species != SP_FELID)
         {
@@ -256,94 +258,182 @@ static bool _altar_prayer()
             }
         }
 
-        int thing_created = items(1, OBJ_BOOKS, BOOK_NECRONOMICON, true, 1,
-                                  0, 0, 0, you.religion);
+        int thing_created = items(1, OBJ_BOOKS, BOOK_NECRONOMICON, true, 1, 0,
+                                  0, you.religion);
 
-        if (thing_created == NON_ITEM)
+        if (thing_created == NON_ITEM || !move_item_to_grid(&thing_created, you.pos()))
             return false;
 
-        move_item_to_grid(&thing_created, you.pos());
+        simple_god_message(" grants you a gift!");
+        more();
 
-        if (thing_created != NON_ITEM)
-        {
-            simple_god_message(" grants you a gift!");
-            more();
+        you.one_time_ability_used.set(you.religion);
+        take_note(Note(NOTE_GOD_GIFT, you.religion));
 
-            you.one_time_ability_used.set(you.religion);
-            did_something = true;
-            take_note(Note(NOTE_GOD_GIFT, you.religion));
-        }
-
-        // Return early so we don't offer our Necronomicon to Kiku.
         return true;
     }
 
-    return did_something;
+    else if (you_worship(GOD_GOZAG) && !player_under_penance()
+        && !you.one_time_ability_used[GOD_GOZAG])
+    {
+        bool found = false;
+        bool prompted = false;
+        for (stack_iterator j(you.pos()); j; ++j)
+        {
+            if (is_artefact(*j)
+                || item_is_orb(*j)
+                || item_is_rune(*j)
+                || j->base_type == OBJ_GOLD)
+            {
+                found = true;
+                continue;
+            }
+
+            string message = "";
+            {
+                unwind_var<short int> old_quant = j->quantity;
+                j->quantity = 1;
+
+                prompted = true;
+
+                string prompt =
+                    make_stringf("Do you wish to duplicate %s?",
+                                 j->name(old_quant.original_value() > 1
+                                         ? DESC_A : DESC_THE).c_str());
+
+                if (!yesno(prompt.c_str(), true, 'n'))
+                    continue;
+
+                message = " duplicates " + j->name(DESC_YOUR) + "!";
+            }
+            if (!copy_item_to_grid(*j, you.pos(), 1))
+            {
+                mprf("Something went wrong!");
+                return false;
+            }
+
+            simple_god_message(message.c_str());
+            you.one_time_ability_used.set(you.religion);
+            take_note(Note(NOTE_ID_ITEM, 0, 0,
+                      j->name(DESC_A).c_str(), "duplicated by Gozag"));
+            return true;
+        }
+        if (prompted)
+            canned_msg(MSG_OK);
+        else if (found)
+            mprf("There's no item here that can be duplicated.");
+        return false;
+    }
+
+    // None of above are true, nothing happens.
+    return false;
 }
 
-void pray()
+/**
+ * Pray at, or convert to, an altar at the current position.
+ *
+ * @return Whether anything happened that took time.
+ */
+static bool _altar_pray_or_convert()
+{
+    const god_type altar_god = feat_altar_god(grd(you.pos()));
+    if (altar_god == GOD_NO_GOD)
+        return false;
+
+    if (you.species == SP_DEMIGOD)
+    {
+        mpr("A being of your status worships no god.");
+        return false;
+    }
+
+    if (you_worship(GOD_NO_GOD) || altar_god != you.religion)
+    {
+        // consider conversion
+        you.turn_is_over = true;
+        // But if we don't convert then god_pitch
+        // makes it not take a turn after all.
+        god_pitch(feat_altar_god(grd(you.pos())));
+        return you.turn_is_over;
+    }
+
+    // pray to your own god's altar
+    return _altar_prayer();
+}
+
+/**
+ * Zazen.
+ */
+static void _zen_meditation()
+{
+    const mon_holy_type holi = you.holiness();
+    mprf(MSGCH_PRAY,
+         "You spend a moment contemplating the meaning of %s.",
+         holi == MH_NONLIVING ? "existence" : holi == MH_UNDEAD ? "unlife" : "life");
+}
+
+/**
+ * Pray. (To your god, or the god of the altar you're at, or to Beogh, if
+ * you're an orc being preached at.)
+ */
+void pray(bool allow_altar_prayer)
 {
     // only successful prayer takes time
     you.turn_is_over = false;
 
-    bool something_happened = false;
-    const god_type altar_god = feat_altar_god(grd(you.pos()));
-    if (altar_god != GOD_NO_GOD)
+    // try to pray to an altar (if any is present)
+    if (allow_altar_prayer && _altar_pray_or_convert())
     {
-        if (!you_worship(GOD_NO_GOD) && altar_god == you.religion)
-            something_happened = _altar_prayer();
-        else if (altar_god != GOD_NO_GOD)
-        {
-            if (you.species == SP_DEMIGOD)
-            {
-                mpr("A being of your status worships no god.");
-                return;
-            }
+        you.turn_is_over = true;
+        return;
+    }
 
-            you.turn_is_over = true;
-            // But if we don't convert then god_pitch
-            // makes it not take a turn after all.
-            god_pitch(feat_altar_god(grd(you.pos())));
+    // convert to beogh via priest.
+    if (allow_altar_prayer && you_worship(GOD_NO_GOD)
+        && (env.level_state & LSTATE_BEOGH) && can_convert_to_beogh())
+    {
+        // TODO: deduplicate this with the code in _altar_pray_or_convert.
+        you.turn_is_over = true;
+        // But if we don't convert then god_pitch
+        // makes it not take a turn after all.
+        god_pitch(GOD_BEOGH);
+        if (you_worship(GOD_BEOGH))
+        {
+            spare_beogh_convert();
             return;
         }
     }
 
+    ASSERT(!you.turn_is_over);
+
+    // didn't convert to anyone.
     if (you_worship(GOD_NO_GOD))
     {
-        const mon_holy_type holi = you.holiness();
-
-        mprf(MSGCH_PRAY,
-             "You spend a moment contemplating the meaning of %s.",
-             holi == MH_NONLIVING ? "existence" : holi == MH_UNDEAD ? "unlife" : "life");
-
-        // Zen meditation is timeless.
+        // wasn't considering following a god; just meditating.
+        if (feat_altar_god(grd(you.pos())) == GOD_NO_GOD)
+            _zen_meditation();
         return;
     }
 
-    if (!something_happened) // If something happened, there already was a prayer
-        mprf(MSGCH_PRAY, "You offer a %sprayer to %s.",
-            you.cannot_speak() ? "silent " : "",
-            god_name(you.religion).c_str());
+    mprf(MSGCH_PRAY, "You offer a %sprayer to %s.",
+         you.cannot_speak() ? "silent " : "",
+         god_name(you.religion).c_str());
 
-    if (you_worship(GOD_FEDHAS) && fedhas_fungal_bloom())
-        something_happened = true;
-
-    // All sacrifices affect items you're standing on.
-    something_happened |= _offer_items();
+    you.turn_is_over = _offer_items()
+                      || (you_worship(GOD_FEDHAS) && fedhas_fungal_bloom());
 
     if (you_worship(GOD_XOM))
         mprf(MSGCH_GOD, "%s", getSpeakString("Xom prayer").c_str());
+    else if (you_worship(GOD_GOZAG))
+        mprf(MSGCH_GOD, "%s", getSpeakString("Gozag prayer").c_str());
     else if (player_under_penance())
         simple_god_message(" demands penance!");
     else
         mprf(MSGCH_PRAY, you.religion, "%s", god_prayer_reaction().c_str());
 
-    if (something_happened)
-        you.turn_is_over = true;
     dprf("piety: %d (-%d)", you.piety, you.piety_hysteresis);
 }
 
-int zin_tithe(item_def& item, int quant, bool quiet, bool converting)
+int zin_tithe(const item_def& item, int quant, bool quiet, bool converting)
 {
     int taken = 0;
     int due = quant += you.attribute[ATTR_TITHE_BASE];
@@ -498,7 +588,7 @@ static void _ashenzari_sac_scroll(const item_def& item)
                                          jwl, SCR_CURSE_JEWELLERY,
                                          0);
         }
-        int it = items(0, OBJ_SCROLLS, scr, true, 0, 0, 0, 0, GOD_ASHENZARI);
+        int it = items(0, OBJ_SCROLLS, scr, true, 0, 0, 0, GOD_ASHENZARI);
         if (it == NON_ITEM)
         {
             mpr("You feel the world is against you.");
@@ -548,7 +638,7 @@ static piety_gain_t _sac_corpse(const item_def& item)
             const monsterentry *m = get_monster_data(dummy.type);
             int hp = hit_points(hd, m->hpdice[1], m->hpdice[2]) + m->hpdice[3];
 
-            dummy.hit_dice = hd;
+            dummy.set_hit_dice(hd);
             dummy.max_hit_points = hp;
         }
         int gain = get_fuzzied_monster_difficulty(&dummy);
@@ -652,33 +742,6 @@ static piety_gain_t _sacrifice_one_item_noncount(const item_def& item,
         break;
     }
 
-    case GOD_NEMELEX_XOBEH:
-    {
-        if (you.attribute[ATTR_CARD_COUNTDOWN] && x_chance_in_y(value, 800))
-        {
-            you.attribute[ATTR_CARD_COUNTDOWN]--;
-#if defined(DEBUG_DIAGNOSTICS) || defined(DEBUG_CARDS) || defined(DEBUG_SACRIFICE)
-            mprf(MSGCH_DIAGNOSTICS, "Countdown down to %d",
-                 you.attribute[ATTR_CARD_COUNTDOWN]);
-#endif
-        }
-        // Nemelex piety gain is fairly fast... at least when you
-        // have low piety.
-        int piety_change = value/2 + 1;
-        if (is_artefact(item))
-            piety_change *= 2;
-        int piety_denom = 30 + you.piety/2;
-
-        gain_piety(piety_change, piety_denom);
-
-        // Preserving the old behaviour of giving the big message for
-        // artefacts and artefacts only.
-        relative_piety_gain = x_chance_in_y(piety_change, piety_denom) ?
-                                is_artefact(item) ?
-                                  PIETY_LOTS : PIETY_SOME : PIETY_NONE;
-        break;
-    }
-
     case GOD_JIYVA:
     {
         // compress into range 0..250
@@ -721,6 +784,11 @@ piety_gain_t sacrifice_item_stack(const item_def& item, int *js, int quantity)
     return relative_gain;
 }
 
+/**
+ * Sacrifice the items at the player's location to the player's god.
+ *
+ * @return  True if an item was sacrificed, false otherwise.
+*/
 static bool _offer_items()
 {
     if (!god_likes_items(you.religion))
@@ -735,7 +803,6 @@ static bool _offer_items()
 
     int num_sacced = 0;
     int num_disliked = 0;
-    item_def *disliked_item = 0;
 
     while (i != NON_ITEM)
     {
@@ -743,14 +810,11 @@ static bool _offer_items()
         const int next = item.link;  // in case we can't get it later.
         const bool disliked = !god_likes_item(you.religion, item);
 
-        if (item_is_stationary(item) || disliked)
+        if (item_is_stationary_net(item) || disliked)
         {
-            i = next;
             if (disliked)
-            {
                 num_disliked++;
-                disliked_item = &item;
-            }
+            i = next;
             continue;
         }
 
@@ -786,23 +850,10 @@ static bool _offer_items()
     // Explanatory messages if nothing the god likes is sacrificed.
     if (num_sacced == 0 && num_disliked > 0)
     {
-        ASSERT(disliked_item);
-
-        if (item_is_orb(*disliked_item))
-            simple_god_message(" wants the Orb's power used on the surface!");
-        else if (item_is_rune(*disliked_item))
-            simple_god_message(" wants the runes to be proudly displayed.");
-        // Zin was handled above, and the other gods don't care about
-        // sacrifices.
-        else if (god_likes_fresh_corpses(you.religion))
+        if (god_likes_fresh_corpses(you.religion))
             simple_god_message(" only cares about fresh corpses!");
         else if (you_worship(GOD_BEOGH))
             simple_god_message(" only cares about orcish remains!");
-        else if (you_worship(GOD_NEMELEX_XOBEH))
-            if (disliked_item->base_type == OBJ_GOLD)
-                simple_god_message(" does not care about gold!");
-            else
-                simple_god_message(" expects you to use your decks, not offer them!");
         else if (you_worship(GOD_ASHENZARI))
             simple_god_message(" can corrupt only scrolls of remove curse.");
     }
