@@ -12,6 +12,7 @@
 #include "act-iter.h"
 #include "artefact.h"
 #include "attitude-change.h"
+#include "coordit.h"
 #include "database.h"
 #include "decks.h"
 #include "effects.h"
@@ -21,21 +22,24 @@
 #include "ghost.h"
 #include "godabil.h"
 #include "itemprop.h"
+#include "items.h"
 #include "libutil.h"
 #include "message.h"
 #include "misc.h"
+#include "mon-behv.h"
 #include "mon-cast.h"
 #include "mon-util.h"
 #include "mon-pick.h"
+#include "mon-poly.h"
 #include "mon-place.h"
 #include "terrain.h"
 #include "mgen_data.h"
 #include "makeitem.h"
-#include "mon-stuff.h"
 #include "mutation.h"
 #include "ouch.h"
 #include "player-stats.h"
 #include "potion.h"
+#include "random-weight.h"
 #include "religion.h"
 #include "shopping.h"
 #include "spl-clouds.h"
@@ -45,8 +49,10 @@
 #include "spl-summoning.h"
 #include "spl-transloc.h"
 #include "state.h"
+#include "stringutil.h"
 #include "transform.h"
 #include "shout.h"
+#include "view.h"
 #include "xom.h"
 
 #include <sstream>
@@ -55,8 +61,6 @@ static void _god_smites_you(god_type god, const char *message = NULL,
                             kill_method_type death_type = NUM_KILLBY);
 static bool _beogh_idol_revenge();
 static void _tso_blasts_cleansing_flame(const char *message = NULL);
-static bool _tso_holy_revenge();
-static bool _ely_holy_revenge(const monster *victim);
 
 static bool _yred_random_zombified_hostile()
 {
@@ -292,12 +296,9 @@ static void _ely_dull_inventory_weapons()
 
         if (you.inv[i].base_type == OBJ_WEAPONS)
         {
-            // Don't dull artefacts at all, or weapons below -1/-1.
-            if (is_artefact(you.inv[i])
-                || you.inv[i].plus <= -1 && you.inv[i].plus2 <= -1)
-            {
+            // Don't dull artefacts at all, or weapons below -1.
+            if (is_artefact(you.inv[i]) || you.inv[i].plus <= -1)
                 continue;
-            }
 
             // 2/3 of the time, don't do anything.
             if (!one_chance_in(3))
@@ -311,8 +312,6 @@ static void _ely_dull_inventory_weapons()
             // Dull the weapon.
             if (you.inv[i].plus > -1)
                 you.inv[i].plus--;
-            if (you.inv[i].plus2 > -1)
-                you.inv[i].plus2--;
 
             // Update the weapon display, if necessary.
             if (wielded)
@@ -468,7 +467,7 @@ static bool _makhleb_retribution()
         avatar->mname = "the fury of Makhleb";
         avatar->flags |= MF_NAME_REPLACE;
         avatar->attitude = ATT_HOSTILE;
-        avatar->hit_dice = you.experience_level;
+        avatar->set_hit_dice(you.experience_level);
 
         spell_type spell = SPELL_NO_SPELL;
         const int severity = min(random_range(you.experience_level / 14,
@@ -795,7 +794,6 @@ static bool _beogh_retribution()
                 set_item_ego_type(wpn, OBJ_WEAPONS, SPWPN_ELECTROCUTION);
 
                 wpn.plus  = random2(3);
-                wpn.plus2 = random2(3);
                 wpn.sub_type = wpn_type;
 
                 set_ident_flags(wpn, ISFLAG_KNOW_TYPE);
@@ -915,10 +913,6 @@ static bool _sif_muna_retribution()
         break;
 
     case 7:
-        if (!forget_spell())
-            mpr("You get a splitting headache.");
-        break;
-
     case 8:
         if (you.magic_points > 0
 #if TAG_MAJOR_VERSION == 34
@@ -935,23 +929,26 @@ static bool _sif_muna_retribution()
         // This will set all the extendable duration spells to
         // a duration of one round, thus potentially exposing
         // the player to real danger.
-        antimagic();
+        debuff_player();
         break;
     }
 
     return true;
 }
 
-static bool _lugonu_retribution()
+/**
+ * Perform translocation-flavored Lugonu retribution.
+ *
+ * 50% chance of tloc miscasts; failing that, 50% chance of teleports/blinks.
+ */
+static void _lugonu_transloc_retribution()
 {
-    // abyssal servant theme
     const god_type god = GOD_LUGONU;
 
     if (coinflip())
     {
         simple_god_message("'s wrath finds you!", god);
         MiscastEffect(&you, -god, SPTYP_TRANSLOCATION, 9, 90, "Lugonu's touch");
-        // No return - Lugonu's touch is independent of other effects.
     }
     else if (coinflip())
     {
@@ -962,28 +959,51 @@ static bool _lugonu_retribution()
             you_teleport_now(false);
         else
             random_blink(false);
-
-        // No return.
     }
+}
 
+/**
+ * Summon Lugonu's minions to punish the player.
+ *
+ * Possibly a major minion with pals, possibly just some riff-raff, depending
+ * on level & chance.
+ */
+static void _lugonu_minion_retribution()
+{
+    // abyssal servant theme
+    const god_type god = GOD_LUGONU;
+
+    // should we summon more & higher-tier lugonu minions?
+    // linear chance, from 0% at xl 4 to 80% at xl 16
+    const bool major = (you.experience_level > (4 + random2(12))
+                        && !one_chance_in(5));
+
+    // how many lesser minions should we try to summon?
+    // if this is major wrath, summon a few minions; 0 below xl9, 0-3 at xl 27.
+    // otherwise, summon exactly (!) 1 + xl/7 minions, maxing at 4 at xl 21.
+    const int how_many = (major ? random2(you.experience_level / 9 + 1)
+                                : 1 + you.experience_level / 7);
+
+    // did we successfully summon any minions? (potentially set true below)
     bool success = false;
-    bool major = (you.experience_level > (4 + random2(12)) && !one_chance_in(5));
-    int how_many = (major ? random2(you.experience_level / 9 + 1)
-                          : 1 + you.experience_level /7);
 
-    for (; how_many > 0; --how_many)
+    for (int i = 0; i < how_many; ++i)
     {
-        mgen_data temp =
-            mgen_data::hostile_at(
-                random_choose_weighted(
-                    15 - (you.experience_level/2),  MONS_ABOMINATION_SMALL,
-                    (you.experience_level/2),       MONS_ABOMINATION_LARGE,
-                    6,                              MONS_THRASHING_HORROR,
-                    3,                              MONS_ANCIENT_ZYME,
-                    0),
-                "the touch of Lugonu",
-                true, 0, 0, you.pos(), 0, god);
+        // try to summon a few minor minions...
+        // weight toward large abominations, and away from small ones, at
+        // higher levels
+        const monster_type to_summon =
+            random_choose_weighted(
+                15 - (you.experience_level/2),  MONS_ABOMINATION_SMALL,
+                you.experience_level/2,         MONS_ABOMINATION_LARGE,
+                6,                              MONS_THRASHING_HORROR,
+                3,                              MONS_ANCIENT_ZYME,
+                0
+            );
 
+        mgen_data temp = mgen_data::hostile_at(to_summon,
+                                               "the touch of Lugonu", true, 0,
+                                               0, you.pos(), 0, god);
         temp.extra_flags |= (MF_NO_REWARD | MF_HARD_RESET);
 
         if (create_monster(temp, false))
@@ -992,15 +1012,15 @@ static bool _lugonu_retribution()
 
     if (major)
     {
-        mgen_data temp =
-        mgen_data::hostile_at(random_choose(
-                                MONS_TENTACLED_STARSPAWN,
-                                MONS_WRETCHED_STAR,
-                                MONS_STARCURSED_MASS,
-                                -1),
-                                "the touch of Lugonu",
-                                true, 0, 0, you.pos(), 0, god);
+        // try to summon one nasty monster.
+        const monster_type to_summon = random_choose(MONS_TENTACLED_STARSPAWN,
+                                                     MONS_WRETCHED_STAR,
+                                                     MONS_STARCURSED_MASS,
+                                                     -1);
 
+        mgen_data temp = mgen_data::hostile_at(to_summon,
+                                               "the touch of Lugonu", true, 0,
+                                               0, you.pos(), 0, god);
         temp.extra_flags |= (MF_NO_REWARD | MF_HARD_RESET);
 
         if (create_monster(temp, false))
@@ -1008,7 +1028,18 @@ static bool _lugonu_retribution()
     }
 
     simple_god_message(success ? " sends minions to punish you."
-                                : "'s minions fail to arrive.", god);
+                               : "'s minions fail to arrive.", god);
+}
+
+/**
+ * Call down the wrath of Lugonu upon the player!
+ *
+ * @return Whether to take further divine wrath actions afterward. (false.)
+ */
+static bool _lugonu_retribution()
+{
+    _lugonu_transloc_retribution();
+    _lugonu_minion_retribution();
 
     return false;
 }
@@ -1027,7 +1058,7 @@ static bool _vehumet_retribution()
     avatar->mname = "the wrath of Vehumet";
     avatar->flags |= MF_NAME_REPLACE;
     avatar->attitude = ATT_HOSTILE;
-    avatar->hit_dice = you.experience_level;
+    avatar->set_hit_dice(you.experience_level);
 
     spell_type spell = SPELL_NO_SPELL;
     const int severity = min(random_range(1 + you.experience_level / 5,
@@ -1200,7 +1231,6 @@ static bool _jiyva_retribution()
             MONS_SHINING_EYE,
             MONS_GIANT_ORANGE_BRAIN,
             MONS_JELLY,
-            MONS_BROWN_OOZE,
             MONS_ACID_BLOB,
             MONS_AZURE_JELLY,
             MONS_DEATH_OOZE,
@@ -1245,7 +1275,7 @@ static bool _fedhas_retribution()
     case 0:
         // Try and spawn some hostile giant spores, if none are created
         // fall through to the elemental miscast effects.
-        if (fedhas_corpse_spores(BEH_HOSTILE, false))
+        if (fedhas_corpse_spores(BEH_HOSTILE))
         {
             simple_god_message(" produces spores.", GOD_FEDHAS);
             break;
@@ -1381,7 +1411,7 @@ static bool _dithmenos_retribution()
     // shadow theme
     const god_type god = GOD_DITHMENOS;
 
-    switch(random2(4))
+    switch (random2(4))
     {
     case 0:
     {
@@ -1438,6 +1468,115 @@ static bool _dithmenos_retribution()
     return true;
 }
 
+static bool _qazlal_retribution()
+{
+    // disaster/elemental theme
+    const god_type god = GOD_QAZLAL;
+
+    switch (random2(3))
+    {
+    case 0:
+    {
+        mgen_data temp =
+            mgen_data::hostile_at(MONS_NO_MONSTER,
+                                  "the adversity of Qazlal",
+                                  true, 0, 0, you.pos(), 0, god);
+
+        temp.hd = you.experience_level;
+        temp.extra_flags |= (MF_NO_REWARD | MF_HARD_RESET);
+
+        int how_many = 1 + (you.experience_level / 5);
+        bool success = false;
+
+        for (; how_many > 0; how_many--)
+        {
+            temp.cls = random_choose(MONS_FIRE_ELEMENTAL,
+                                     MONS_WATER_ELEMENTAL,
+                                     MONS_AIR_ELEMENTAL,
+                                     MONS_EARTH_ELEMENTAL,
+                                     -1);
+            if (create_monster(temp, false))
+                success = true;
+        }
+        if (success)
+            simple_god_message(" incites the elements against you!", god);
+        else
+        {
+            simple_god_message(" fails to incite the elements against you.",
+                               god);
+        }
+        break;
+    }
+    case 1:
+    {
+        // TODO: think of terrain-ish effects for the other elements
+        bool success = false;
+        vector<coord_weight> candidates;
+        for (radius_iterator ri(you.pos(), LOS_NO_TRANS); ri; ++ri)
+        {
+            if (grd(*ri) != DNGN_FLOOR
+                || actor_at(*ri)
+                || igrd(*ri) != NON_ITEM)
+            {
+                continue;
+            }
+
+            const int weight = LOS_RADIUS*LOS_RADIUS
+                               - distance2(you.pos(), *ri);
+            candidates.push_back(coord_weight(*ri, weight));
+        }
+        int how_many = min((int)candidates.size(),
+                           3 + (you.experience_level / 2));
+        while (how_many > 0)
+        {
+            coord_def* pos = random_choose_weighted(candidates);
+            if (!pos)
+                break;
+            success = true;
+            how_many--;
+            temp_change_terrain(*pos, DNGN_LAVA,
+                                random2(you.experience_level * BASELINE_DELAY),
+                                TERRAIN_CHANGE_FLOOD);
+            for (vector<coord_weight>::iterator it = candidates.begin();
+                 it != candidates.end(); ++it)
+            {
+                if (it->first == *pos)
+                {
+                    candidates.erase(it);
+                    break;
+                }
+            }
+        }
+        if (success)
+        {
+            mprf(MSGCH_GOD, god,
+                 "The ground around you shudders, and lava spills forth!");
+        }
+        else
+        {
+            mprf(MSGCH_GOD, god,
+                 "The ground around you shudders for a moment.");
+        }
+        break;
+    }
+    case 2:
+        if (mutate(RANDOM_QAZLAL_MUTATION, "the adversity of Qazlal", false,
+                   false, true, false, false, false, true))
+        {
+            simple_god_message(" strips away your elemental protection.",
+                               god);
+        }
+        else
+        {
+            simple_god_message(" fails to strip away your elemental protection.",
+                               god);
+        }
+        break;
+    }
+
+    return true;
+}
+
 bool divine_retribution(god_type god, bool no_bonus, bool force)
 {
     ASSERT(god != GOD_NO_GOD);
@@ -1480,8 +1619,10 @@ bool divine_retribution(god_type god, bool no_bonus, bool force)
     case GOD_FEDHAS:        do_more = _fedhas_retribution(); break;
     case GOD_CHEIBRIADOS:   do_more = _cheibriados_retribution(); break;
     case GOD_DITHMENOS:     do_more = _dithmenos_retribution(); break;
+    case GOD_QAZLAL:        do_more = _qazlal_retribution(); break;
 
     case GOD_ASHENZARI:
+    case GOD_GOZAG:
         // No reduction with time.
         return false;
 
@@ -1522,7 +1663,7 @@ bool divine_retribution(god_type god, bool no_bonus, bool force)
     return true;
 }
 
-bool do_god_revenge(conduct_type thing_done, const monster *victim)
+bool do_god_revenge(conduct_type thing_done)
 {
     bool retval = false;
 
@@ -1531,16 +1672,6 @@ bool do_god_revenge(conduct_type thing_done, const monster *victim)
     case DID_DESTROY_ORCISH_IDOL:
         retval = _beogh_idol_revenge();
         break;
-    case DID_KILL_HOLY:
-    case DID_HOLY_KILLED_BY_UNDEAD_SLAVE:
-    case DID_HOLY_KILLED_BY_SERVANT:
-        // It's TSO who does the smiting and war stuff so he handles revenge
-        // for his allies as well -- unless another god has some special ties.
-        if (victim && victim->god == GOD_ELYVILON)
-            retval = _ely_holy_revenge(victim);
-        else
-            retval = _tso_holy_revenge();
-        break;
     default:
         break;
     }
@@ -1614,78 +1745,6 @@ static void _tso_blasts_cleansing_flame(const char *message)
     }
 }
 
-// Currently only used when holy beings have been killed.
-static string _get_tso_speech(const string key)
-{
-    string result = getSpeakString("the Shining One " + key);
-
-    if (result.empty())
-        return "The Shining One is angry!";
-
-    return result;
-}
-
-// Killing holy beings may anger TSO.
-static bool _tso_holy_revenge()
-{
-    god_acting gdact(GOD_SHINING_ONE, true);
-
-    // TSO watches evil god worshippers more closely.
-    if (!is_good_god(you.religion)
-        && ((is_evil_god(you.religion) && one_chance_in(6))
-            || one_chance_in(8)))
-    {
-        string revenge;
-
-        if (is_evil_god(you.religion))
-            revenge = _get_tso_speech("holy evil");
-        else
-            revenge = _get_tso_speech("holy other");
-
-        _tso_blasts_cleansing_flame(revenge.c_str());
-
-        return true;
-    }
-
-    return false;
-}
-
-// Killing apises may make Elyvilon sad.  She'll sulk and stuff.
-static bool _ely_holy_revenge(const monster *victim)
-{
-    god_acting gdact(GOD_ELYVILON, true);
-
-    if (!is_good_god(you.religion)
-        && ((is_evil_god(you.religion) && one_chance_in(4))
-            || one_chance_in(6)))
-    {
-        string msg = getSpeakString("Elyvilon holy");
-        if (msg.empty())
-            msg = "Elyvilon is displeased.";
-        mprf(MSGCH_GOD, GOD_ELYVILON, "%s", msg.c_str());
-
-        vector<monster*> targets;
-        for (monster_near_iterator mi(you.pos(), LOS_NO_TRANS); mi; ++mi)
-        {
-            if (mi->friendly())
-                targets.push_back(*mi);
-        }
-
-        mprf("You %sare rebuked by divine will.", targets.size() ? "and your allies "
-                                                                 : "");
-        for (vector<monster*>::const_iterator mi = targets.begin();
-             mi != targets.end(); ++mi)
-        {
-            (*mi)->weaken(NULL, 25);
-        }
-        you.weaken(NULL, 25);
-
-        return true;
-    }
-
-    return false;
-}
-
 static void _god_smites_you(god_type god, const char *message,
                             kill_method_type death_type)
 {
@@ -1748,3 +1807,99 @@ void ash_reduce_penance(int amount)
     if (new_pen < you.penance[GOD_ASHENZARI])
         dec_penance(GOD_ASHENZARI, you.penance[GOD_ASHENZARI] - new_pen);
 }
+
+void gozag_incite(monster *mon)
+{
+    ASSERT(!mon->wont_attack());
+
+    behaviour_event(mon, ME_ALERT, &you);
+
+    bool success = false;
+
+    if (coinflip() && mon->needs_berserk(false))
+    {
+        mon->go_berserk(false);
+        success = true;
+    }
+    else
+    {
+        int tries = 3;
+        do
+        {
+            switch (random2(3))
+            {
+                case 0:
+                    if (mon->has_ench(ENCH_MIGHT))
+                        break;
+                    enchant_actor_with_flavour(mon, mon, BEAM_MIGHT);
+                    success = true;
+                    break;
+                case 1:
+                    if (mon->has_ench(ENCH_HASTE))
+                        break;
+                    enchant_actor_with_flavour(mon, mon, BEAM_HASTE);
+                    success = true;
+                    break;
+                case 2:
+                    if (mon->invisible() || you.can_see_invisible())
+                        break;
+                    enchant_actor_with_flavour(mon, mon, BEAM_INVISIBILITY);
+                    success = true;
+                    break;
+            }
+        }
+        while (!success && --tries > 0);
+    }
+
+    if (success)
+        view_update_at(mon->pos());
+}
+
+/**
+ * Invoke the CURSE OF GOZAG by goldifying some part of a stack that the player
+ * is trying to pick up.
+ * @param it            The item being picked up.
+ * @param quant_got     The number of items being picked up. (May be only part
+ * of the stack.)
+ * @param quiet         Whether to suppress messages.
+ * @return              How much of the stack was goldified.
+ */
+bool gozag_goldify(const item_def &it, int quant_got, bool quiet)
+{
+    if (it.base_type != OBJ_POTIONS
+        && it.base_type != OBJ_SCROLLS
+        && it.base_type != OBJ_FOOD)
+    {
+        return 0;
+    }
+
+
+    const int val = item_value(it, true) / it.quantity;
+    double prob = (double)(val - 20) / 100.0;
+    if (prob > 1.0)
+        prob = 1.0;
+
+    int goldified_count = 0;
+    for (int i = 0; i < quant_got; i++)
+        if (decimal_chance(prob))
+            goldified_count++;
+
+    if (!goldified_count)
+        return goldified_count;
+
+    if (!quiet)
+    {
+        string msg = get_desc_quantity(goldified_count, quant_got, "the")
+                     + " " + it.name(DESC_PLAIN);
+        msg += goldified_count > 1 ? " turn" : " turns";
+        msg += " to gold as you touch ";
+        msg += goldified_count > 1 ? "them." : "it.";
+
+        mprf(MSGCH_GOD, GOD_GOZAG, "%s", msg.c_str());
+    }
+
+    get_gold(it, goldified_count, quiet);
+    dec_penance(GOD_GOZAG, goldified_count);
+
+    return goldified_count;
+}
