@@ -10,17 +10,20 @@
 
 struct bolt;
 
-void init_properties(void);
+void init_properties();
 
 // cursed:
 bool item_known_cursed(const item_def &item) PURE;
+bool curse_an_item(bool ignore_holy_wrath = false);
 void do_curse_item(item_def &item, bool quiet = true);
 void do_uncurse_item(item_def &item, bool inscribe = true, bool no_ash = false,
                      bool check_bondage = true);
 
 // stationary:
-void set_item_stationary(item_def &item);
+void set_net_stationary(item_def &item);
 bool item_is_stationary(const item_def &item) PURE;
+bool item_is_stationary_net(const item_def &item) PURE;
+actor *net_holdee(const item_def &net);
 
 // ident:
 bool item_ident(const item_def &item, iflags_t flags) PURE;
@@ -75,15 +78,18 @@ void ident_reflector(item_def *item);
 int weapon_rarity(int w_type) IMMUTABLE;
 
 int   cmp_weapon_size(const item_def &item, size_type size) PURE;
-bool  check_weapon_wieldable_size(const item_def &item, size_type size) PURE;
-
-size_type weapon_size(const item_def &item) PURE;
+bool  is_weapon_wieldable(const item_def &item, size_type size) PURE;
 
 hands_reqd_type basic_hands_reqd(const item_def &item, size_type size) PURE;
 hands_reqd_type hands_reqd(const actor* ac, object_class_type base_type, int sub_type);
 
 bool is_giant_club_type(int wpn_type) IMMUTABLE;
+bool is_ranged_weapon_type(int wpn_type) IMMUTABLE;
+bool is_blessed_weapon_type(int wpn_type) IMMUTABLE;
+bool is_demonic_weapon_type(int wpn_type) IMMUTABLE;
+bool is_magic_weapon_type(int wpn_type) IMMUTABLE;
 
+bool is_melee_weapon(const item_def &weapon) PURE;
 bool is_demonic(const item_def &item) PURE;
 bool is_blessed(const item_def &item) PURE;
 bool is_blessed_convertible(const item_def &item) PURE;
@@ -94,18 +100,20 @@ int get_vorpal_type(const item_def &item) PURE;
 int get_damage_type(const item_def &item) PURE;
 int single_damage_type(const item_def &item) PURE;
 
-bool is_brandable_weapon(const item_def &wpn, bool allow_ranged);
+bool is_brandable_weapon(const item_def &wpn, bool allow_ranged, bool divine = false);
 
 int weapon_str_weight(const item_def &wpn) PURE;
 
-skill_type weapon_skill(const item_def &item) PURE;
-skill_type weapon_skill(object_class_type wclass, int wtype) IMMUTABLE;
+skill_type item_attack_skill(const item_def &item) PURE;
+skill_type item_attack_skill(object_class_type wclass, int wtype) IMMUTABLE;
+
+skill_type melee_skill(const item_def &item) PURE;
+skill_type melee_skill(object_class_type wclass, int wtype) IMMUTABLE;
 
 skill_type range_skill(const item_def &item) PURE;
 skill_type range_skill(object_class_type wclass, int wtype) IMMUTABLE;
 
 bool item_skills(const item_def &item, set<skill_type> &skills);
-void maybe_change_train(const item_def &item, bool start);
 
 // launcher and ammo functions:
 bool is_range_weapon(const item_def &item) PURE;
@@ -117,7 +125,12 @@ bool is_throwable(const actor *actor, const item_def &wpn,
                   bool force = false) PURE;
 launch_retval is_launched(const actor *actor, const item_def *launcher,
                           const item_def &missile) PURE;
-bool is_melee_weapon(const item_def &weapon) PURE;
+
+bool ammo_always_destroyed(const item_def &missile) PURE;
+bool ammo_never_destroyed(const item_def &missile) PURE;
+int  ammo_type_destroy_chance(int missile_type) PURE;
+int  ammo_type_damage(int missile_type) PURE;
+
 
 reach_type weapon_reach(const item_def &item) PURE;
 
@@ -133,7 +146,7 @@ bool is_xp_evoker(const item_def &item);
 bool evoker_is_charged(const item_def &item);
 
 // ring functions:
-int  ring_has_pluses(const item_def &item) PURE;
+bool ring_has_pluses(const item_def &item) PURE;
 bool ring_has_stackable_effect(const item_def &item) PURE;
 
 // food functions:
@@ -170,6 +183,7 @@ int property(const item_def &item, int prop_type) PURE;
 bool gives_ability(const item_def &item) PURE;
 bool gives_resistance(const item_def &item) PURE;
 int item_mass(const item_def &item) PURE;
+bool is_item_jelly_edible(const item_def &item);
 equipment_type get_item_slot(object_class_type type, int sub_type) IMMUTABLE;
 equipment_type get_item_slot(const item_def &item) PURE;
 
@@ -177,6 +191,7 @@ string item_base_name(const item_def &item);
 string item_base_name(object_class_type type, int sub_type);
 string food_type_name(int sub_type);
 const char *weapon_base_name(weapon_type subtype) IMMUTABLE;
+weapon_type name_nospace_to_weapon(string name_nospace);
 
 void seen_item(const item_def &item);
 
@@ -186,4 +201,6 @@ static inline bool is_weapon(const item_def &item)
            || item.base_type == OBJ_STAVES
            || item.base_type == OBJ_RODS;
 }
+
+void remove_whitespace(string &str);
 #endif
