@@ -23,6 +23,7 @@
 #include "shout.h"
 #include "spl-util.h"
 #include "state.h"
+#include "stringutil.h"
 #include "tiledef-dngn.h"
 #include "tileview.h"
 #include "unwind.h"
@@ -225,9 +226,11 @@ static int dgn_change_level_flags(lua_State *ls)
 static void _chance_magnitude_check(lua_State *ls, int which_par, int chance)
 {
     if (chance < 0 || chance > CHANCE_ROLL)
+    {
         luaL_argerror(ls, which_par,
                       make_stringf("Chance must be in the range [0,%d]",
                                    CHANCE_ROLL).c_str());
+    }
 }
 
 static int dgn_chance(lua_State *ls)
@@ -635,10 +638,12 @@ static int dgn_map_pathfind(lua_State *ls, int minargs,
     MAP(ls, 1, map);
     const int nargs = lua_gettop(ls);
     if (nargs < minargs)
+    {
         return luaL_error
         (ls,
          make_stringf("Not enough points to test connectedness "
                       "(need at least %d)", minargs / 2).c_str());
+    }
 
     map_def::map_feature_finder feat_finder(*map);
     map_def::map_bounds_check bounds_checker(*map);
@@ -1525,9 +1530,10 @@ LUAFN(dgn_with_map_anchors)
         for (i = 1; i < top; i += 2)
         {
             if (lua_isnumber(ls, i) && lua_isnumber(ls, i + 1))
-                map_anchor_points.push_back(
-                                            coord_def(lua_tointeger(ls, i),
+            {
+                map_anchor_points.push_back(coord_def(lua_tointeger(ls, i),
                                                       lua_tointeger(ls, i + 1)));
+            }
         }
 
         ASSERT(lua_isfunction(ls, -1));
