@@ -11,25 +11,12 @@
 #include <string>
 #include <vector>
 #include <map>
-
-extern const char *standard_plural_qualifiers[];
-
-// Applies a description type to a name, but does not pluralise! You
-// must pluralise the name if needed. The quantity is used to prefix the
-// name with a quantity if appropriate.
-string apply_description(description_level_type desc, const string &name,
-                         int quantity = 1, bool num_in_words = false);
-
-description_level_type description_type_by_name(const char *desc);
-
-string lowercase_string(string s);
-string &lowercase(string &s);
-string &uppercase(string &s);
-string uppercase_first(string);
-string lowercase_first(string);
+#include "stringutil.h" // :( for find_earliest_match
 
 bool key_is_escape(int key);
 
+// numeric string functions
+
 #define CASE_ESCAPE case ESCAPE: case CONTROL('G'): case -1:
 
 // Unscales a fixed-point number, rounding up.
@@ -72,26 +59,30 @@ static inline ucs_t toalower(ucs_t c)
 
 int numcmp(const char *a, const char *b, int limit = 0);
 bool numcmpstr(string a, string b);
-size_t strlcpy(char *dst, const char *src, size_t n);
-
-int strwidth(const char *s);
-int strwidth(const string &s);
-string chop_string(const char *s, int width, bool spaces = true);
-string chop_string(const string &s, int width, bool spaces = true);
-string wordwrap_line(string &s, int cols, bool tags = false,
-                     bool indent = false);
 
 bool version_is_stable(const char *ver);
 
 // String "tags"
 #define TAG_UNFOUND -20404
 bool strip_tag(string &s, const string &tag, bool nopad = false);
-bool strip_suffix(string &s, const string &suffix);
 int strip_number_tag(string &s, const string &tagprefix);
 vector<string> strip_multiple_tag_prefix(string &s, const string &tagprefix);
 string strip_tag_prefix(string &s, const string &tagprefix);
 bool parse_int(const char *s, int &i);
 
+string number_in_words(unsigned number, int pow = 0);
+
+// String 'descriptions'
+
+extern const char *standard_plural_qualifiers[];
+
+// Applies a description type to a name, but does not pluralise! You
+// must pluralise the name if needed. The quantity is used to prefix the
+// name with a quantity if appropriate.
+string apply_description(description_level_type desc, const string &name,
+                         int quantity = 1, bool num_in_words = false);
+
+description_level_type description_type_by_name(const char *desc);
 string article_a(const string &name, bool lowercase = true);
 string pluralise(const string &name,
                  const char *stock_plural_quals[] = standard_plural_qualifiers,
@@ -99,79 +90,70 @@ string pluralise(const string &name,
 string apostrophise(const string &name);
 string apostrophise_fixup(const string &msg);
 
-string number_in_words(unsigned number, int pow = 0);
+
 
 bool shell_safe(const char *file);
 
-/**
- * Returns 1 + the index of the first suffix that matches the given string,
- * 0 if no suffixes match.
- */
-int ends_with(const string &s, const char *suffixes[]);
-
-string strip_filename_unsafe_chars(const string &s);
-
-string vmake_stringf(const char *format, va_list args);
-string make_stringf(PRINTF(0, ));
-
-string replace_all(string s, const string &tofind, const string &replacement);
-
-string replace_all_of(string s, const string &tofind, const string &replacement);
-
-string maybe_capitalise_substring(string s);
-string maybe_pick_random_substring(string s);
-
-int count_occurrences(const string &text, const string &searchfor);
-
 void play_sound(const char *file);
 
-string &trim_string(string &str);
-string &trim_string_right(string &str);
-string trimmed_string(string s);
-
-static inline bool starts_with(const string &s, const string &prefix)
-{
-    return s.rfind(prefix, 0) != string::npos;
-}
-
-static inline bool ends_with(const string &s, const string &suffix)
-{
-    if (s.length() < suffix.length())
-        return false;
-    return s.find(suffix, s.length() - suffix.length()) != string::npos;
-}
-
-// Splits string 's' on the separator 'sep'. If trim == true, trims each
-// segment. If accept_empties == true, accepts empty segments. If nsplits >= 0,
-// splits on the first nsplits occurrences of the separator, and stores the
-// remainder of the string as the last segment; negative values of nsplits
-// split on all occurrences of the separator.
-vector<string> split_string(const string &sep, string s, bool trim = true,
-                            bool accept_empties = false, int nsplits = -1);
-
-template <typename Z>
-string comma_separated_line(Z start, Z end, const string &andc = " and ",
-                            const string &comma = ", ")
-{
-    string text;
-    for (Z i = start; i != end; ++i)
-    {
-        if (i != start)
-        {
-            Z tmp = i;
-            if (++tmp != end)
-                text += comma;
-            else
-                text += andc;
-        }
-
-        text += *i;
-    }
-    return text;
-}
-
 string unwrap_desc(string desc);
 
+template<class T> bool _always_true(T) { return true; }
+
+/**
+ * Find the enumerator e between begin and end that satisfies pred(e) and
+ * whose name, as given by namefunc(e), has the earliest occurrence of the
+ * substring spec.
+ *
+ * @param spec      The substring to search for.
+ * @param begin     The beginning of the enumerator range to search in.
+ * @param end       One past the end of the enum range to search in.
+ * @param pred      A function from Enum to bool. Enumerators that do not
+ *                  satisfy the predicate are ignored.
+ * @param namefunc  A function from Enum to string or const char * giving
+ *                  the name of the enumerator.
+ * @return The enumerator that satisfies pred and whose name contains the
+ *         spec substring beginning at the earliest position. If no such
+ *         enumerator exists, returns end. If there are multiple strings
+ *         containing the spec as a prefix, returns the shortest such string
+ *         (so exact matches are preferred); otherwise ties are broken in
+ *         an unspecified manner.
+ */
+template<class Enum, class Pred, class NameFunc>
+Enum find_earliest_match(string spec, Enum begin, Enum end,
+                         Pred pred, NameFunc namefunc)
+{
+    Enum selected = end;
+    const size_t speclen = spec.length();
+    size_t bestpos = string::npos;
+    size_t bestlen = string::npos;
+    for (size_t i = begin; i < (size_t) end; ++i)
+    {
+        const Enum curr = static_cast<Enum>(i);
+
+        if (!pred(curr))
+            continue;
+
+        const string name = lowercase_string(namefunc(curr));
+        const size_t pos = name.find(spec);
+        const size_t len = name.length();
+
+        if (pos < bestpos || pos == 0 && len < bestlen)
+        {
+            // Exit early if we found an exact match.
+            if (pos == 0 && len == speclen)
+                return curr;
+
+            // npos is never less than bestpos, so the spec was found.
+            bestpos = pos;
+            if (pos == 0)
+                bestlen = len;
+            selected = curr;
+        }
+    }
+    return selected;
+}
+
 template <typename Z>
 void erase_any(vector<Z> &vec, unsigned long which)
 {
@@ -188,6 +170,17 @@ static inline void swapv(Z &a, Z &b)
     b = tmp;
 }
 
+// A comparator for pairs.
+template<typename T>
+struct greater_second
+{
+    bool operator()(const T & left, const T & right)
+    {
+        return left.second > right.second;
+    }
+};
+
+
 static inline int sqr(int x)
 {
     return x * x;
