@@ -11,10 +11,8 @@
 int create_item_named(string name, coord_def pos, string *error);
 
 int items(bool allow_uniques, object_class_type force_class, int force_type,
-           bool dont_place, int item_level,
-           int rune_type = 0,
-           uint32_t mapmask = 0, int force_ego = 0, int agent = -1,
-           bool mundane = false);
+          bool dont_place, int item_level, uint32_t mapmask = 0,
+          int force_ego = 0, int agent = -1, bool mundane = false);
 
 void item_colour(item_def &item);
 void init_rod_mp(item_def &item, int ncharges = -1, int item_level = -1);
