@@ -18,12 +18,14 @@ void clear_message_window();
 
 void scroll_message_window(int n);
 
-void mesclr(bool force = false);
+void clear_messages(bool force = false);
 
 void flush_prev_message();
 
 void more(bool user_forced = false);
 
+void canned_msg(canned_message_type which_message);
+
 class formatted_string;
 
 void formatted_mpr(const formatted_string& fs,
