@@ -14,6 +14,8 @@ struct bolt;
 void init_mons_spells();
 bool is_valid_mon_spell(spell_type spell);
 
+bool mons_should_cloud_cone(monster* agent, int power, const coord_def pos);
+
 bool handle_mon_spell(monster* mons, bolt &beem);
 
 bolt mons_spell_beam(monster* mons, spell_type spell_cast, int power,
@@ -27,7 +29,10 @@ bool setup_mons_cast(monster* mons, bolt &pbolt, spell_type spell_cast,
 
 void mons_cast_haunt(monster* mons);
 unsigned short mons_word_of_recall(monster* mons, unsigned short recall_target);
-bool actor_is_illusion_cloneable(actor *target);
 void mons_cast_spectral_orcs(monster* mons);
 void setup_breath_timeout(monster* mons);
+
+monster* cast_phantom_mirror(monster* mons, monster* targ,
+                             int hp_perc = 35,
+                             int summ_type = SPELL_PHANTOM_MIRROR);
 #endif
