@@ -152,14 +152,13 @@ const uint64_t M_CANT_SPAWN        = (uint64_t)1<<46;
 // derived undead can't be randomly generated
 const uint64_t M_NO_GEN_DERIVED    = (uint64_t)1<<47;
 
-// tries to maintain range unless target is incapacitated
-const uint64_t M_STABBER           = (uint64_t)1<<48;
+// 1<<48
 
 // hybridized monster composed of other monster parts
 const uint64_t M_HYBRID            = (uint64_t)1<<49;
 
-// monster is always alerted to hostiles, and does not forget them over time
-const uint64_t M_VIGILANT          = (uint64_t)1<<50;
+// blinks around randomly (was M_VIGILANT)
+const uint64_t M_BLINKER           = (uint64_t)1<<50;
 
 // monster starts with Ozocubu's Armour
 const uint64_t M_OZOCUBUS_ARMOUR   = (uint64_t)1<<51;
@@ -232,7 +231,7 @@ const uint64_t MF_NAME_DESCRIPTOR    = BIT(27); // mname should be treated with
 const uint64_t MF_NAME_DEFINITE      = BIT(28); // give this monster the definite "the"
                                      // article, instead of the indefinite "a"
                                      // article.
-//////////////////////////////////// = BIT(29);
+const uint64_t MF_SPECTRALISED       = BIT(29); // living monster revived by a lost soul
 const uint64_t MF_DEMONIC_GUARDIAN   = BIT(30); // is a demonic_guardian
 const uint64_t MF_NAME_SPECIES       = BIT(31); // mname should be used for corpses as well,
 const uint64_t MF_NAME_ZOMBIE        = BIT(32); // mname replaces zombies/skeletons, use
