@@ -28,6 +28,15 @@ monster* mons_place(mgen_data mg);
 
 bool needs_resolution(monster_type mon_type);
 
+monster_type resolve_monster_type(monster_type mon_type,
+                                  monster_type &base_type,
+                                  proximity_type proximity = PROX_ANYWHERE,
+                                  coord_def *pos = nullptr,
+                                  unsigned mmask = 0,
+                                  dungeon_char_type *stair_type = nullptr,
+                                  level_id *place = nullptr,
+                                  bool *want_band = nullptr);
+
 const monster_type fixup_zombie_type(const monster_type cls,
                                      const monster_type base_type);
 
