@@ -10,6 +10,7 @@
 #include "cio.h"
 #include "command.h"
 #include "database.h"
+#include "end.h"
 #include "files.h"
 #include "hints.h"
 #include "initfile.h"
@@ -26,10 +27,11 @@
 #include "ng-input.h"
 #include "ng-restr.h"
 #include "options.h"
+#include "prompt.h"
 #include "random.h"
 #include "species.h"
 #include "state.h"
-#include "stuff.h"
+
 
 #ifdef USE_TILE_LOCAL
 #include "tilereg-crt.h"
@@ -950,7 +952,7 @@ void job_group::attach(const newgame_def* ng, const newgame_def& defaults,
             tmp->set_fg_colour(LIGHTGRAY);
             tmp->set_highlight_colour(BLUE);
         }
-        else if(job_allowed(ng->species, job) == CC_RESTRICTED)
+        else if (job_allowed(ng->species, job) == CC_RESTRICTED)
         {
             tmp->set_fg_colour(DARKGRAY);
             tmp->set_highlight_colour(BLUE);
@@ -1625,8 +1627,8 @@ static vector<weapon_choice> _get_weapons(const newgame_def* ng)
     vector<weapon_choice> weapons;
     if (ng->job == JOB_HUNTER || ng->job == JOB_ARCANE_MARKSMAN)
     {
-        weapon_type startwep[4] = { WPN_THROWN, WPN_SLING, WPN_BOW,
-                                    WPN_CROSSBOW };
+        weapon_type startwep[4] = { WPN_THROWN, WPN_HUNTING_SLING,
+                                    WPN_SHORTBOW, WPN_HAND_CROSSBOW };
 
         for (int i = 0; i < 4; i++)
         {
