@@ -5,6 +5,7 @@
 #include "ability.h"
 #include "decks.h"
 #include "dungeon.h"
+#include "end.h"
 #include "files.h"
 #include "food.h"
 #include "godcompanions.h"
@@ -15,28 +16,29 @@
 #include "item_use.h"
 #include "jobs.h"
 #include "maps.h"
-#include "misc.h"
 #include "mutation.h"
 #include "newgame.h"
 #include "ng-init.h"
 #include "ng-wanderer.h"
 #include "options.h"
 #include "player.h"
+#include "prompt.h"
 #include "religion.h"
+#include "rot.h"
 #include "skills.h"
 #include "skills2.h"
 #include "spl-book.h"
 #include "spl-util.h"
 #include "state.h"
-#include "stuff.h"
+
 #include "tutorial.h"
 
 #define MIN_START_STAT       3
 
 static void _newgame_give_item(object_class_type base, int sub_type,
-                               int qty = 1, int plus = 0, int plus2 = 0);
+                               int qty = 1, int plus = 0);
 
-static void _init_player(void)
+static void _init_player()
 {
     you.init();
     dlua.callfn("dgn_clear_data", "");
@@ -61,7 +63,6 @@ static void _species_stat_init(species_type which_species)
 
     case SP_HIGH_ELF:           s =  7; i = 11; d = 10;      break;  // 28
     case SP_DEEP_ELF:           s =  5; i = 12; d = 10;      break;  // 27
-    case SP_SLUDGE_ELF:         s =  8; i =  9; d =  9;      break;  // 26
 
     case SP_DEEP_DWARF:         s = 11; i =  8; d =  8;      break;  // 27
 
@@ -71,7 +72,9 @@ static void _species_stat_init(species_type which_species)
     case SP_MINOTAUR:           s = 12; i =  5; d =  5;      break;  // 22
     case SP_GARGOYLE:           s = 11; i =  8; d =  5;      break;  // 24
     case SP_HILL_ORC:           s = 10; i =  8; d =  6;      break;  // 24
+#if TAG_MAJOR_VERSION == 34
     case SP_LAVA_ORC:           s = 10; i =  8; d =  6;      break;  // 24
+#endif
     case SP_CENTAUR:            s = 10; i =  7; d =  4;      break;  // 21
     case SP_NAGA:               s = 10; i =  8; d =  6;      break;  // 24
 
@@ -80,8 +83,8 @@ static void _species_stat_init(species_type which_species)
     case SP_FORMICID:           s = 12; i =  7; d =  6;      break;  // 25
     case SP_VINE_STALKER:       s = 10; i =  8; d =  9;      break;  // 27
 
-    case SP_KOBOLD:             s =  7; i =  6; d = 10;      break;  // 23
-    case SP_HALFLING:           s =  5; i =  8; d = 11;      break;  // 24
+    case SP_KOBOLD:             s =  6; i =  6; d = 11;      break;  // 23
+    case SP_HALFLING:           s =  8; i =  7; d =  9;      break;  // 24
     case SP_SPRIGGAN:           s =  4; i =  9; d = 11;      break;  // 24
 
     case SP_MUMMY:              s = 11; i =  7; d =  7;      break;  // 25
@@ -175,8 +178,7 @@ static void _jobs_stat_init(job_type which_job)
     you.base_stats[STAT_INT] += i;
     you.base_stats[STAT_DEX] += d;
 
-    you.hp_max_perm = 0;
-    you.mp_max_perm = 0;
+    you.hp_max_adj_perm = 0;
 }
 
 // Make sure no stats are unacceptably low
@@ -221,19 +223,15 @@ void give_basic_mutations(species_type speci)
 {
     switch (speci)
     {
+#if TAG_MAJOR_VERSION == 34
     case SP_LAVA_ORC:
         you.mutation[MUT_CONSERVE_SCROLLS] = 1;
-    // Intentional fallthrough.
-    case SP_HILL_ORC:
-        you.mutation[MUT_SAPROVOROUS] = 1;
         break;
+#endif
     case SP_OGRE:
         you.mutation[MUT_TOUGH_SKIN]      = 1;
-        you.mutation[MUT_FAST_METABOLISM] = 1;
-        you.mutation[MUT_SAPROVOROUS]     = 1;
         break;
     case SP_HALFLING:
-        you.mutation[MUT_SLOW_METABOLISM]     = 1;
         you.mutation[MUT_MUTATION_RESISTANCE] = 1;
         break;
     case SP_MINOTAUR:
@@ -249,8 +247,6 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_TOUGH_SKIN]      = 3;
         you.mutation[MUT_FAST]            = 2;
         you.mutation[MUT_DEFORMED]        = 1;
-        you.mutation[MUT_FAST_METABOLISM] = 1;
-        you.mutation[MUT_HERBIVOROUS]     = 1;
         you.mutation[MUT_HOOVES]          = 3;
         break;
     case SP_NAGA:
@@ -264,7 +260,6 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_POISON_RESISTANCE]          = 1;
         you.mutation[MUT_COLD_RESISTANCE]            = 1;
         you.mutation[MUT_NEGATIVE_ENERGY_RESISTANCE] = 3;
-        you.mutation[MUT_UNBREATHING]                = 1;
         break;
     case SP_DEEP_DWARF:
         you.mutation[MUT_SLOW_HEALING]    = 3;
@@ -278,13 +273,12 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_SAPROVOROUS]                = 3;
         you.mutation[MUT_CARNIVOROUS]                = 3;
         you.mutation[MUT_SLOW_HEALING]               = 1;
-        you.mutation[MUT_UNBREATHING]                = 1;
         break;
     case SP_GARGOYLE:
         you.mutation[MUT_PETRIFICATION_RESISTANCE]   = 1;
         you.mutation[MUT_NEGATIVE_ENERGY_RESISTANCE] = 1;
         you.mutation[MUT_SHOCK_RESISTANCE]           = 1;
-        you.mutation[MUT_UNBREATHING]                = 1;
+        you.mutation[MUT_ROT_IMMUNITY]               = 1;
         break;
     case SP_TENGU:
         you.mutation[MUT_BEAK]   = 1;
@@ -299,13 +293,11 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_SHAGGY_FUR]      = 1;
         break;
     case SP_KOBOLD:
-        you.mutation[MUT_SAPROVOROUS] = 2;
         you.mutation[MUT_CARNIVOROUS] = 3;
         break;
     case SP_VAMPIRE:
         you.mutation[MUT_FANGS]        = 3;
         you.mutation[MUT_ACUTE_VISION] = 1;
-        you.mutation[MUT_UNBREATHING]  = 1;
         break;
     case SP_FELID:
         you.mutation[MUT_FANGS]           = 3;
@@ -333,7 +325,8 @@ void give_basic_mutations(species_type speci)
         you.mutation[MUT_ANTIMAGIC_BITE] = 1;
         you.mutation[MUT_REGENERATION]   = 1;
         you.mutation[MUT_MANA_SHIELD]    = 1;
-        you.mutation[MUT_NO_DEVICE_HEAL] = 1;
+        you.mutation[MUT_NO_DEVICE_HEAL] = 3;
+        you.mutation[MUT_ROT_IMMUNITY]   = 1;
         break;
     default:
         break;
@@ -342,19 +335,23 @@ void give_basic_mutations(species_type speci)
     // Some mutations out-sourced because they're
     // relevant during character choice.
     you.mutation[MUT_CLAWS] = species_has_claws(speci, true);
+    you.mutation[MUT_UNBREATHING] = species_is_unbreathing(speci);
+
+    // Necessary mostly for wizmode race changing.
+    you.mutation[MUT_COLD_BLOODED] = species_genus(speci) == GENPC_DRACONIAN;
 
     // Starting mutations are unremovable.
     for (int i = 0; i < NUM_MUTATIONS; ++i)
-        you.innate_mutations[i] = you.mutation[i];
+        you.innate_mutation[i] = you.mutation[i];
 }
 
 static void _newgame_make_item_tutorial(int slot, equipment_type eqslot,
                                  object_class_type base,
                                  int sub_type, int replacement = -1,
-                                 int qty = 1, int plus = 0, int plus2 = 0)
+                                 int qty = 1, int plus = 0)
 {
     newgame_make_item(slot, eqslot, base, sub_type, replacement, qty, plus,
-                      plus2, true);
+                      true);
 }
 
 // Creates an item of a given base and sub type.
@@ -363,7 +360,7 @@ static void _newgame_make_item_tutorial(int slot, equipment_type eqslot,
 void newgame_make_item(int slot, equipment_type eqslot,
                        object_class_type base,
                        int sub_type, int replacement,
-                       int qty, int plus, int plus2, bool force_tutorial)
+                       int qty, int plus, bool force_tutorial)
 {
     // Don't set normal equipment in the tutorial.
     if (!force_tutorial && crawl_state.game_is_tutorial())
@@ -400,7 +397,6 @@ void newgame_make_item(int slot, equipment_type eqslot,
     item.sub_type  = sub_type;
     item.quantity  = qty;
     item.plus      = plus;
-    item.plus2     = plus2;
     item.special   = 0;
 
     if (is_deck(item))
@@ -440,9 +436,9 @@ void newgame_make_item(int slot, equipment_type eqslot,
 }
 
 static void _newgame_give_item(object_class_type base, int sub_type,
-                               int qty, int plus, int plus2)
+                               int qty, int plus)
 {
-    newgame_make_item(-1, EQ_NONE, base, sub_type, -1, qty, plus, plus2);
+    newgame_make_item(-1, EQ_NONE, base, sub_type, -1, qty, plus);
 }
 
 static void _newgame_clear_item(int slot)
@@ -488,26 +484,30 @@ static void _update_weapon(const newgame_def& ng)
             autopickup_starting_ammo(MI_THROWING_NET);
         }
         break;
-    case WPN_BOW:
-        newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_BOW, -1, 1, plus, plus);
+    case WPN_SHORTBOW:
+        newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_SHORTBOW, -1, 1, plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_ARROW, -1, 20);
         autopickup_starting_ammo(MI_ARROW);
 
         // Wield the bow instead.
         you.equip[EQ_WEAPON] = 1;
         break;
-    case WPN_CROSSBOW:
-        newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_CROSSBOW, -1, 1, plus, plus);
+    case WPN_HAND_CROSSBOW:
+        newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_HAND_CROSSBOW, -1, 1,
+                          plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_BOLT, -1, 20);
         autopickup_starting_ammo(MI_BOLT);
 
         // Wield the crossbow instead.
         you.equip[EQ_WEAPON] = 1;
         break;
-    case WPN_SLING:
-        newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_SLING, -1, 1, plus, plus);
+    case WPN_HUNTING_SLING:
+        newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_HUNTING_SLING, -1, 1,
+                          plus);
         newgame_make_item(2, EQ_NONE, OBJ_MISSILES, MI_SLING_BULLET, -1, 20);
         autopickup_starting_ammo(MI_SLING_BULLET);
+        autopickup_starting_ammo(MI_STONE);
+
 
         // Wield the sling instead.
         you.equip[EQ_WEAPON] = 1;
@@ -644,8 +644,7 @@ static void _give_items_skills(const newgame_def& ng)
         you.religion = GOD_YREDELEMNUL;
         you.piety = 35;
 
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1,
-                          1, 1);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1, +1);
         _update_weapon(ng);
 
         newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_LEATHER_ARMOUR,
@@ -664,8 +663,7 @@ static void _give_items_skills(const newgame_def& ng)
             you.char_direction = GDT_GAME_START;
         you.piety = 38;
 
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1,
-                          1, 1);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1, +1);
         _update_weapon(ng);
 
         newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_LEATHER_ARMOUR,
@@ -689,7 +687,7 @@ static void _give_items_skills(const newgame_def& ng)
 
         you.equip[EQ_WEAPON] = -1;
 
-        newgame_make_item(0, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE, -1, 1, 1);
+        newgame_make_item(0, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE, -1, 1, +1);
         newgame_make_item(1, EQ_NONE, OBJ_POTIONS, POT_CURING);
         newgame_make_item(2, EQ_NONE, OBJ_POTIONS, POT_HEAL_WOUNDS);
 
@@ -699,7 +697,7 @@ static void _give_items_skills(const newgame_def& ng)
         break;
 
     case JOB_SKALD:
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1, 0, 0);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_SHORT_SWORD, -1, 1, +0);
         _update_weapon(ng);
 
         newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_LEATHER_ARMOUR,
@@ -724,13 +722,9 @@ static void _give_items_skills(const newgame_def& ng)
 
         // One free escape.
         newgame_make_item(3, EQ_NONE, OBJ_SCROLLS, SCR_BLINKING);
-        newgame_make_item(4, EQ_NONE, OBJ_MISSILES, MI_DART, -1, 15);
-
-        newgame_make_item(5, EQ_NONE, OBJ_MISSILES, MI_DART, -1, 10);
-        set_item_ego_type(you.inv[5], OBJ_MISSILES, SPMSL_DISPERSAL);
-
-        // Plain darts are maybe too weak for autopickup.
-        // autopickup_starting_ammo(MI_DART);
+        newgame_make_item(4, EQ_NONE, OBJ_MISSILES, MI_TOMAHAWK, -1, 5);
+        set_item_ego_type(you.inv[4], OBJ_MISSILES, SPMSL_DISPERSAL);
+        autopickup_starting_ammo(MI_TOMAHAWK);
 
         you.skills[SK_FIGHTING]       = 2;
         you.skills[SK_ARMOUR]         = 1;
@@ -781,26 +775,18 @@ static void _give_items_skills(const newgame_def& ng)
         break;
 
     case JOB_ENCHANTER:
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_DAGGER, -1, 1, 1,
-                           1);
-        newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE, -1, 1, 1);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_DAGGER, -1, 1, +1);
+        newgame_make_item(1, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE, -1, 1, +1);
         newgame_make_item(2, EQ_NONE, OBJ_BOOKS, BOOK_MALEDICT);
 
-        // Gets some darts - this job is difficult to start off with.
-        newgame_make_item(3, EQ_NONE, OBJ_MISSILES, MI_DART, -1, 12);
-
-        // Plain darts are maybe too weak for autopickup.
-        // autopickup_starting_ammo(MI_DART);
-
         if (you.species == SP_OGRE || you.species == SP_TROLL)
             you.inv[0].sub_type = WPN_CLUB;
 
         weap_skill = 1;
-        you.skills[SK_THROWING]     = 1;
         you.skills[SK_HEXES]        = 3;
         you.skills[SK_SPELLCASTING] = 2;
         you.skills[SK_DODGING]      = 2;
-        you.skills[SK_STEALTH]      = 2;
+        you.skills[SK_STEALTH]      = 3;
         break;
 
     case JOB_SUMMONER:
@@ -831,6 +817,9 @@ static void _give_items_skills(const newgame_def& ng)
         newgame_make_item(2, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE);
         newgame_make_item(3, EQ_NONE, OBJ_BOOKS, BOOK_CHANGES);
 
+        // keep picking up sticks
+        autopickup_starting_ammo(MI_ARROW);
+
         you.skills[SK_FIGHTING]       = 1;
         you.skills[SK_UNARMED_COMBAT] = 3;
         you.skills[SK_DODGING]        = 2;
@@ -900,7 +889,7 @@ static void _give_items_skills(const newgame_def& ng)
         break;
 
     case JOB_ASSASSIN:
-        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_DAGGER, -1, 1, 2, 2);
+        newgame_make_item(0, EQ_WEAPON, OBJ_WEAPONS, WPN_DAGGER, -1, 1, +2);
         newgame_make_item(1, EQ_NONE, OBJ_WEAPONS, WPN_BLOWGUN);
 
         newgame_make_item(2, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE);
@@ -940,7 +929,7 @@ static void _give_items_skills(const newgame_def& ng)
         if (you.species == SP_OGRE)
         {
             you.inv[0].sub_type = WPN_CLUB;
-            you.inv[0].plus = you.inv[0].plus2 = 1;
+            you.inv[0].plus = 1;
         }
 
         // Skills.
@@ -977,7 +966,7 @@ static void _give_items_skills(const newgame_def& ng)
         if (you.species == SP_OGRE)
         {
             you.inv[0].sub_type = WPN_CLUB;
-            you.inv[0].plus = you.inv[0].plus2 = 1;
+            you.inv[0].plus = 1;
         }
 
         // Skills
@@ -1006,7 +995,7 @@ static void _give_items_skills(const newgame_def& ng)
         if (!you.weapon())
             you.skills[SK_UNARMED_COMBAT] = weap_skill;
         else
-            you.skills[weapon_skill(*you.weapon())] = weap_skill;
+            you.skills[melee_skill(*you.weapon())] = weap_skill;
     }
 
     if (you.species == SP_FELID)
@@ -1046,7 +1035,6 @@ static void _give_starting_food()
     {
         item.base_type = OBJ_POTIONS;
         item.sub_type  = POT_BLOOD;
-        init_stack_blood_potions(item);
     }
     else
     {
@@ -1082,8 +1070,8 @@ static void _setup_tutorial_miscs()
     // No gold to begin with.
     you.gold = 0;
 
-    // Give him some mana to play around with.
-    you.mp_max_perm += 2;
+    // Give them some mana to play around with.
+    you.mp_max_adj += 2;
 
     _newgame_make_item_tutorial(0, EQ_BODY_ARMOUR, OBJ_ARMOUR, ARM_ROBE);
 
