@@ -14,7 +14,7 @@ void autopickup_starting_ammo(missile_type missile);
 void newgame_make_item(int slot, equipment_type eqslot,
                        object_class_type base,
                        int sub_type, int replacement = -1,
-                       int qty = 1, int plus = 0, int plus2 = 0,
+                       int qty = 1, int plus = 0,
                        bool force_tutorial = false);
 
 struct newgame_def;
