@@ -32,11 +32,13 @@
 #include "describe.h"
 #include "dgnevent.h"
 #include "effects.h"
+#include "end.h"
 #include "env.h"
 #include "files.h"
 #include "fight.h"
 #include "fineff.h"
 #include "godabil.h"
+#include "godpassive.h"
 #include "hints.h"
 #include "hiscores.h"
 #include "invent.h"
@@ -48,14 +50,16 @@
 #include "message.h"
 #include "mgen_data.h"
 #include "misc.h"
+#include "mon-death.h"
 #include "mon-util.h"
 #include "mon-place.h"
-#include "mon-stuff.h"
 #include "mutation.h"
 #include "notes.h"
+#include "output.h"
 #include "player.h"
 #include "player-stats.h"
 #include "potion.h"
+#include "prompt.h"
 #include "random.h"
 #include "religion.h"
 #include "shopping.h"
@@ -64,19 +68,17 @@
 #include "spl-selfench.h"
 #include "spl-other.h"
 #include "state.h"
-#include "stuff.h"
+#include "stringutil.h"
 #include "transform.h"
 #include "tutorial.h"
 #include "view.h"
 #include "shout.h"
 #include "xom.h"
 
-static void _end_game(scorefile_entry &se);
-
-static void _maybe_melt_player_enchantments(beam_type flavour, int damage)
+void maybe_melt_player_enchantments(beam_type flavour, int damage)
 {
     if (flavour == BEAM_FIRE || flavour == BEAM_LAVA
-        || flavour == BEAM_HELLFIRE || flavour == BEAM_NAPALM
+        || flavour == BEAM_HELLFIRE || flavour == BEAM_STICKY_FLAME
         || flavour == BEAM_STEAM)
     {
         if (you.duration[DUR_CONDENSATION_SHIELD] > 0)
@@ -90,7 +92,8 @@ static void _maybe_melt_player_enchantments(beam_type flavour, int damage)
 
         if (you.mutation[MUT_ICEMAIL])
         {
-            mprf(MSGCH_DURATION, "Your icy envelope dissipates!");
+            if (!you.duration[DUR_ICEMAIL_DEPLETED])
+                mprf(MSGCH_DURATION, "Your icy envelope dissipates!");
             you.duration[DUR_ICEMAIL_DEPLETED] = ICEMAIL_TIME;
             you.redraw_armour_class = true;
         }
@@ -123,7 +126,7 @@ int check_your_resists(int hurted, beam_type flavour, string source,
     }
 
     if (doEffects)
-        _maybe_melt_player_enchantments(flavour, hurted);
+        maybe_melt_player_enchantments(flavour, hurted);
 
     switch (flavour)
     {
@@ -195,11 +198,20 @@ int check_your_resists(int hurted, beam_type flavour, string source,
 
         if (hurted < original && doEffects)
             canned_msg(MSG_YOU_RESIST);
+        else if (hurted > original && doEffects)
+        {
+            mpr("You are shocked senseless!");
+            xom_is_stimulated(200);
+        }
         break;
 
     case BEAM_POISON:
         if (doEffects)
         {
+            // Ensure that we received a valid beam object before proceeding.
+            // See also melee_attack.cc:_print_resist_messages() which cannot be
+            // used with this beam type (as it does not provide a valid beam).
+            ASSERT(beam);
             int pois = div_rand_round(beam->damage.num * beam->damage.size, 3);
             pois = 3 + random_range(pois * 2 / 3, pois * 4 / 3);
 
@@ -218,14 +230,14 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         break;
 
     case BEAM_POISON_ARROW:
-        // [dshaligram] NOT importing uber-poison arrow from 4.1. Giving no
-        // bonus to poison resistant players seems strange and unnecessarily
-        // arbitrary.
-
         resist = player_res_poison();
 
         if (doEffects)
         {
+            // Ensure that we received a valid beam object before proceeding.
+            // See also melee_attack.cc:_print_resist_messages() which cannot be
+            // used with this beam type (as it does not provide a valid beam).
+            ASSERT(beam);
             int pois = div_rand_round(beam->damage.num * beam->damage.size, 3);
             pois = 3 + random_range(pois * 2 / 3, pois * 4 / 3);
 
@@ -242,7 +254,7 @@ int check_your_resists(int hurted, beam_type flavour, string source,
                                       hurted, true);
 
         if (doEffects)
-            drain_exp(true, min(75, 35 + original * 2 / 3));
+            drain_player(min(75, 35 + original * 2 / 3), true);
         break;
 
     case BEAM_ICE:
@@ -272,12 +284,10 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         break;
 
     case BEAM_ACID:
-        if (player_res_acid())
-        {
-            if (doEffects)
-                canned_msg(MSG_YOU_RESIST);
-            hurted = hurted * player_acid_resist_factor() / 100;
-        }
+        hurted = resist_adjust_damage(&you, flavour, player_res_acid(),
+                                      hurted, true);
+        if (hurted < original && doEffects)
+            canned_msg(MSG_YOU_RESIST);
         break;
 
     case BEAM_MIASMA:
@@ -305,43 +315,6 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         break;
     }
 
-    case BEAM_BOLT_OF_ZIN:
-    {
-        // Damage to chaos and mutations.
-
-        // For mutation damage, we want to count innate mutations for
-        // the demonspawn, but not for other species.
-        int mutated = how_mutated(you.species == SP_DEMONSPAWN, true);
-        int multiplier = min(mutated * 3, 60);
-        if (you.is_chaotic() || player_is_shapechanged())
-            multiplier = 60; // full damage
-        else if (you.is_undead || is_chaotic_god(you.religion))
-            multiplier = max(multiplier, 20);
-
-        hurted = hurted * multiplier / 60;
-
-        if (doEffects)
-        {
-            if (hurted <= 0)
-                canned_msg(MSG_YOU_RESIST);
-            else if (multiplier > 30)
-                mpr("The blast sears you terribly!");
-            else
-                mpr("The blast sears you!");
-
-            if (one_chance_in(3)
-                // delete_mutation() handles MUT_MUTATION_RESISTANCE but not the amulet
-                && (!you.rmut_from_item()
-                    || one_chance_in(10)))
-            {
-                // silver stars only, if this ever changes we may want to give
-                // aux as well
-                delete_mutation(RANDOM_GOOD_MUTATION, source);
-            }
-        }
-        break;
-    }
-
     case BEAM_AIR:
     {
         // Airstrike.
@@ -356,7 +329,7 @@ int check_your_resists(int hurted, beam_type flavour, string source,
     {
         if (you.holiness() == MH_UNDEAD)
         {
-            if (doEffects)
+            if (doEffects && hurted > 0)
             {
                 you.heal(roll_dice(2, 9));
                 mpr("You are bolstered by the flame.");
@@ -377,16 +350,25 @@ int check_your_resists(int hurted, beam_type flavour, string source,
         break;
     }                           // end switch
 
-    if (doEffects)
-        maybe_id_resist(flavour);
-
     return hurted;
 }
 
-void splash_with_acid(int acid_strength, int death_source, bool corrode_items,
+/**
+ * Attempts to apply corrosion to the player and deals acid damage.
+ *
+ * Each full equipment slot gives a chance of applying the corrosion debuff,
+ * and each empty equipment slot increases the amount of acid damage taken.
+ *
+ * @param acid_strength The strength of the acid.
+ * @param death_source The monster index of the acid's source.
+ * @param allow_corrosion Whether to try and apply the corrosion debuff.
+ * @param hurt_msg A message to display when dealing damage.
+ */
+void splash_with_acid(int acid_strength, int death_source, bool allow_corrosion,
                       const char* hurt_msg)
 {
     int dam = 0;
+    bool do_corrosion = false;
     const bool wearing_cloak = player_wearing_slot(EQ_CLOAK);
 
     for (int slot = EQ_MIN_ARMOUR; slot <= EQ_MAX_ARMOUR; slot++)
@@ -400,11 +382,14 @@ void splash_with_acid(int acid_strength, int death_source, bool corrode_items,
             if (!item && slot != EQ_SHIELD)
                 dam++;
 
-            if (item && corrode_items && x_chance_in_y(acid_strength + 1, 20))
-                corrode_item(*item, &you);
+            if (item && allow_corrosion && x_chance_in_y(acid_strength + 1, 30))
+                do_corrosion = true;
         }
     }
 
+    if (do_corrosion)
+        corrode_actor(&you);
+
     // Covers head, hands and feet.
     if (player_equip_unrand(UNRAND_LEAR))
         dam = !wearing_cloak;
@@ -418,234 +403,36 @@ void splash_with_acid(int acid_strength, int death_source, bool corrode_items,
     dam += 2;
     dam = roll_dice(dam, acid_strength);
 
-    const int post_res_dam = dam * player_acid_resist_factor() / 100;
+    const int post_res_dam = resist_adjust_damage(&you, BEAM_ACID,
+                                                  you.res_acid(), dam);
 
     if (post_res_dam > 0)
     {
         mpr(hurt_msg ? hurt_msg : "The acid burns!");
 
         if (post_res_dam < dam)
-        {
             canned_msg(MSG_YOU_RESIST);
-            if (!player_res_acid(false, true))
-                maybe_id_resist(BEAM_ACID);
-        }
 
         ouch(post_res_dam, death_source, KILLED_BY_ACID);
     }
 }
 
-// Helper function for the expose functions below.
-// This currently works because elements only target a single type each.
-static int _get_target_class(beam_type flavour)
+/**
+ * Handle side-effects for exposure to element other than damage.
+ *
+ * @param flavour The beam type.
+ * @param strength The strength, which is interpreted as a number of player turns.
+ * @param slow_cold_blooded If True, the beam_type is BEAM_COLD, and the player
+ *                          is cold-blooded and not cold-resistant, slow the
+ *                          player 50% of the time.
+ */
+void expose_player_to_element(beam_type flavour, int strength, bool slow_cold_blooded)
 {
-    int target_class = OBJ_UNASSIGNED;
+    maybe_melt_player_enchantments(flavour, strength ? strength : 10);
+    qazlal_element_adapt(flavour, strength);
 
-    switch (flavour)
-    {
-    case BEAM_FIRE:
-    case BEAM_LAVA:
-    case BEAM_NAPALM:
-    case BEAM_HELLFIRE:
-        target_class = OBJ_SCROLLS;
-        break;
-
-    case BEAM_COLD:
-    case BEAM_ICE:
-    case BEAM_FRAG:
-        target_class = OBJ_POTIONS;
-        break;
-
-    case BEAM_SPORE:
-    case BEAM_DEVOUR_FOOD:
-        target_class = OBJ_FOOD;
-        break;
-
-    default:
-        break;
-    }
-
-    return target_class;
-}
-
-// XXX: These expose functions could use being reworked into a real system...
-// the usage and implementation is currently very hacky.
-// Handles the destruction of inventory items from the elements.
-static bool _expose_invent_to_element(beam_type flavour, int strength)
-{
-    int num_dest = 0;
-    int total_dest = 0;
-    int jiyva_block = 0;
-
-    const int target_class = _get_target_class(flavour);
-    if (target_class == OBJ_UNASSIGNED)
-        return false;
-
-    // Wisp form semi-melds all of inventory, making it unusable for you,
-    // but also immune to destruction.  No message is needed.
-    if (you.form == TRAN_WISP)
-        return false;
-
-    // Fedhas worshipers are exempt from the food destruction effect
-    // of spores.
-    if (flavour == BEAM_SPORE
-        && you_worship(GOD_FEDHAS))
-    {
-        simple_god_message(" protects your food from the spores.",
-                           GOD_FEDHAS);
-        return false;
-    }
-
-    // Currently we test against each stack (and item in the stack)
-    // independently at strength%... perhaps we don't want that either
-    // because it makes the system very fair and removes the protection
-    // factor of junk (which might be more desirable for game play).
-    for (int i = 0; i < ENDOFPACK; ++i)
-    {
-        if (!you.inv[i].defined())
-            continue;
-
-        if (you.inv[i].base_type == target_class
-            || target_class == OBJ_FOOD
-               && you.inv[i].base_type == OBJ_CORPSES)
-        {
-            // Conservation doesn't help against harpies' devouring food.
-            if (flavour != BEAM_DEVOUR_FOOD
-                && you.conservation() && !one_chance_in(10))
-            {
-                continue;
-            }
-
-            // These stack with conservation; they're supposed to be good.
-            if (target_class == OBJ_SCROLLS
-                && you.mutation[MUT_CONSERVE_SCROLLS]
-                && !one_chance_in(10))
-            {
-                continue;
-            }
-
-            if (target_class == OBJ_SCROLLS
-                && player_equip_unrand(UNRAND_FIRESTARTER)
-                && !one_chance_in(10))
-            {
-                continue;
-            }
-
-            if (target_class == OBJ_POTIONS
-                && you.mutation[MUT_CONSERVE_POTIONS]
-                && !one_chance_in(10))
-            {
-                continue;
-            }
-
-            if (you_worship(GOD_JIYVA) && !player_under_penance()
-                && x_chance_in_y(you.piety, MAX_PIETY))
-            {
-                ++jiyva_block;
-                continue;
-            }
-
-            // Get name and quantity before destruction.
-            const string item_name = you.inv[i].name(DESC_PLAIN);
-            const int quantity = you.inv[i].quantity;
-            num_dest = 0;
-
-            // Loop through all items in the stack.
-            for (int j = 0; j < you.inv[i].quantity; ++j)
-            {
-                if (bernoulli(strength, 0.01))
-                {
-                    num_dest++;
-
-                    if (i == you.equip[EQ_WEAPON])
-                        you.wield_change = true;
-
-                    if (dec_inv_item_quantity(i, 1))
-                        break;
-                    else if (is_blood_potion(you.inv[i]))
-                        remove_oldest_blood_potion(you.inv[i]);
-                }
-            }
-
-            // Name destroyed items.
-            // TODO: Combine messages using a vector.
-            if (num_dest > 0)
-            {
-                switch (target_class)
-                {
-                case OBJ_SCROLLS:
-                    mprf("%s %s catch%s fire!",
-                         part_stack_string(num_dest, quantity).c_str(),
-                         item_name.c_str(),
-                         (num_dest == 1) ? "es" : "");
-                    break;
-
-                case OBJ_POTIONS:
-                    mprf("%s %s freeze%s and shatter%s!",
-                         part_stack_string(num_dest, quantity).c_str(),
-                         item_name.c_str(),
-                         (num_dest == 1) ? "s" : "",
-                         (num_dest == 1) ? "s" : "");
-                    break;
-
-                case OBJ_FOOD:
-                    mprf("%s %s %s %s!",
-                         part_stack_string(num_dest, quantity).c_str(),
-                         item_name.c_str(),
-                         (num_dest == 1) ? "is" : "are",
-                         (flavour == BEAM_DEVOUR_FOOD) ?
-                             "devoured" : "covered with spores");
-                    break;
-
-                default:
-                    mprf("%s %s %s destroyed!",
-                         part_stack_string(num_dest, quantity).c_str(),
-                         item_name.c_str(),
-                         (num_dest == 1) ? "is" : "are");
-                    break;
-                }
-
-                total_dest += num_dest;
-            }
-        }
-    }
-
-    if (jiyva_block)
-    {
-        simple_god_message(
-            make_stringf(" shields %s delectables from destruction.",
-                         (total_dest > 0) ? "some of your" : "your").c_str(),
-            GOD_JIYVA);
-    }
-
-    if (!total_dest)
-        return false;
-
-    // Message handled elsewhere.
-    if (flavour == BEAM_DEVOUR_FOOD)
-        return true;
-
-    xom_is_stimulated((num_dest > 1) ? 25 : 12);
-
-    return true;
-}
-
-// Handle side-effects for exposure to element other than damage.  This
-// function exists because some code calculates its own damage instead
-// of using check_your_resists() and we want to isolate all the special
-// code they keep having to do... namely condensation shield checks,
-// you really can't expect this function to even be called for much
-// else.
-//
-// This function now calls _expose_invent_to_element() if strength > 0.
-//
-// XXX: This function is far from perfect and a work in progress.
-bool expose_player_to_element(beam_type flavour, int strength,
-                              bool damage_inventory, bool slow_dracs)
-{
-    _maybe_melt_player_enchantments(flavour, strength ? strength : 10);
-
-    if (flavour == BEAM_COLD && slow_dracs && player_genus(GENPC_DRACONIAN)
+    if (flavour == BEAM_COLD && slow_cold_blooded
+        && player_mutation_level(MUT_COLD_BLOODED)
         && you.res_cold() <= 0 && coinflip())
     {
         you.slow_down(0, strength);
@@ -655,14 +442,9 @@ bool expose_player_to_element(beam_type flavour, int strength,
     {
         mprf(MSGCH_WARN, "The flames go out!");
         you.duration[DUR_LIQUID_FLAMES] = 0;
-        you.props.erase("napalmer");
-        you.props.erase("napalm_aux");
+        you.props.erase("sticky_flame_source");
+        you.props.erase("sticky_flame_aux");
     }
-
-    if (strength <= 0 || !damage_inventory)
-        return false;
-
-    return _expose_invent_to_element(flavour, strength);
 }
 
 static void _lose_level_abilities()
@@ -720,7 +502,16 @@ void lose_level(int death_source, const char *aux)
     ouch(0, death_source, KILLED_BY_DRAINING, aux);
 }
 
-bool drain_exp(bool announce_full, int power, bool ignore_protection)
+/**
+ * Drain the player.
+ *
+ * @param power             The amount by which to drain the player.
+ * @param announce_full     Whether to print messages even when fully resisting
+ *                          the drain.
+ * @param ignore_protection Whether to ignore the player's rN.
+ * @return                  Whether draining occurred.
+ */
+bool drain_player(int power, bool announce_full, bool ignore_protection)
 {
     const int protection = player_prot_life();
 
@@ -809,7 +600,7 @@ static void _xom_checks_damage(kill_method_type death_type,
             return;
         }
 
-        int leveldif = mons->hit_dice - you.experience_level;
+        int leveldif = mons->get_experience_level() - you.experience_level;
         if (leveldif == 0)
             leveldif = 1;
 
@@ -998,7 +789,7 @@ static void _wizard_restore_life()
     if (you.hp_max <= 0)
         unrot_hp(9999);
     while (you.hp_max <= 0)
-        you.hp_max_perm++, calc_hp();
+        you.hp_max_adj_perm++, calc_hp();
     if (you.hp <= 0)
         set_hp(you.hp_max);
 }
@@ -1037,13 +828,20 @@ void ouch(int dam, int death_source, kill_method_type death_type,
         dam = div_rand_round(dam * (10 - min(degree, 5)), 10);
     }
 
-    if (you.species == SP_DEEP_DWARF && dam != INSTANT_DEATH
-                                     && death_type != KILLED_BY_POISON)
+    if ((you.duration[DUR_FORTITUDE] || you.species == SP_DEEP_DWARF)
+         && dam != INSTANT_DEATH && death_type != KILLED_BY_POISON)
     {
-        // Deep Dwarves get to shave any hp loss.
-        int shave = 1 + random2(2 + random2(1 + you.experience_level / 3));
-        dprf("HP shaved: %d.", shave);
-        dam -= shave;
+        if (you.species == SP_DEEP_DWARF)
+        {
+            // Deep Dwarves get to shave any hp loss.
+            int shave = 1 + random2(2 + random2(1 + you.experience_level / 3));
+            dprf("HP shaved: %d.", shave);
+            dam -= shave;
+        }
+
+        if (you.duration[DUR_FORTITUDE])
+            dam -= random2(10);
+
         if (dam <= 0)
         {
             // Rotting and costs may lower hp directly.
@@ -1153,7 +951,7 @@ void ouch(int dam, int death_source, kill_method_type death_type,
             _maybe_fog(dam);
             _powered_by_pain(dam);
             if (drain_amount > 0)
-                drain_exp(true, drain_amount, true);
+                drain_player(drain_amount, true, true);
         }
         if (you.hp > 0)
           return;
@@ -1291,7 +1089,7 @@ void ouch(int dam, int death_source, kill_method_type death_type,
     if (!non_death && !crawl_state.game_is_tutorial() && !you.wizard)
         save_ghost();
 
-    _end_game(se);
+    end_game(se);
 }
 
 string morgue_name(string char_name, time_t when_crawl_got_even)
@@ -1305,176 +1103,6 @@ string morgue_name(string char_name, time_t when_crawl_got_even)
     return name;
 }
 
-// Delete save files on game end.
-static void _delete_files()
-{
-    crawl_state.need_save = false;
-    you.save->unlink();
-    delete you.save;
-    you.save = 0;
-}
-
-void screen_end_game(string text)
-{
-    crawl_state.cancel_cmd_all();
-    _delete_files();
-
-    if (!text.empty())
-    {
-        clrscr();
-        linebreak_string(text, get_number_of_cols());
-        display_tagged_block(text);
-
-        if (!crawl_state.seen_hups)
-            get_ch();
-    }
-
-    game_ended();
-}
-
-void _end_game(scorefile_entry &se)
-{
-    for (int i = 0; i < ENDOFPACK; i++)
-        if (you.inv[i].defined() && item_type_unknown(you.inv[i]))
-            add_inscription(you.inv[i], "unknown");
-
-    for (int i = 0; i < ENDOFPACK; i++)
-    {
-        if (!you.inv[i].defined())
-            continue;
-        set_ident_flags(you.inv[i], ISFLAG_IDENT_MASK);
-        set_ident_type(you.inv[i], ID_KNOWN_TYPE);
-    }
-
-    _delete_files();
-
-    // death message
-    if (se.get_death_type() != KILLED_BY_LEAVING
-        && se.get_death_type() != KILLED_BY_QUITTING
-        && se.get_death_type() != KILLED_BY_WINNING)
-    {
-        canned_msg(MSG_YOU_DIE);
-        xom_death_message((kill_method_type) se.get_death_type());
-
-        switch (you.religion)
-        {
-        case GOD_FEDHAS:
-            simple_god_message(" appreciates your contribution to the "
-                               "ecosystem.");
-            break;
-
-        case GOD_NEMELEX_XOBEH:
-            nemelex_death_message();
-            break;
-
-        case GOD_KIKUBAAQUDGHA:
-        {
-            const mon_holy_type holi = you.holiness();
-
-            if (holi == MH_NONLIVING || holi == MH_UNDEAD)
-            {
-                simple_god_message(" rasps: \"You have failed me! "
-                                   "Welcome... oblivion!\"");
-            }
-            else
-            {
-                simple_god_message(" rasps: \"You have failed me! "
-                                   "Welcome... death!\"");
-            }
-            break;
-        }
-
-        case GOD_YREDELEMNUL:
-            if (you.is_undead)
-                simple_god_message(" claims you as an undead slave.");
-            else if (se.get_death_type() != KILLED_BY_DISINT
-                     && se.get_death_type() != KILLED_BY_LAVA)
-            {
-                mprf(MSGCH_GOD, "Your body rises from the dead as a mindless zombie.");
-            }
-            // No message if you're not undead and your corpse is lost.
-            break;
-
-        default:
-            break;
-        }
-
-        flush_prev_message();
-        viewwindow(); // don't do for leaving/winning characters
-
-        if (crawl_state.game_is_hints())
-            hints_death_screen();
-    }
-
-    string fname = morgue_name(you.your_name, se.get_death_time());
-    if (!dump_char(fname, true, true, &se))
-    {
-        mpr("Char dump unsuccessful! Sorry about that.");
-        if (!crawl_state.seen_hups)
-            more();
-        clrscr();
-    }
-#ifdef USE_TILE_WEB
-    else
-        tiles.send_dump_info("morgue", fname);
-#endif
-
-#if defined(DGL_WHEREIS) || defined(USE_TILE_WEB)
-    string reason = se.get_death_type() == KILLED_BY_QUITTING? "quit" :
-                    se.get_death_type() == KILLED_BY_WINNING ? "won"  :
-                    se.get_death_type() == KILLED_BY_LEAVING ? "bailed out"
-                                                             : "dead";
-#ifdef DGL_WHEREIS
-    whereis_record(reason.c_str());
-#endif
-#endif
-
-    if (!crawl_state.seen_hups)
-        more();
-
-    if (!crawl_state.disables[DIS_CONFIRMATIONS])
-        get_invent(OSEL_ANY);
-    textcolor(LIGHTGREY);
-
-    // Prompt for saving macros.
-    if (crawl_state.unsaved_macros && yesno("Save macros?", true, 'n'))
-        macro_save();
-
-    clrscr();
-    cprintf("Goodbye, %s.", you.your_name.c_str());
-    cprintf("\n\n    "); // Space padding where # would go in list format
-
-    string hiscore = hiscores_format_single_long(se, true);
-
-    const int lines = count_occurrences(hiscore, "\n") + 1;
-
-    cprintf("%s", hiscore.c_str());
-
-    cprintf("\nBest Crawlers - %s\n",
-            crawl_state.game_type_name().c_str());
-
-    // "- 5" gives us an extra line in case the description wraps on a line.
-    hiscores_print_list(get_number_of_lines() - lines - 5);
-
-#ifndef DGAMELAUNCH
-    cprintf("\nYou can find your morgue file in the '%s' directory.",
-            morgue_directory().c_str());
-#endif
-
-    // just to pause, actual value returned does not matter {dlb}
-    if (!crawl_state.seen_hups && !crawl_state.disables[DIS_CONFIRMATIONS])
-        get_ch();
-
-    if (se.get_death_type() == KILLED_BY_WINNING)
-        crawl_state.last_game_won = true;
-
-#ifdef USE_TILE_WEB
-    tiles.send_exit_reason(reason, hiscore);
-#endif
-
-    game_ended();
-}
-
 int actor_to_death_source(const actor* agent)
 {
     if (agent->is_player())
