@@ -68,10 +68,11 @@ enum kill_method_type
     NUM_KILLBY
 };
 
+void maybe_melt_player_enchantments(beam_type flavour, int damage);
 int check_your_resists(int hurted, beam_type flavour, string source,
                        bolt *beam = 0, bool doEffects = true);
 void splash_with_acid(int acid_strength, int death_source,
-                      bool corrode_items = true, const char* hurt_msg = nullptr);
+                      bool allow_corrosion = true, const char* hurt_msg = nullptr);
 
 class actor;
 int actor_to_death_source(const actor* agent);
@@ -84,13 +85,11 @@ void ouch(int dam, int death_source, kill_method_type death_type,
           const char *death_source_name = NULL, bool attacker_effects = true);
 
 void lose_level(int death_source, const char* aux);
-bool drain_exp(bool announce_full = true, int power = 25,
-               bool ignore_protection = false);
+bool drain_player(int power = 25, bool announce_full = true,
+                  bool ignore_protection = false);
 
-bool expose_player_to_element(beam_type flavour, int strength = 0,
-                              bool damage_inventory = true,
-                              bool slow_dracs = true);
+void expose_player_to_element(beam_type flavour, int strength = 0,
+                              bool slow_cold_blooded = true);
 
-void screen_end_game(string text);
 int timescale_damage(const actor *act, int damage);
 #endif
