@@ -27,9 +27,12 @@
 #include "files.h"
 #include "format.h"
 #include "godabil.h"
+#include "godpassive.h"
 #include "initfile.h"
 #include "itemname.h"
+#include "itemprop.h"
 #include "items.h"
+#include "jobs.h"
 #include "lang-fake.h"
 #include "libutil.h"
 #include "menu.h"
@@ -38,17 +41,19 @@
 #include "mon-info.h"
 #include "mon-util.h"
 #include "mutation.h"
-#include "jobs.h"
+#include "notes.h"
 #include "ouch.h"
 #include "player.h"
+#include "prompt.h"
 #include "religion.h"
 #include "skills2.h"
 #include "state.h"
 #include "status.h"
-#include "stuff.h"
+#include "stringutil.h"
 #include "throw.h"
 #include "transform.h"
 #include "travel.h"
+#include "view.h"
 #include "viewchar.h"
 #include "viewgeom.h"
 #include "showsymb.h"
@@ -327,7 +332,11 @@ class colour_bar
                && you.num_turns >= m_request_redraw_after;
     }
 
+#if TAG_MAJOR_VERSION == 34
     void draw(int ox, int oy, int val, int max_val, bool temp = false, int sub_val = 0)
+#else
+    void draw(int ox, int oy, int val, int max_val, int sub_val = 0)
+#endif
     {
         ASSERT(val <= max_val);
         if (max_val <= 0)
@@ -335,8 +344,9 @@ class colour_bar
             m_old_disp = -1;
             return;
         }
-
+#if TAG_MAJOR_VERSION == 34
         const colour_t temp_colour = temperature_colour(temperature());
+#endif
         const int width = crawl_view.hudsz.x - (ox - 1);
         const int sub_disp = (width * val / max_val);
         int disp  = width * max(0, val - sub_val) / max_val;
@@ -357,7 +367,13 @@ class colour_bar
             textcolor(BLACK + m_empty * 16);
 
             if (cx < disp)
+            {
+#if TAG_MAJOR_VERSION == 34
                 textcolor(BLACK + (temp) ? temp_colour * 16 : m_default * 16);
+#else
+                textcolor(BLACK + m_default * 16);
+#endif
+            }
             else if (cx < sub_disp)
                 textcolor(BLACK + YELLOW * 16);
             else if (old_disp >= sub_disp && cx < old_disp)
@@ -366,7 +382,11 @@ class colour_bar
 #else
             if (cx < disp && cx < old_disp)
             {
+#if TAG_MAJOR_VERSION == 34
                 textcolor((temp) ? temp_colour : m_default);
+#else
+                textcolor(m_default);
+#endif
                 putwch('=');
             }
             else if (cx < disp)
@@ -472,6 +492,39 @@ colour_bar Temp_Bar(RED, LIGHTRED, LIGHTBLUE, DARKGREY);
 // Status display
 // ----------------------------------------------------------------------
 
+static bool _boosted_hp()
+{
+    return you.duration[DUR_DIVINE_VIGOUR]
+           || you.berserk();
+}
+
+static bool _boosted_mp()
+{
+    return you.duration[DUR_DIVINE_VIGOUR];
+}
+
+static bool _boosted_ac()
+{
+    return you.duration[DUR_ICY_ARMOUR]
+           || player_stoneskin()
+           || player_icemail_armour_class()
+           || you.duration[DUR_QAZLAL_AC];
+}
+
+static bool _boosted_ev()
+{
+    return you.duration[DUR_PHASE_SHIFT]
+           || you.duration[DUR_AGILITY];
+}
+
+static bool _boosted_sh()
+{
+    return you.duration[DUR_CONDENSATION_SHIELD]
+           || you.duration[DUR_MAGIC_SHIELD]
+           || you.duration[DUR_DIVINE_SHIELD]
+           || qazlal_sh_boost() > 0;
+}
+
 #ifdef DGL_SIMPLE_MESSAGING
 void update_message_status()
 {
@@ -494,15 +547,17 @@ void update_turn_count()
 {
     // Don't update turn counter when running/resting/traveling to
     // prevent pointless screen updates.
-    if (!Options.show_gold_turns
-        || you.running > 0
+    if (you.running > 0
         || you.running < 0 && Options.travel_delay == -1)
     {
         return;
     }
 
     const int yhack = crawl_state.game_is_zotdef()
-                    + (you.species == SP_LAVA_ORC);
+#if TAG_MAJOR_VERSION == 34
+                    + (you.species == SP_LAVA_ORC)
+#endif
+                    ;
     CGOTOXY(19+6, 9 + yhack, GOTO_STAT);
 
     // Show the turn count starting from 1. You can still quit on turn 0.
@@ -530,6 +585,7 @@ static int _count_digits(int val)
     return 1;
 }
 
+#if TAG_MAJOR_VERSION == 34
 static void _print_stats_temperature(int x, int y)
 {
     cgotoxy(x, y, GOTO_STAT);
@@ -538,6 +594,7 @@ static void _print_stats_temperature(int x, int y)
 
     Temp_Bar.draw(19, y, temperature(), TEMP_MAX, true);
 }
+#endif
 
 static void _print_stats_mp(int x, int y)
 {
@@ -549,7 +606,7 @@ static void _print_stats_mp(int x, int y)
     // Calculate colour
     short mp_colour = HUD_VALUE_COLOUR;
 
-    const bool boosted = you.duration[DUR_DIVINE_VIGOUR];
+    const bool boosted = _boosted_mp();
 
     if (boosted)
         mp_colour = LIGHTBLUE;
@@ -645,8 +702,7 @@ static void _print_stats_hp(int x, int y)
     // Calculate colour
     short hp_colour = HUD_VALUE_COLOUR;
 
-    const bool boosted = you.duration[DUR_DIVINE_VIGOUR]
-                         || you.berserk();
+    const bool boosted = _boosted_hp();
 
     if (boosted)
         hp_colour = LIGHTBLUE;
@@ -700,8 +756,10 @@ static void _print_stats_hp(int x, int y)
     if (you.species == SP_DJINNI)
         EP_Bar.draw(19, y, you.hp, you.hp_max);
     else
-#endif
         HP_Bar.draw(19, y, you.hp, you.hp_max, false, you.hp - max(0, poison_survival()));
+#else
+        HP_Bar.draw(19, y, you.hp, you.hp_max, you.hp - max(0, poison_survival()));
+#endif
 }
 
 static short _get_stat_colour(stat_type stat)
@@ -718,6 +776,7 @@ static short _get_stat_colour(stat_type stat)
     if (you.duration[DUR_DIVINE_STAMINA]
         || stat == STAT_STR && you.duration[DUR_MIGHT]
         || stat == STAT_STR && you.duration[DUR_BERSERK]
+        || stat == STAT_STR && you.duration[DUR_FORTITUDE]
         || stat == STAT_INT && you.duration[DUR_BRILLIANCE]
         || stat == STAT_DEX && you.duration[DUR_AGILITY])
     {
@@ -748,8 +807,10 @@ static void _print_stats_ac(int x, int y)
 {
     // AC:
     CGOTOXY(x+4, y, GOTO_STAT);
-    if (you.duration[DUR_ICY_ARMOUR] || player_stoneskin() || player_icemail_armour_class())
+    if (_boosted_ac())
         textcolor(LIGHTBLUE);
+    else if (you.duration[DUR_CORROSION])
+        textcolor(RED);
     else
         textcolor(HUD_VALUE_COLOUR);
     string ac = make_stringf("%2d ", you.armour_class());
@@ -757,21 +818,18 @@ static void _print_stats_ac(int x, int y)
     if (you.wizard)
         ac += make_stringf("(%d%%) ", you.gdr_perc());
 #endif
-    CPRINTF("%s", ac.c_str());
+    CPRINTF("%-12s", ac.c_str());
 
     // SH: (two lines lower)
     CGOTOXY(x+4, y+2, GOTO_STAT);
-    if (you.incapacitated() && player_wearing_slot(EQ_SHIELD))
+    if (you.incapacitated() && you.shielded())
         textcolor(RED);
-    else if (you.duration[DUR_CONDENSATION_SHIELD]
-             || you.duration[DUR_MAGIC_SHIELD]
-             || you.duration[DUR_DIVINE_SHIELD])
-    {
+    else if (_boosted_sh())
         textcolor(LIGHTBLUE);
-    }
     else
         textcolor(HUD_VALUE_COLOUR);
-    CPRINTF("%2d ", player_shield_class());
+    string sh = make_stringf("%2d ", player_displayed_shield_class());
+    CPRINTF("%-12s", sh.c_str());
 }
 
 static void _print_stats_ev(int x, int y)
@@ -779,76 +837,85 @@ static void _print_stats_ev(int x, int y)
     CGOTOXY(x+4, y, GOTO_STAT);
     textcolor(you.duration[DUR_PETRIFYING] || you.duration[DUR_GRASPING_ROOTS]
               || you.cannot_move() ? RED :
-              you.duration[DUR_PHASE_SHIFT] || you.duration[DUR_AGILITY]
+              _boosted_ev()
               ? LIGHTBLUE : HUD_VALUE_COLOUR);
     CPRINTF("%2d ", player_evasion());
 }
 
-static void _print_stats_wp(int y)
+/**
+ * Get the appropriate colour for the UI text describing the player's weapon.
+ * (Or hands/ice fists/etc, as appropriate.)
+ *
+ * @return     A colour enum for the player's weapon.
+ */
+static int _wpn_name_colour()
 {
-    int col;
-    string text;
+    if (you.duration[DUR_CORROSION])
+        return RED;
+
     if (you.weapon())
     {
         const item_def& wpn = *you.weapon();
 
         const string prefix = item_prefix(wpn);
-        const int prefcol = menu_colour(wpn.name(DESC_INVENTORY), prefix);
+        const int prefcol = menu_colour(wpn.name(DESC_INVENTORY), prefix, "stats");
         if (prefcol != -1)
-            col = prefcol;
-        else
-            col = LIGHTGREY;
-
-        text = wpn.name(DESC_INVENTORY, true, false, true);
+            return prefcol;
+        return LIGHTGREY;
     }
-    else
+
+    switch (you.form)
     {
-        const string prefix = "-) ";
-        col = LIGHTGREY;
-        switch (you.form)
-        {
         case TRAN_SPIDER:
-            col = LIGHTGREEN;
-            break;
+            return LIGHTGREEN;
+
         case TRAN_BLADE_HANDS:
-            col = RED;
-            break;
-        case TRAN_STATUE:
-        case TRAN_WISP:
-            col = LIGHTGREY;
-            break;
+            return RED;
+
         case TRAN_ICE_BEAST:
-            col = WHITE;
-            break;
+            return WHITE;
+
         case TRAN_DRAGON:
-            col = GREEN;
-            break;
+            return GREEN;
+
         case TRAN_LICH:
         case TRAN_SHADOW:
-            col = MAGENTA;
-            break;
+            return MAGENTA;
+
+        case TRAN_FUNGUS:
+        case TRAN_TREE:
+            return BROWN;
+
+        case TRAN_STATUE:
+        case TRAN_WISP:
         case TRAN_BAT:
         case TRAN_PIG:
         case TRAN_PORCUPINE:
-            col = LIGHTGREY;
-            break;
-        case TRAN_FUNGUS:
-        case TRAN_TREE:
-            col = BROWN;
-            break;
-        case TRAN_JELLY:
-            col = LIGHTRED;
-            break;
         default:
-            break;
-        }
-        text = prefix + you.unarmed_attack_name();
+            return LIGHTGREY;
     }
+}
+
+/**
+ * Print a description of the player's weapon (or lack thereof) to the UI.
+ *
+ * @param y     The y-coordinate to print the description at.
+ */
+static void _print_stats_wp(int y)
+{
+    string text;
+    if (you.weapon())
+    {
+        const item_def& wpn = *you.weapon();
+        text = wpn.name(DESC_INVENTORY, true, false, true);
+    }
+    else
+        text = "-) " + you.unarmed_attack_name();
 
     CGOTOXY(1, y, GOTO_STAT);
     textcolor(Options.status_caption_colour);
     CPRINTF("Wp: ");
-    textcolor(col);
+    textcolor(_wpn_name_colour());
 #ifdef USE_TILE_LOCAL
     int w = crawl_view.hudsz.x - (tiles.is_using_small_layout()?0:4);
     CPRINTF("%s", chop_string(text, w).c_str());
@@ -870,7 +937,7 @@ static void _print_stats_qv(int y)
         const item_def& quiver = you.inv[q];
         const string prefix = item_prefix(quiver);
         const int prefcol =
-            menu_colour(quiver.name(DESC_INVENTORY), prefix);
+            menu_colour(quiver.name(DESC_INVENTORY), prefix, "stats");
         if (prefcol != -1)
             col = prefcol;
         else
@@ -914,6 +981,17 @@ struct status_light
     string text;
 };
 
+static void _add_status_light_to_out(int i, vector<status_light>& out)
+{
+    status_info inf;
+
+    if (fill_status_info(i, &inf) && !inf.light_text.empty())
+    {
+        status_light sl(inf.light_colour, inf.light_text);
+        out.push_back(sl);
+    }
+}
+
 // The colour scheme for these flags is currently:
 //
 // - yellow, "orange", red      for bad conditions
@@ -922,7 +1000,7 @@ struct status_light
 // - blue, light blue           for good enchantments
 // - magenta, light magenta     for "better" enchantments (deflect, fly)
 //
-// Prints burden, hunger,
+// Prints hunger,
 // pray, holy, teleport, regen, fly/lev, invis, silence,
 //   conf. touch, sage
 // confused, mesmerised, fire, poison, disease, rot, held, glow, swift,
@@ -949,111 +1027,43 @@ static void _get_status_lights(vector<status_light>& out)
     }
 #endif
 
-    const int statuses[] =
+    // We used to have to hardcode every status, now we just hardcode the
+    // statuses important enough to appear first. (Rightmost)
+    const unsigned int important_statuses[] =
     {
         STATUS_STR_ZERO, STATUS_INT_ZERO, STATUS_DEX_ZERO,
-        STATUS_BURDEN,
         STATUS_HUNGER,
+        DUR_PARALYSIS,
+        DUR_CONF,
         DUR_PETRIFYING,
         DUR_PETRIFIED,
-        DUR_PARALYSIS,
-        DUR_JELLY_PRAYER,
-        DUR_TELEPORT,
-        DUR_DEATHS_DOOR,
-        DUR_QUAD_DAMAGE,
-        DUR_ANTIMAGIC,
-        STATUS_MISSILES,
-        STATUS_REGENERATION,
         DUR_BERSERK,
-        STATUS_DIG,
-        DUR_RESISTANCE,
-        STATUS_AIRBORNE,
-        STATUS_INVISIBLE,
-        DUR_CONTROL_TELEPORT,
-        DUR_DISJUNCTION,
-        DUR_SILENCE,
-        DUR_CONFUSING_TOUCH,
-        STATUS_SAGE,
-        DUR_FIRE_SHIELD,
-        DUR_SLIMIFY,
-        DUR_SURE_BLADE,
-        DUR_CONF,
-        DUR_LOWERED_MR,
-        STATUS_BEHELD,
-        DUR_LIQUID_FLAMES,
-        DUR_POISONING,
-        STATUS_SICK,
-        STATUS_ROT,
-        STATUS_NET,
-        STATUS_CONTAMINATION,
-        DUR_SWIFTNESS,
+        DUR_TELEPORT,
+        DUR_HASTE,
+        DUR_SLOW,
         STATUS_SPEED,
-        DUR_DEATH_CHANNEL,
-        DUR_TELEPATHY,
-        DUR_STEALTH,
-        DUR_BREATH_WEAPON,
+        DUR_DEATHS_DOOR,
         DUR_EXHAUSTED,
-        DUR_POWERED_BY_DEATH,
-        DUR_TRANSFORMATION,
-        DUR_AFRAID,
-        DUR_MIRROR_DAMAGE,
-        DUR_SCRYING,
-        STATUS_CLINGING,
-        DUR_TORNADO,
-        DUR_LIQUEFYING,
-        DUR_HEROISM,
-        DUR_FINESSE,
-        DUR_LIFESAVING,
-        DUR_DARKNESS,
-        STATUS_FIREBALL,
-        DUR_SHROUD_OF_GOLUBRIA,
-        DUR_TORNADO_COOLDOWN,
-        DUR_CORONA,
-        STATUS_UMBRA,
-        STATUS_CONSTRICTED,
-        DUR_DIVINE_STAMINA,
-        STATUS_AUGMENTED,
-        STATUS_TERRAIN,
-        STATUS_SILENCE,
-        STATUS_NO_CTELE,
-        DUR_SENTINEL_MARK,
-        STATUS_RECALL,
-        STATUS_LIQUEFIED,
-        DUR_WATER_HOLD,
-        DUR_FLAYED,
-        DUR_RETCHING,
-        DUR_WEAK,
-        DUR_DIMENSION_ANCHOR,
-        STATUS_BEOGH,
-        DUR_INFUSION,
-        DUR_SONG_OF_SLAYING,
-        STATUS_DRAINED,
-        DUR_TOXIC_RADIANCE,
-        STATUS_RAY,
-        DUR_RECITE,
-        DUR_GRASPING_ROOTS,
-        DUR_FIRE_VULN,
-        DUR_FROZEN,
-        DUR_SAP_MAGIC,
-        STATUS_MAGIC_SAPPED,
-        STATUS_ELIXIR,
-        DUR_BARBS,
-        DUR_POISON_VULN,
-        DUR_PORTAL_PROJECTILE,
-        DUR_FORESTED,
-        DUR_DRAGON_CALL,
-        DUR_DRAGON_CALL_COOLDOWN,
-        DUR_ABJURATION_AURA,
+        DUR_QUAD_DAMAGE,
     };
 
-    status_info inf;
-    for (unsigned i = 0; i < ARRAYSZ(statuses); ++i)
+    for (unsigned i = 0; i < ARRAYSZ(important_statuses) ; ++i)
+        _add_status_light_to_out(important_statuses[i], out);
+
+    for (unsigned status = 0; status <= STATUS_LAST_STATUS ; ++status)
     {
-        if (fill_status_info(statuses[i], &inf) && !inf.light_text.empty())
+        bool cancel = false;
+
+        for (unsigned i = 0; i < ARRAYSZ(important_statuses) ; ++i)
         {
-            status_light sl(inf.light_colour, inf.light_text);
-            out.push_back(sl);
+            if (important_statuses[i] == status)
+                cancel = true;
         }
+
+        if (cancel)
+            continue;
+
+        _add_status_light_to_out(status, out);
     }
 }
 
@@ -1249,26 +1259,36 @@ static void _redraw_title(const string &your_name, const string &job_name)
     textcolor(LIGHTGREY);
 }
 
-void print_stats(void)
+void print_stats()
 {
+#if TAG_MAJOR_VERSION == 34
     int temp = (you.species == SP_LAVA_ORC) ? 1 : 0;
     int temp_pos = 5;
     int ac_pos = temp_pos + temp;
     int ev_pos = temp_pos + temp + 1;
+#else
+    int ac_pos = 5;
+    int ev_pos = ac_pos + 1;
+#endif
 
     cursor_control coff(false);
     textcolor(LIGHTGREY);
 
-    // Displayed evasion is now tied to dex.
-    if (you.redraw_stats[STAT_DEX])
+    // Displayed evasion is tied to dex/str.
+    if (you.redraw_stats[STAT_DEX]
+        || you.redraw_stats[STAT_STR])
+    {
         you.redraw_evasion = true;
+    }
 
     if (HP_Bar.wants_redraw())
         you.redraw_hit_points = true;
     if (MP_Bar.wants_redraw())
         you.redraw_magic_points = true;
+#if TAG_MAJOR_VERSION == 34
     if (Temp_Bar.wants_redraw() && you.species == SP_LAVA_ORC)
         you.redraw_temperature = true;
+#endif
 
     // Poison display depends on regen rate, so should be redrawn every turn.
     if (you.duration[DUR_POISONING])
@@ -1290,19 +1310,29 @@ void print_stats(void)
     if (you.redraw_magic_points) { you.redraw_magic_points = false; _print_stats_mp (1, 4); }
 #if TAG_MAJOR_VERSION == 34
     _print_stats_contam(1, 4);
-#endif
     if (you.redraw_temperature)  { you.redraw_temperature = false;  _print_stats_temperature (1, temp_pos); }
+#endif
     if (you.redraw_armour_class) { you.redraw_armour_class = false; _print_stats_ac (1, ac_pos); }
     if (you.redraw_evasion)      { you.redraw_evasion = false;      _print_stats_ev (1, ev_pos); }
 
     for (int i = 0; i < NUM_STATS; ++i)
         if (you.redraw_stats[i])
+        {
+#if TAG_MAJOR_VERSION == 34
             _print_stat(static_cast<stat_type>(i), 19, 5 + i + temp);
+#else
+            _print_stat(static_cast<stat_type>(i), 19, 5 + i);
+#endif
+        }
     you.redraw_stats.init(false);
 
     if (you.redraw_experience)
     {
+#if TAG_MAJOR_VERSION == 34
         CGOTOXY(1, 8 + temp, GOTO_STAT);
+#else
+        CGOTOXY(1, 8, GOTO_STAT);
+#endif
         textcolor(Options.status_caption_colour);
         CPRINTF("XL: ");
         textcolor(HUD_VALUE_COLOUR);
@@ -1318,7 +1348,11 @@ void print_stats(void)
         }
         if (crawl_state.game_is_zotdef())
         {
+#if TAG_MAJOR_VERSION == 34
             CGOTOXY(1, 9 + temp, GOTO_STAT);
+#else
+            CGOTOXY(1, 9, GOTO_STAT);
+#endif
             textcolor(Options.status_caption_colour);
             CPRINTF("ZP: ");
             textcolor(HUD_VALUE_COLOUR);
@@ -1327,13 +1361,15 @@ void print_stats(void)
         you.redraw_experience = false;
     }
 
+#if TAG_MAJOR_VERSION == 34
     int yhack = crawl_state.game_is_zotdef() + temp;
-
-    // If Options.show_gold_turns, line 9 is Gold and Turns
-#ifdef USE_TILE_LOCAL
-    if (Options.show_gold_turns && !tiles.is_using_small_layout())
 #else
-    if (Options.show_gold_turns)
+    int yhack = crawl_state.game_is_zotdef();
+#endif
+
+    // Line 9 is Gold and Turns
+#ifdef USE_TILE_LOCAL
+    if (!tiles.is_using_small_layout())
 #endif
     {
         // Increase y-value for all following lines.
@@ -1404,8 +1440,10 @@ static string _level_description_string_hud()
 void print_stats_level()
 {
     int ypos = 8;
+#if TAG_MAJOR_VERSION == 34
     if (you.species == SP_LAVA_ORC)
         ypos++;
+#endif
     cgotoxy(19, ypos, GOTO_STAT);
     textcolor(HUD_CAPTION_COLOUR);
     CPRINTF("Place: ");
@@ -1418,19 +1456,27 @@ void print_stats_level()
     clear_to_end_of_line();
 }
 
-void draw_border(void)
+void draw_border()
 {
     textcolor(HUD_CAPTION_COLOUR);
     clrscr();
 
     textcolor(Options.status_caption_colour);
 
+#if TAG_MAJOR_VERSION == 34
     int temp = (you.species == SP_LAVA_ORC) ? 1 : 0;
+#endif
 //    int hp_pos = 3;
     int mp_pos = 4;
+#if TAG_MAJOR_VERSION == 34
     int ac_pos = 5 + temp;
     int ev_pos = 6 + temp;
     int sh_pos = 7 + temp;
+#else
+    int ac_pos = 5;
+    int ev_pos = 6;
+    int sh_pos = 7;
+#endif
     int str_pos = ac_pos;
     int int_pos = ev_pos;
     int dex_pos = sh_pos;
@@ -1451,16 +1497,73 @@ void draw_border(void)
     CGOTOXY(19, int_pos, GOTO_STAT); CPRINTF("Int:");
     CGOTOXY(19, dex_pos, GOTO_STAT); CPRINTF("Dex:");
 
-    if (Options.show_gold_turns)
-    {
-        int yhack = crawl_state.game_is_zotdef() + temp;
-        CGOTOXY(1, 9 + yhack, GOTO_STAT); CPRINTF("Gold:");
-        CGOTOXY(19, 9 + yhack, GOTO_STAT);
-        CPRINTF(Options.show_game_turns ? "Time:" : "Turn:");
-    }
+#if TAG_MAJOR_VERSION == 34
+    int yhack = crawl_state.game_is_zotdef() + temp;
+#else
+    int yhack = crawl_state.game_is_zotdef();
+#endif
+    CGOTOXY(1, 9 + yhack, GOTO_STAT); CPRINTF("Gold:");
+    CGOTOXY(19, 9 + yhack, GOTO_STAT);
+    CPRINTF(Options.show_game_turns ? "Time:" : "Turn:");
     // Line 8 is exp pool, Level
 }
 
+void set_redraw_status(uint64_t flags)
+{
+    you.redraw_status_flags |= flags;
+}
+
+void redraw_screen()
+{
+    if (!crawl_state.need_save)
+    {
+        // If the game hasn't started, don't do much.
+        clrscr();
+        return;
+    }
+
+#ifdef USE_TILE_WEB
+    tiles.close_all_menus();
+#endif
+
+    draw_border();
+
+    you.redraw_title        = true;
+    you.redraw_hit_points   = true;
+    you.redraw_magic_points = true;
+#if TAG_MAJOR_VERSION == 34
+    if (you.species == SP_LAVA_ORC)
+        you.redraw_temperature = true;
+#endif
+    you.redraw_stats.init(true);
+    you.redraw_armour_class = true;
+    you.redraw_evasion      = true;
+    you.redraw_experience   = true;
+    you.wield_change        = true;
+    you.redraw_quiver       = true;
+
+    set_redraw_status(
+                      REDRAW_LINE_1_MASK | REDRAW_LINE_2_MASK | REDRAW_LINE_3_MASK);
+
+    print_stats();
+
+    bool note_status = notes_are_active();
+    activate_notes(false);
+    print_stats_level();
+#ifdef DGL_SIMPLE_MESSAGING
+    update_message_status();
+#endif
+    update_turn_count();
+    activate_notes(note_status);
+
+    viewwindow();
+
+    // Display the message window at the end because it places
+    // the cursor behind possible prompts.
+    display_message_window();
+    update_screen();
+}
+
 // ----------------------------------------------------------------------
 // Monster pane
 // ----------------------------------------------------------------------
@@ -1882,7 +1985,7 @@ static void _print_overview_screen_equip(column_composer& cols,
                      colname,
                      melded ? "melded " : "",
                      chop_string(item.name(DESC_PLAIN, true),
-                                 melded ? sw - 38 : sw - 31, false).c_str(),
+                                 melded ? sw - 43 : sw - 36, false).c_str(),
                      colname);
             equip_chars.push_back(equip_char);
         }
@@ -2006,6 +2109,11 @@ static string _god_powers(bool simple)
         return simple ? godpowers
                       : colour_string(godpowers, god_colour(you.religion));
     }
+    else if (you_worship(GOD_GOZAG))
+    {
+        return simple ? godpowers
+                      : colour_string(godpowers, god_colour(you.religion));
+    }
     else if (!you_worship(GOD_NO_GOD))
     {
         if (player_under_penance())
@@ -2037,24 +2145,9 @@ static vector<formatted_string> _get_overview_stats()
     // 4 columns
     column_composer cols1(4, 18, 28, 40);
 
-    const bool boosted_hp  = you.duration[DUR_DIVINE_VIGOUR]
-                                || you.berserk();
-    const bool boosted_mp  = you.duration[DUR_DIVINE_VIGOUR];
-    const bool boosted_ac  = you.duration[DUR_ICY_ARMOUR]
-                                || player_stoneskin();
-    const bool boosted_ev  = you.duration[DUR_PHASE_SHIFT]
-                                || you.duration[DUR_AGILITY];
-    const bool boosted_str = you.duration[DUR_DIVINE_STAMINA]
-                                || you.duration[DUR_MIGHT]
-                                || you.duration[DUR_BERSERK];
-    const bool boosted_int = you.duration[DUR_DIVINE_STAMINA]
-                                || you.duration[DUR_BRILLIANCE];
-    const bool boosted_dex = you.duration[DUR_DIVINE_STAMINA]
-                                || you.duration[DUR_AGILITY];
-
     if (!player_rotted())
     {
-        if (boosted_hp)
+        if (_boosted_hp())
         {
             snprintf(buf, sizeof buf, "HP <lightblue>%3d/%d</lightblue>",
                      you.hp, you.hp_max);
@@ -2064,7 +2157,7 @@ static vector<formatted_string> _get_overview_stats()
     }
     else
     {
-        if (boosted_hp)
+        if (_boosted_hp())
         {
             snprintf(buf, sizeof buf, "HP <lightblue>%3d/%d (%d)</lightblue>",
                      you.hp, you.hp_max, get_real_hp(true, true));
@@ -2077,7 +2170,7 @@ static vector<formatted_string> _get_overview_stats()
     }
     cols1.add_formatted(0, buf, false);
 
-    if (boosted_mp)
+    if (_boosted_mp())
     {
         snprintf(buf, sizeof buf, "MP <lightblue>%3d/%d</lightblue>",
                  you.magic_points, you.max_magic_points);
@@ -2092,7 +2185,7 @@ static vector<formatted_string> _get_overview_stats()
     snprintf(buf, sizeof buf, "Gold %d", you.gold);
     cols1.add_formatted(0, buf, false);
 
-    if (boosted_ac)
+    if (_boosted_ac())
     {
         snprintf(buf, sizeof buf, "AC <lightblue>%2d</lightblue>",
                  you.armour_class());
@@ -2101,7 +2194,7 @@ static vector<formatted_string> _get_overview_stats()
         snprintf(buf, sizeof buf, "AC %2d" , you.armour_class());
     cols1.add_formatted(1, buf, false);
 
-    if (boosted_ev)
+    if (_boosted_ev())
     {
         snprintf(buf, sizeof buf, "EV <lightblue>%2d</lightblue>",
                  player_evasion());
@@ -2110,75 +2203,52 @@ static vector<formatted_string> _get_overview_stats()
         snprintf(buf, sizeof buf, "EV %2d", player_evasion());
     cols1.add_formatted(1, buf, false);
 
-    snprintf(buf, sizeof buf, "SH %2d", player_shield_class());
+
+    if (_boosted_sh())
+    {
+        snprintf(buf, sizeof buf, "SH <lightblue>%2d</lightblue>",
+                 player_displayed_shield_class());
+    }
+    else
+        snprintf(buf, sizeof buf, "SH %2d", player_displayed_shield_class());
     cols1.add_formatted(1, buf, false);
 
+    const char* str_col = colour_to_str(_get_stat_colour(STAT_STR)).c_str();
     if (you.strength(false) == you.max_strength())
     {
-        if (boosted_str)
-        {
-            snprintf(buf, sizeof buf, "Str <lightblue>%2d</lightblue>",
-                     you.strength(false));
-        }
-        else
-            snprintf(buf, sizeof buf, "Str %2d", you.strength(false));
+        snprintf(buf, sizeof buf, "Str <%s>%2d</%s>",
+                 str_col, you.strength(false), str_col);
     }
     else
     {
-        if (boosted_str)
-        {
-            snprintf(buf, sizeof buf, "Str <lightblue>%2d (%d)</lightblue>",
-                     you.strength(false), you.max_strength());
-        }
-        else
-            snprintf(buf, sizeof buf, "Str <yellow>%2d</yellow> (%d)",
-                     you.strength(false), you.max_strength());
+        snprintf(buf, sizeof buf, "Str <%s>%2d (%d)</%s>",
+                 str_col, you.strength(false), you.max_strength(), str_col);
     }
     cols1.add_formatted(2, buf, false);
 
+    const char* int_col = colour_to_str(_get_stat_colour(STAT_INT)).c_str();
     if (you.intel(false) == you.max_intel())
     {
-        if (boosted_int)
-        {
-            snprintf(buf, sizeof buf, "Int <lightblue>%2d</lightblue>",
-                     you.intel(false));
-        }
-        else
-            snprintf(buf, sizeof buf, "Int %2d", you.intel(false));
+        snprintf(buf, sizeof buf, "Int <%s>%2d</%s>",
+                 int_col, you.intel(false), int_col);
     }
     else
     {
-        if (boosted_int)
-        {
-            snprintf(buf, sizeof buf, "Int <lightblue>%2d (%d)</lightblue>",
-                     you.intel(false), you.max_intel());
-        }
-        else
-            snprintf(buf, sizeof buf, "Int <yellow>%2d</yellow> (%d)",
-                     you.intel(false), you.max_intel());
+        snprintf(buf, sizeof buf, "Int <%s>%2d (%d)</%s>",
+                 int_col, you.intel(false), you.max_intel(), int_col);
     }
     cols1.add_formatted(2, buf, false);
 
+    const char* dex_col = colour_to_str(_get_stat_colour(STAT_DEX)).c_str();
     if (you.dex(false) == you.max_dex())
     {
-        if (boosted_dex)
-        {
-            snprintf(buf, sizeof buf, "Dex <lightblue>%2d</lightblue>",
-                     you.dex(false));
-        }
-        else
-            snprintf(buf, sizeof buf, "Dex %2d", you.dex(false));
+        snprintf(buf, sizeof buf, "Dex <%s>%2d</%s>",
+                 dex_col, you.dex(false), dex_col);
     }
     else
     {
-        if (boosted_dex)
-        {
-            snprintf(buf, sizeof buf, "Dex <lightblue>%2d (%d)</lightblue>",
-                     you.dex(false), you.max_dex());
-        }
-        else
-            snprintf(buf, sizeof buf, "Dex <yellow>%2d</yellow> (%d)",
-                     you.dex(false), you.max_dex());
+        snprintf(buf, sizeof buf, "Dex <%s>%2d (%d)</%s>",
+                 dex_col, you.dex(false), you.max_dex(), dex_col);
     }
     cols1.add_formatted(2, buf, false);
 
@@ -2197,6 +2267,7 @@ static vector<formatted_string> _get_overview_stats()
     else
         lives[0] = 0;
 
+#if TAG_MAJOR_VERSION == 34
     char temperature[20];
     if (you.species == SP_LAVA_ORC)
     {
@@ -2205,6 +2276,7 @@ static vector<formatted_string> _get_overview_stats()
     }
     else
         temperature[0] = 0;
+#endif
 
     snprintf(buf, sizeof buf,
              "XL: %d%s\n"
@@ -2269,21 +2341,20 @@ static vector<formatted_string> _get_overview_resistances(
     out += _resist_composer("rElec", cwidth, relec) + "\n";
 
     const int rsust = player_sust_abil(calc_unid);
-    out += _resist_composer("SustAb", cwidth, rsust, 2) + "\n";
+    out += _resist_composer("SustAb", cwidth, rsust) + "\n";
 
     const int rmuta = (you.rmut_from_item(calc_unid)
                        || player_mutation_level(MUT_MUTATION_RESISTANCE) == 3);
     out += _resist_composer("rMut", cwidth, rmuta) + "\n";
 
+
+    const int gourmand = you.gourmand(calc_unid);
     const int saplevel = player_mutation_level(MUT_SAPROVOROUS);
-    const bool show_gourm = (you.species != SP_MUMMY
-                             && you.species != SP_VAMPIRE
-                             && player_mutation_level(MUT_HERBIVOROUS) < 3
-                             && you.gourmand());
-    out += _resist_composer(show_gourm ? "Gourm" : "Saprov",
+    const bool show_saprov = saplevel && !gourmand;
+    out += _resist_composer(show_saprov ? "Saprov" : "Gourm",
                             cwidth,
-                            show_gourm ? 1 : saplevel,
-                            show_gourm ? 1 : 3) + "\n";
+                            show_saprov ? saplevel : gourmand,
+                            show_saprov ? 3 : 1) + "\n";
 
     const int rmagi = player_res_magic(calc_unid) / 40;
     out += _resist_composer("MR", cwidth, rmagi, 5) + "\n";
@@ -2305,8 +2376,6 @@ static vector<formatted_string> _get_overview_resistances(
     out += show_angry ? _resist_composer("Rnd*Rage", cwidth, 1, 1, false) + "\n"
                       : _resist_composer("Clarity", cwidth, rclar) + "\n";
 
-    const int rcons = you.conservation(calc_unid);
-    out += _resist_composer("Conserve", cwidth, rcons) + "\n";
     const int rcorr = you.res_corr(calc_unid);
     out += _resist_composer("rCorr", cwidth, rcorr) + "\n";
     const int rrott = you.res_rotting();
@@ -2427,16 +2496,16 @@ void print_overview_screen()
 string stealth_desc(int stealth)
 {
     string prefix =
-         (stealth <  10) ? "extremely un" :
-         (stealth <  30) ? "very un" :
-         (stealth <  60) ? "un" :
-         (stealth <  90) ? "fairly " :
-         (stealth < 120) ? "" :
-         (stealth < 160) ? "quite " :
-         (stealth < 220) ? "very " :
-         (stealth < 300) ? "extremely " :
+         (stealth ==  0) ? "extremely un" :
+         (stealth <  50) ? "very un" :
+         (stealth < 100) ? "un" :
+         (stealth < 150) ? "fairly " :
+         (stealth < 200) ? "" :
+         (stealth < 250) ? "quite " :
+         (stealth < 300) ? "very " :
+         (stealth < 350) ? "extremely " :
          (stealth < 400) ? "extraordinarily " :
-         (stealth < 520) ? "incredibly "
+         (stealth < 500) ? "incredibly "
                          : "uncannily ";
     return prefix + "stealthy";
 }
@@ -2480,92 +2549,12 @@ static string _status_mut_abilities(int sw)
     string text = "<w>@:</w> ";
     vector<string> status;
 
-    const int statuses[] =
-    {
-        DUR_TRANSFORMATION,
-        DUR_PARALYSIS,
-        DUR_PETRIFIED,
-        DUR_SLEEP,
-        DUR_PETRIFYING,
-        STATUS_BURDEN,
-        STATUS_STR_ZERO, STATUS_INT_ZERO, STATUS_DEX_ZERO,
-        DUR_BREATH_WEAPON,
-        STATUS_BEHELD,
-        DUR_LIQUID_FLAMES,
-        DUR_ICY_ARMOUR,
-        DUR_ANTIMAGIC,
-        STATUS_MISSILES,
-        DUR_JELLY_PRAYER,
-        STATUS_REGENERATION,
-        DUR_DEATHS_DOOR,
-        DUR_STONESKIN,
-        DUR_TELEPORT,
-        DUR_DISJUNCTION,
-        DUR_DEATH_CHANNEL,
-        DUR_PHASE_SHIFT,
-        DUR_SILENCE,
-        STATUS_INVISIBLE,
-        DUR_CONF,
-        DUR_EXHAUSTED,
-        DUR_MIGHT,
-        DUR_BRILLIANCE,
-        DUR_AGILITY,
-        DUR_DIVINE_VIGOUR,
-        DUR_DIVINE_STAMINA,
-        DUR_BERSERK,
-        STATUS_AIRBORNE,
-        STATUS_MANUAL,
-        STATUS_SAGE,
-        DUR_MAGIC_SHIELD,
-        DUR_FIRE_SHIELD,
-        DUR_POISONING,
-        STATUS_SICK,
-        STATUS_CONTAMINATION,
-        STATUS_ROT,
-        DUR_CONFUSING_TOUCH,
-        DUR_SLIMIFY,
-        DUR_SURE_BLADE,
-        STATUS_NET,
-        STATUS_SPEED,
-        DUR_AFRAID,
-        DUR_MIRROR_DAMAGE,
-        DUR_SCRYING,
-        DUR_TORNADO,
-        DUR_HEROISM,
-        DUR_FINESSE,
-        DUR_LIFESAVING,
-        DUR_DARKNESS,
-        STATUS_FIREBALL,
-        DUR_SHROUD_OF_GOLUBRIA,
-        DUR_TORNADO_COOLDOWN,
-        STATUS_BACKLIT,
-        STATUS_UMBRA,
-        STATUS_CONSTRICTED,
-        STATUS_AUGMENTED,
-        STATUS_RECALL,
-        STATUS_LIQUEFIED,
-        DUR_FLAYED,
-        DUR_RETCHING,
-        DUR_WEAK,
-        DUR_DIMENSION_ANCHOR,
-        STATUS_DRAINED,
-        DUR_TOXIC_RADIANCE,
-        DUR_RECITE,
-        DUR_GRASPING_ROOTS,
-        DUR_FIRE_VULN,
-        DUR_POISON_VULN,
-        DUR_FROZEN,
-        DUR_SAP_MAGIC,
-        STATUS_MAGIC_SAPPED,
-        DUR_FORESTED,
-        DUR_DRAGON_CALL,
-        DUR_ABJURATION_AURA,
-    };
-
+    // A hard-coded duration/status list used to be used here. This list is no
+    // longer hard-coded. May 2014. -reaverb
     status_info inf;
-    for (unsigned i = 0; i < ARRAYSZ(statuses); ++i)
+    for (unsigned i = 0; i <= STATUS_LAST_STATUS; ++i)
     {
-        if (fill_status_info(statuses[i], &inf) && !inf.short_text.empty())
+        if (fill_status_info(i, &inf) && !inf.short_text.empty())
             status.push_back(inf.short_text);
     }
 
@@ -2654,10 +2643,6 @@ static string _status_mut_abilities(int sw)
         mutations.push_back("restore body");
         break;
 
-    case SP_KOBOLD:
-        mutations.push_back("disease resistance");
-        break;
-
     case SP_VAMPIRE:
         if (you.experience_level >= 6)
             mutations.push_back("bottle blood");
