@@ -18,6 +18,7 @@
 #include "player.h"
 #include "religion.h"
 #include "state.h"
+#include "stringutil.h"
 #include "transform.h"
 #include "hints.h"
 
@@ -159,7 +160,15 @@ bool attribute_increase()
     }
 }
 
-// Rearrange stats, biased based on your armour and skills.
+/*
+ * Have Jiyva increase a player stat by one and decrease a different stat by
+ * one.
+ *
+ * This considers armour evp and skills to determine which stats to change. A
+ * target stat vector is created based on these factors, which is then fuzzed,
+ * and then a shuffle of the player's stat points that doesn't increase the l^2
+ * distance to the target vector is chosen.
+*/
 void jiyva_stat_action()
 {
     int cur_stat[3];
@@ -170,14 +179,13 @@ void jiyva_stat_action()
         cur_stat[x] = you.stat(static_cast<stat_type>(x), false);
         stat_total += cur_stat[x];
     }
-    // Try to avoid burdening people or making their armour difficult to use.
-    int current_capacity = carrying_capacity(BS_UNENCUMBERED);
-    int carrying_strength = cur_stat[0] + (you.burden - current_capacity + 207)/208;
+
     int evp = you.unadjusted_body_armour_penalty();
-    target_stat[0] = max(max(9, evp), 2 + carrying_strength);
+    target_stat[0] = max(9, evp);
     target_stat[1] = 9;
     target_stat[2] = 9;
     int remaining = stat_total - 18 - target_stat[0];
+
     // Divide up the remaining stat points between Int and either Str or Dex,
     // based on skills.
     if (remaining > 0)
@@ -197,17 +205,19 @@ void jiyva_stat_action()
         }
 
         // Heavy armour weights towards strength, Dodging skill towards
-        // dexterity.  EVP 15 (chain) is enough to weight towards pure
-        // Str in the absence of dodging skill, but 15 dodging will
-        // will push that back to pure Dex.
-        int str_weight = (10*evp - you.skill(SK_DODGING, 10))/15;
+        // dexterity.  EVP 15 (chain) is enough to weight towards pure Str in
+        // the absence of dodging skill, but 15 dodging will will push that
+        // back to pure Dex.
+        int str_weight = (10 * evp - you.skill(SK_DODGING, 10)) / 15;
         // Clip weight between 0 (pure dex) and 10 (pure strength).
         str_weight = min(10, max(0, str_weight));
 
         // If you are in really heavy armour, then you already are getting a
         // lot of Str and more won't help much, so weight magic more.
-        other_weights = max(other_weights - (evp >= 15 ? 4 : 1) * magic_weights/2, 0);
-        magic_weights = div_rand_round(remaining * magic_weights, magic_weights + other_weights);
+        other_weights = max(other_weights - (evp >= 15 ? 4 : 1)
+                            * magic_weights / 2, 0);
+        magic_weights = div_rand_round(remaining * magic_weights,
+                                       magic_weights + other_weights);
         other_weights = remaining - magic_weights;
         target_stat[1] += magic_weights;
 
@@ -242,8 +252,10 @@ void jiyva_stat_action()
     {
         simple_god_message("'s power touches on your attributes.");
         const string cause = "the 'helpfulness' of " + god_name(you.religion);
-        modify_stat(static_cast<stat_type>(stat_up_choice), 1, true, cause.c_str());
-        modify_stat(static_cast<stat_type>(stat_down_choice), -1, true, cause.c_str());
+        modify_stat(static_cast<stat_type>(stat_up_choice), 1, true,
+                    cause.c_str());
+        modify_stat(static_cast<stat_type>(stat_down_choice), -1, true,
+                    cause.c_str());
     }
 }
 
@@ -377,6 +389,9 @@ static int _strength_modifier()
     if (you.duration[DUR_MIGHT] || you.duration[DUR_BERSERK])
         result += 5;
 
+    if (you.duration[DUR_FORTITUDE])
+        result += 10;
+
     if (you.duration[DUR_DIVINE_STAMINA])
         result += you.attribute[ATTR_DIVINE_STAMINA];
 
@@ -529,16 +544,6 @@ bool lose_stat(stat_type which_stat, int stat_loss, bool force,
 
         int sust = player_sust_abil();
         stat_loss >>= sust;
-
-        if (sust && !player_sust_abil(false))
-        {
-            item_def *ring = get_only_unided_ring();
-            if (ring && !is_artefact(*ring)
-                && ring->sub_type == RING_SUSTAIN_ABILITIES)
-            {
-                wear_id_type(*ring);
-            }
-        }
     }
 
     mprf(stat_loss > 0 ? MSGCH_WARN : MSGCH_PLAIN,
@@ -668,8 +673,8 @@ static void _handle_stat_change(stat_type stat, const char* cause, bool see_sour
     switch (stat)
     {
     case STAT_STR:
-        burden_change();
         you.redraw_armour_class = true; // includes shields
+        you.redraw_evasion = true; // Might reduce EV penalty
         break;
 
     case STAT_INT:
@@ -709,8 +714,6 @@ void update_stat_zero()
             {
                 mprf("Your %s has recovered.", stat_desc(s, SD_NAME));
                 you.redraw_stats[s] = true;
-                if (i == STAT_STR)
-                    burden_change();
             }
         }
         else // no stat penalty at all
