@@ -73,11 +73,11 @@
 #include "AppHdr.h"
 #include <map>
 #include <algorithm>
+#include "end.h"
 #include "l_defs.h"
-#include "libutil.h"
 #include "mapdef.h"
 #include "maps.h"
-#include "stuff.h"
+#include "stringutil.h"
 
 #define YYERROR_VERBOSE 1
 #define YYENABLE_NLS 0
