@@ -115,8 +115,7 @@ const char* random_choose_weighted(int weight, const char* first, ...)
 #define UINT32_MAX ((uint32_t)(-1))
 #endif
 
-// [0, max)
-int random2(int max)
+static int _random2(int max, int rng)
 {
     if (max <= 1)
         return 0;
@@ -125,7 +124,7 @@ int random2(int max)
 
     while (true)
     {
-        uint32_t bits = get_uint32();
+        uint32_t bits = get_uint32(rng);
         uint32_t val  = bits / partn;
 
         if (val < (uint32_t)max)
@@ -133,26 +132,20 @@ int random2(int max)
     }
 }
 
+// [0, max)
+int random2(int max)
+{
+    return _random2(max, 0);
+}
+
 // [0, max), separate RNG state
 int ui_random(int max)
 {
-    if (max <= 1)
-        return 0;
-
-    uint32_t partn = UINT32_MAX / max;
-
-    while (true)
-    {
-        uint32_t bits = get_uint32(1);
-        uint32_t val  = bits / partn;
-
-        if (val < (uint32_t)max)
-            return (int)val;
-    }
+    return _random2(max, 1);
 }
 
 // [0, 1]
-bool coinflip(void)
+bool coinflip()
 {
     return static_cast<bool>(random2(2));
 }
@@ -238,19 +231,6 @@ dice_def calc_dice(int num_dice, int max_damage)
     return ret;
 }
 
-// Attempts to make missile weapons nicer to the player by reducing the
-// extreme variance in damage done.
-void scale_dice(dice_def &dice, int threshold)
-{
-    while (dice.size > threshold)
-    {
-        dice.num *= 2;
-        // If it's an odd number, lose one; this is more than
-        // compensated by the increase in number of dice.
-        dice.size /= 2;
-    }
-}
-
 // Calculates num/den and randomly adds one based on the remainder.
 // [floor(num/den), ceil(num/den)]
 int div_rand_round(int num, int den)
@@ -262,6 +242,11 @@ int div_rand_round(int num, int den)
         return num / den;
 }
 
+int div_round_up(int num, int den)
+{
+    return num / den + (num % den != 0);
+}
+
 // [0, max)
 int bestroll(int max, int rolls)
 {
@@ -344,31 +329,6 @@ double random_real()
     return get_uint32() / 4294967296.0;
 }
 
-// range [0, 1.0]
-double random_real_inc()
-{
-    return get_uint32() / 4294967295.0;
-}
-
-// range [0, 1.0], weighted to middle with multiple rolls
-double random_real_avg(int rolls)
-{
-    ASSERT(rolls > 0);
-    double sum = 0;
-
-    for (int i = 0; i < rolls; i++)
-        sum += random_real_inc();
-
-    return sum / (double)rolls;
-}
-
-// range [low, high], weighted to middle with multiple rolls
-double random_range_real(double low, double high, int nrolls)
-{
-    const int roll = random_real_avg(nrolls) * (high - low);
-    return low + roll;
-}
-
 // Roll n_trials, return true if at least one succeeded.  n_trials might be
 // not integer.
 // [0, 1]
@@ -376,7 +336,7 @@ bool bernoulli(double n_trials, double trial_prob)
 {
     if (n_trials <= 0 || trial_prob <= 0)
         return false;
-    return random_real() >= pow(1 - trial_prob, n_trials);
+    return !decimal_chance(pow(1 - trial_prob, n_trials));
 }
 
 bool one_chance_in(int a_million)
@@ -403,6 +363,11 @@ int fuzz_value(int val, int lowfuzz, int highfuzz, int naverage)
     return val + random2avg(lfuzz + hfuzz + 1, naverage) - lfuzz;
 }
 
+bool decimal_chance(double percent)
+{
+    return random_real() < percent;
+}
+
 // This is used when the front-end randomness is inconclusive.  There are
 // never more than two possibilities, which simplifies things.
 bool defer_rand::x_chance_in_y_contd(int x, int y, int index)
