@@ -21,9 +21,6 @@ int random_range(int low, int high);
 int random_range(int low, int high, int nrolls);
 uint32_t random_int();
 double random_real();
-double random_real_inc();
-double random_real_avg(int rolls);
-double random_range_real(double low, double high, int nrolls = 1);
 
 int random2avg(int max, int rolls);
 int bestroll(int max, int rolls);
@@ -33,6 +30,7 @@ int binomial_generator(unsigned n_trials, unsigned trial_prob);
 bool bernoulli(double n_trials, double trial_prob);
 int fuzz_value(int val, int lowfuzz, int highfuzz, int naverage = 2);
 int roll_dice(int num, int size);
+bool decimal_chance(double percent);
 
 int ui_random(int max);
 
@@ -105,7 +103,6 @@ struct dice_def
 };
 
 dice_def calc_dice(int num_dice, int max_damage);
-void scale_dice(dice_def &dice, int threshold = 24);
 
 template <typename T>
 void shuffle_array(T* arr, int n)
