@@ -7,14 +7,15 @@ enum piety_gain_t
     NUM_PIETY_GAIN
 };
 
+#if TAG_MAJOR_VERSION == 34
 enum nemelex_gift_types
 {
     NEM_GIFT_ESCAPE = 0,
     NEM_GIFT_DESTRUCTION,
-    NEM_GIFT_DUNGEONS,
     NEM_GIFT_SUMMONING,
     NEM_GIFT_WONDERS,
     NUM_NEMELEX_GIFT_TYPES,
 };
+#endif
 
 #endif
