@@ -26,12 +26,17 @@ void destroy_shop_at(coord_def p);
 
 string shop_name(const coord_def& where);
 string shop_name(const coord_def& where, bool add_stop);
+string shop_type_name(shop_type type);
 
 bool shoptype_identifies_stock(shop_type type);
 
 bool is_shop_item(const item_def &item);
 bool shop_item_unknown(const item_def &item);
 
+int str_to_shoptype(const string &s);
+const char *shoptype_to_str(shop_type type);
+void list_shop_types();
+
 /////////////////////////////////////////////////////////////////////
 
 struct level_pos;
