@@ -14,14 +14,15 @@
 #include "evoke.h"
 #include "fontwrapper-ft.h"
 #include "hints.h"
-#include "libutil.h"
 #include "options.h"
+#include "output.h"
 #include "player.h"
 #include "religion.h"
 #include "skills.h"
 #include "skills2.h"
 #include "state.h"
-#include "stuff.h"
+#include "stringutil.h"
+
 #ifdef USE_TILE
  #include "tilepick.h"
  #include "tilereg-crt.h"
@@ -297,10 +298,6 @@ COLORS SkillMenuEntry::get_colour() const
             return LIGHTGREEN;
         return you.train[m_sk] ? LIGHTGREEN : GREEN;
     }
-    else if (crosstrain_bonus(m_sk) > 1 && is_set(SKMF_APTITUDE))
-        return GREEN;
-    else if (is_antitrained(m_sk) && is_set(SKMF_APTITUDE))
-        return RED;
     else if (you.train[m_sk] == 2)
         return WHITE;
     else
@@ -328,33 +325,6 @@ string SkillMenuEntry::get_prefix()
 #endif
 }
 
-static bool _crosstrain_other(skill_type sk, skill_menu_state state)
-{
-    vector<skill_type> crosstrain_skills = get_crosstrain_skills(sk);
-
-    for (unsigned int i = 0; i < crosstrain_skills.size(); ++i)
-    {
-        if (you.skill(crosstrain_skills[i], 10, true)
-            <= you.skill(sk, 10, true) - CROSSTRAIN_THRESHOLD
-           && _show_skill(crosstrain_skills[i], state))
-        {
-            return true;
-        }
-    }
-
-    return false;
-}
-
-static bool _antitrain_other(skill_type sk, skill_menu_state state)
-{
-    skill_type opposite = opposite_skill(sk);
-    if (opposite == SK_NONE)
-        return false;
-
-    return _show_skill(opposite, state) && you.skills[sk] > 0
-           && you.skills[opposite] < 27 && compare_skills(sk, opposite);
-}
-
 void SkillMenuEntry::set_aptitude()
 {
     string text = "<white>";
@@ -362,49 +332,28 @@ void SkillMenuEntry::set_aptitude()
     const bool manual = skill_has_manual(m_sk);
     const int apt = species_apt(m_sk, you.species);
 
-    // Crosstraining + manuals aptitude bonus.
-    int ct_bonus = manual ? 4 : 0;
-
-    for (int ct_mult = crosstrain_bonus(m_sk); ct_mult > 1; ct_mult /= 2)
-        ct_bonus += 4;
+    // Manuals aptitude bonus.
+    int manual_bonus = manual ? 4 : 0;
 
     if (apt != 0)
         text += make_stringf("%+d", apt);
     else
         text += make_stringf(" %d", apt);
 
-    text += "</white>";
+    text += "</white> ";
 
-    if (_antitrain_other(m_sk, skm.get_state(SKM_SHOW)))
+    if (manual_bonus)
     {
-        skm.set_flag(SKMF_ANTITRAIN);
-        text += "<red>*</red>";
-    }
-    else if (_crosstrain_other(m_sk, skm.get_state(SKM_SHOW)))
-    {
-        skm.set_flag(SKMF_CROSSTRAIN);
-        text += "<green>*</green>";
-    }
-    else
-        text += " ";
-
-    if (is_antitrained(m_sk))
-    {
-        skm.set_flag(SKMF_ANTITRAIN);
-        text += make_stringf("<red>%d</red>", ct_bonus - 4);
-    }
-    else if (ct_bonus)
-    {
-        skm.set_flag(SKMF_CROSSTRAIN);
-        text += manual ? "<lightgreen>" : "<green>";
+        skm.set_flag(SKMF_MANUAL);
+        text += "<lightgreen>";
 
         // Only room for two characters.
-        if (ct_bonus < 10)
-            text += make_stringf("+%d", ct_bonus);
+        if (manual_bonus < 10)
+            text += make_stringf("+%d", manual_bonus);
         else
-            text += make_stringf("%d", ct_bonus);
+            text += make_stringf("%d", manual_bonus);
 
-        text += manual ? "</lightgreen>" : "</green>";
+        text += "</lightgreen>";
     }
 
     m_aptitude->set_text(text);
@@ -578,11 +527,7 @@ string SkillMenuSwitch::get_help()
                "fast as others.";
     case SKM_LEVEL_ENHANCED:
         if (skm.is_set(SKMF_ENHANCED))
-        {
-            return make_stringf("Skills enhanced by the power of %s are in "
-                                "<blue>blue</blue>. ",
-                                god_name(you.religion).c_str());
-        }
+            return make_stringf("Enhanced skills are in <blue>blue</blue>.");
         else
         {
             vector<string> causes;
@@ -1249,36 +1194,18 @@ void SkillMenu::set_default_help()
         text = hints_skills_info();
     else
     {
-        if (!is_set(SKMF_CROSSTRAIN) && !is_set(SKMF_ANTITRAIN))
+        if (!is_set(SKMF_MANUAL))
             text = m_switches[SKM_VIEW]->get_help();
 
-        if (get_state(SKM_LEVEL) == SKM_LEVEL_ENHANCED
-            && !(is_set(SKMF_CROSSTRAIN) && is_set(SKMF_ANTITRAIN)))
-        {
+        if (get_state(SKM_LEVEL) == SKM_LEVEL_ENHANCED)
             text += m_switches[SKM_LEVEL]->get_help();
-        }
         else
             text += "The species aptitude is in <white>white</white>. ";
 
-        if (is_set(SKMF_CROSSTRAIN))
-            text += "Crosstraining is in <green>green</green>. ";
-        if (is_set(SKMF_ANTITRAIN))
-            text += "Antitraining is in <red>red</red>. ";
+        if (is_set(SKMF_MANUAL))
 
-        if (is_set(SKMF_CROSSTRAIN) && is_set(SKMF_ANTITRAIN))
         {
-            text += "The skill responsible for the bonus or malus is "
-                    "marked with '*'.";
-        }
-        else if (is_set(SKMF_CROSSTRAIN))
-        {
-            text += "The skill responsible for the bonus is marked with "
-                    "'<green>*</green>'.";
-        }
-        else if (is_set(SKMF_ANTITRAIN))
-        {
-            text += "The skill responsible for the malus is marked with "
-                    "'<red>*</red>'.";
+            text += "Manual usage is in <green>green</green>. ";
         }
     }
 
@@ -1307,8 +1234,7 @@ void SkillMenu::set_skills()
 
     SkillMenuEntry::m_letter = '9';
     bool default_set = false;
-    clear_flag(SKMF_CROSSTRAIN);
-    clear_flag(SKMF_ANTITRAIN);
+    clear_flag(SKMF_MANUAL);
 
     int col = 0, ln = 0;
 
@@ -1482,7 +1408,7 @@ void SkillMenu::set_links()
 
 void skill_menu(int flag, int exp)
 {
-    // potion or card; you may elect to sin against Trog
+    // experience potion; you may elect to sin against Trog
     if (flag & SKMF_EXPERIENCE && all_skills_maxed(true))
     {
         mpr("You feel omnipotent.");
@@ -1503,7 +1429,7 @@ void skill_menu(int flag, int exp)
     int keyn;
 
     // Calling a user lua function here to let players automatically accept
-    // the given skill distribution for a potion or card of experience.
+    // the given skill distribution for a potion of experience.
     if (skm.is_set(SKMF_EXPERIENCE)
         && clua.callbooleanfn(false, "auto_experience", NULL)
         && skm.exit())
