@@ -11,6 +11,9 @@ enum genus_type
 
 genus_type species_genus(species_type species);
 int species_has_claws(species_type species, bool mut_level = false);
+bool species_is_undead(species_type species);
+bool species_is_unbreathing(species_type species);
+bool species_can_swim(species_type species);
 bool species_likes_water(species_type species);
 bool species_likes_lava(species_type species);
 bool species_can_throw_large_rocks(species_type species);
