@@ -3,7 +3,7 @@
 
 #include "spl-cast.h"
 
-int allowed_deaths_door_hp(void);
+int allowed_deaths_door_hp();
 spret_type cast_deaths_door(int pow, bool fail);
 void remove_ice_armour();
 spret_type ice_armour(int pow, bool fail);
