@@ -33,12 +33,14 @@
 #include "mon-behv.h"
 #include "mon-util.h"
 #include "orb.h"
+#include "output.h"
+#include "prompt.h"
 #include "random.h"
 #include "shout.h"
 #include "spl-util.h"
 #include "stash.h"
 #include "state.h"
-#include "stuff.h"
+
 #include "teleport.h"
 #include "terrain.h"
 #include "throw.h"
@@ -48,12 +50,6 @@
 #include "viewmap.h"
 #include "xom.h"
 
-static bool _abyss_blocks_teleport(bool cblink)
-{
-    // Controlled Blink (the spell) works more reliably in the Abyss.
-    return cblink ? coinflip() : !one_chance_in(3);
-}
-
 // XXX: can miscast before cancelling.
 spret_type cast_controlled_blink(int pow, bool fail)
 {
@@ -116,7 +112,7 @@ void disjunction()
 // a monster being at the target spot), and the player gains no
 // contamination.
 int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
-          string *pre_msg)
+          string *pre_msg, bool safely_cancellable)
 {
     ASSERT(!crawl_state.game_is_arena());
 
@@ -137,14 +133,6 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
             mpr(pre_msg->c_str());
         canned_msg(MSG_STRANGE_STASIS);
     }
-    else if (player_in_branch(BRANCH_ABYSS)
-             && _abyss_blocks_teleport(high_level_controlled_blink)
-             && !wizard_blink)
-    {
-        if (pre_msg)
-            mpr(pre_msg->c_str());
-        mpr("The power of the Abyss keeps you in your place!");
-    }
     else if (you.confused() && !wizard_blink)
     {
         if (pre_msg)
@@ -154,6 +142,14 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
     // The orb sometimes degrades controlled blinks to completely uncontrolled.
     else if (orb_haloed(you.pos()) && !wizard_blink)
     {
+        if (safely_cancellable && !high_level_controlled_blink
+            && !yesno("Your blink will be uncontrolled - continue anyway?",
+                      false, 'n'))
+        {
+            canned_msg(MSG_OK);
+            return -1;
+        }
+
         if (pre_msg)
             mpr(pre_msg->c_str());
         mprf(MSGCH_ORB, "The orb interferes with your control of the blink!");
@@ -164,6 +160,14 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
     }
     else if (!allow_control_teleport(true) && !wizard_blink)
     {
+        if (safely_cancellable && !high_level_controlled_blink
+            && !yesno("Your blink will be uncontrolled - continue anyway?",
+                      false, 'n'))
+        {
+            canned_msg(MSG_OK);
+            return -1;
+        }
+
         if (pre_msg)
             mpr(pre_msg->c_str());
         mpr("A powerful magic interferes with your control of the blink.");
@@ -192,11 +196,11 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
 
             if (!beam.isValid || beam.target == you.pos())
             {
-                if (!wizard_blink
+                if (!wizard_blink && !safely_cancellable
                     && !yesno("Are you sure you want to cancel this blink?",
                               false, 'n'))
                 {
-                    mesclr();
+                    clear_messages();
                     continue;
                 }
                 canned_msg(MSG_OK);
@@ -221,12 +225,12 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
 
             if (grd(beam.target) == DNGN_OPEN_SEA)
             {
-                mesclr();
+                clear_messages();
                 mpr("You can't blink into the sea!");
             }
             else if (grd(beam.target) == DNGN_LAVA_SEA)
             {
-                mesclr();
+                clear_messages();
                 mpr("You can't blink into the sea of lava!");
             }
             else if (!check_moveto(beam.target, "blink"))
@@ -244,12 +248,12 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
                 if (wizard_blink)
                     break;
 
-                mesclr();
+                clear_messages();
                 mpr("There's something in the way!");
             }
             else
             {
-                mesclr();
+                clear_messages();
                 mpr("You can only blink to visible locations.");
             }
         }
@@ -276,7 +280,7 @@ int blink(int pow, bool high_level_controlled_blink, bool wizard_blink,
             if (!wizard_blink)
                 place_cloud(CLOUD_TLOC_ENERGY, you.pos(), 1 + random2(3), &you);
 
-            move_player_to_grid(beam.target, false, true);
+            move_player_to_grid(beam.target, false);
 
             // Controlling teleport contaminates the player. -- bwr
             if (!wizard_blink)
@@ -305,12 +309,6 @@ void random_blink(bool allow_partial_control, bool override_abyss, bool override
 
     if (you.no_tele(true, true, true) && !override_stasis)
         canned_msg(MSG_STRANGE_STASIS);
-    else if (player_in_branch(BRANCH_ABYSS)
-             && !override_abyss
-             && _abyss_blocks_teleport(false))
-    {
-        mpr("The power of the Abyss keeps you in your place!");
-    }
     // First try to find a random square not adjacent to the player,
     // then one adjacent if that fails.
     else if (!random_near_space(&you, you.pos(), target)
@@ -331,7 +329,7 @@ void random_blink(bool allow_partial_control, bool override_abyss, bool override
     {
         canned_msg(MSG_YOU_BLINK);
         coord_def origin = you.pos();
-        move_player_to_grid(target, false, true);
+        move_player_to_grid(target, false);
 
         // Leave a purple cloud.
         if (!cell_is_solid(origin))
@@ -367,7 +365,7 @@ spret_type cast_teleport_self(bool fail)
     return SPRET_SUCCESS;
 }
 
-void you_teleport(void)
+void you_teleport()
 {
     // [Cha] here we block teleportation, which will save the player from
     // death from read-id'ing scrolls (in sprint)
@@ -616,7 +614,7 @@ static bool _teleport_player(bool allow_control, bool wizard_tele,
                 if (!wizard_tele && !cell_is_solid(old_pos))
                     place_cloud(CLOUD_TLOC_ENERGY, old_pos, 1 + random2(3), &you);
 
-                move_player_to_grid(pos, false, true);
+                move_player_to_grid(pos, false);
 
                 // Controlling teleport contaminates the player. - bwr
                 if (!wizard_tele)
@@ -691,7 +689,7 @@ static bool _teleport_player(bool allow_control, bool wizard_tele,
         if (!cell_is_solid(old_pos))
             place_cloud(CLOUD_TLOC_ENERGY, old_pos, 1 + random2(3), &you);
 
-        move_player_to_grid(newpos, false, true);
+        move_player_to_grid(newpos, false);
     }
 
     _handle_teleport_update(large_change, old_pos);
@@ -761,7 +759,7 @@ bool you_teleport_to(const coord_def where_to, bool move_monsters)
 
     bool large_change = you.see_cell(where);
 
-    move_player_to_grid(where, false, true);
+    move_player_to_grid(where, false);
 
     _handle_teleport_update(large_change, old_pos);
     return true;
@@ -829,6 +827,13 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
 
     item_def& item = mitm[item_idx];
 
+    // Nets can be apported when they have a victim trapped.
+    if (item_is_stationary(item) && !item_is_stationary_net(item))
+    {
+        mpr("You cannot apport that!");
+        return SPRET_ABORT;
+    }
+
     // Can't apport the Orb in zotdef or sprint
     if (item_is_orb(item)
         && (crawl_state.game_is_zotdef()
@@ -839,23 +844,6 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     }
 
     fail_check();
-    // Mass of one unit.
-    const int unit_mass = item_mass(item);
-    const int max_mass = pow * 30 + random2(pow * 20);
-
-    int max_units = item.quantity;
-    if (unit_mass > 0)
-        max_units = max_mass / unit_mass;
-
-    if (max_units <= 0)
-    {
-        if (item_is_orb(item))
-            orb_pickup_noise(where, 30);
-
-        mpr("The mass is resisting your pull.");
-
-        return SPRET_SUCCESS;
-    }
 
     // We need to modify the item *before* we move it, because
     // move_top_item() might change the location, or merge
@@ -882,9 +870,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     }
 
     // If we apport a net, free the monster under it.
-    if (item.base_type == OBJ_MISSILES
-        && item.sub_type == MI_THROWING_NET
-        && item_is_stationary(item))
+    if (item_is_stationary_net(item))
     {
         free_stationary_net(item_idx);
         if (monster* mons = monster_at(where))
@@ -907,10 +893,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
 
     // The maximum number of squares the item will actually move, always
     // at least one square.
-    int quantity = item.quantity;
-    int apported_mass = unit_mass * min(quantity, max_units);
-
-    int max_dist = max(60 * pow / (apported_mass + 150), 1);
+    int max_dist = max(pow * 2 / 5, 1);
 
     dprf("Apport dist=%d, max_dist=%d", dist, max_dist);
 
@@ -942,19 +925,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     mprf("Yoink! You pull the item%s towards yourself.",
          (item.quantity > 1) ? "s" : "");
 
-    if (max_units < item.quantity)
-    {
-        if (!copy_item_to_grid(item, new_spot, max_units))
-        {
-            // Always >1 item.
-            mpr("They abruptly stop in place!");
-            // Too late to abort.
-            return SPRET_SUCCESS;
-        }
-        item.quantity -= max_units;
-    }
-    else
-        move_top_item(where, new_spot);
+    move_top_item(where, new_spot);
 
     // Mark the item as found now.
     origin_set(new_spot);
@@ -1007,7 +978,7 @@ static bool _quadrant_blink(coord_def dir, int pow)
     }
 
     coord_def origin = you.pos();
-    move_player_to_grid(target, false, true);
+    move_player_to_grid(target, false);
 
     // Leave a purple cloud.
     if (!cell_is_solid(origin))
