@@ -23,20 +23,23 @@
 #include "coordit.h"
 #include "directn.h"
 #include "godabil.h"
-#include "stuff.h"
 #include "env.h"
 #include "items.h"
 #include "libutil.h"
+#include "message.h"
 #include "mon-behv.h"
 #include "mon-util.h"
 #include "notes.h"
 #include "options.h"
+#include "output.h"
 #include "player.h"
+#include "prompt.h"
 #include "religion.h"
 #include "spl-cast.h"
 #include "spl-book.h"
 #include "spl-damage.h"
 #include "spl-zap.h"
+#include "stringutil.h"
 #include "target.h"
 #include "terrain.h"
 #include "transform.h"
@@ -70,10 +73,7 @@ struct spell_desc
     bool         ms_utility;
 };
 
-static const struct spell_desc spelldata[] =
-{
-    #include "spl-data.h"
-};
+#include "spl-data.h"
 
 static int spell_list[NUM_SPELLS];
 
@@ -86,7 +86,7 @@ static const struct spell_desc *_seekspell(spell_type spellid);
 //
 
 // All this does is merely refresh the internal spell list {dlb}:
-void init_spell_descs(void)
+void init_spell_descs()
 {
     for (int i = 0; i < NUM_SPELLS; i++)
         spell_list[i] = -1;
@@ -151,26 +151,9 @@ spell_type spell_by_name(string name, bool partial_match)
         return SPELL_NO_SPELL;
     }
 
-    spell_type spellmatch = SPELL_NO_SPELL;
-    for (int i = 0; i < NUM_SPELLS; i++)
-    {
-        spell_type type = static_cast<spell_type>(i);
-        if (!is_valid_spell(type))
-            continue;
-
-        const char *sptitle = spell_title(type);
-        const string spell_name = lowercase_string(sptitle);
-
-        if (spell_name.find(name) != string::npos)
-        {
-            if (spell_name == name)
-                return type;
-
-            spellmatch = type;
-        }
-    }
-
-    return spellmatch;
+    const spell_type sp = find_earliest_match(name, SPELL_NO_SPELL, NUM_SPELLS,
+                                              is_valid_spell, spell_title);
+    return sp == NUM_SPELLS ? SPELL_NO_SPELL : sp;
 }
 
 spschool_flag_type school_by_name(string name)
@@ -285,8 +268,6 @@ bool add_spell_to_memory(spell_type spell)
                 you.spell_letter_table[letter_to_index(Options.auto_spell_letters[k].second[l])] == -1)
             {
                 j = letter_to_index(Options.auto_spell_letters[k].second[l]);
-                mprf("Spell assigned to '%c'.",
-                     Options.auto_spell_letters[k].second[l]);
                 break;
             }
         if (j != -1)
@@ -300,6 +281,7 @@ bool add_spell_to_memory(spell_type spell)
                 break;
         }
 
+    mprf("Spell assigned to '%c'.", index_to_letter(j));
     you.spell_letter_table[j] = i;
 
     you.spell_no++;
@@ -1095,6 +1077,7 @@ bool spell_is_useless(spell_type spell, bool transient)
             return true;
         }
 
+#if TAG_MAJOR_VERSION == 34
         if (you.species == SP_LAVA_ORC && !temperature_effect(LORC_STONESKIN))
         {
             switch (spell)
@@ -1109,6 +1092,7 @@ bool spell_is_useless(spell_type spell, bool transient)
                 break;
             }
         }
+#endif
     }
 
     switch (spell)
@@ -1120,7 +1104,7 @@ bool spell_is_useless(spell_type spell, bool transient)
             return true;
         break;
     case SPELL_SWIFTNESS:
-        if (transient && you.form == TRAN_TREE)
+        if (transient && you.is_stationary())
             return true;
         // looking at player_movement_speed, this should be correct ~DMB
         if (player_movement_speed() <= 6)
@@ -1165,10 +1149,12 @@ bool spell_is_useless(spell_type spell, bool transient)
         }
         break;
 
+#if TAG_MAJOR_VERSION == 34
     case SPELL_STONESKIN:
         if (you.species == SP_LAVA_ORC)
             return true;
         break;
+#endif
 
     case SPELL_LEDAS_LIQUEFACTION:
         if (!you.stand_on_solid_ground()
@@ -1189,16 +1175,25 @@ bool spell_is_useless(spell_type spell, bool transient)
     return false;
 }
 
-// This function takes a spell, and determines what color it should be
-// highlighted with. You shouldn't have to touch this unless you want
-// to add new highlighting options.
+/**
+ * Determines what color a spell should be highlighted with.
+ *
+ * @param spell           The type of spell to be colored.
+ * @param default_color   Color to be used if the spell is unremarkable.
+ * @param transient       If true, check if spell is temporarily useless.
+ * @param rod_spell       If the spell being evoked from a rod.
+ * @return                The color to highlight the spell.
+ */
 int spell_highlight_by_utility(spell_type spell, int default_color,
                                bool transient, bool rod_spell)
 {
     // If your god hates the spell, that
     // overrides all other concerns
-    if (god_hates_spell(spell, you.religion, rod_spell))
+    if (god_hates_spell(spell, you.religion, rod_spell)
+        || is_good_god(you.religion) && you.spellcasting_unholy())
+    {
         return COL_FORBIDDEN;
+    }
 
     if (_spell_is_empowered(spell) && !rod_spell)
         default_color = COL_EMPOWERED;
@@ -1242,6 +1237,9 @@ bool spell_no_hostile_in_range(spell_type spell, bool rod)
     case SPELL_HOLY_BREATH:
     {
         targetter_cloud tgt(&you, range);
+        // Accept monsters that are in clouds for the hostiles-in-range check
+        // (not for actual targetting).
+        tgt.avoid_clouds = false;
         for (radius_iterator ri(you.pos(), range, C_ROUND, LOS_NO_TRANS);
              ri; ++ri)
         {
@@ -1260,7 +1258,9 @@ bool spell_no_hostile_in_range(spell_type spell, bool rod)
                     && (!mons_class_flag(mons->type, M_NO_EXP_GAIN)
                         || (mons->type == MONS_BALLISTOMYCETE
                             && mons->number != 0)))
+                {
                     return false;
+                }
             }
         }
 
@@ -1274,8 +1274,11 @@ bool spell_no_hostile_in_range(spell_type spell, bool rod)
     if (testbits(get_spell_flags(spell), SPFLAG_HELPFUL))
         return false;
 
+    const bool neutral = testbits(get_spell_flags(spell), SPFLAG_NEUTRAL);
+
     bolt beam;
     beam.flavour = BEAM_VISUAL;
+    beam.origin_spell = spell;
 
     zap_type zap = spell_to_zap(spell);
     if (spell == SPELL_FIREBALL)
@@ -1286,7 +1289,7 @@ bool spell_no_hostile_in_range(spell_type spell, bool rod)
     if (zap != NUM_ZAPS)
     {
         beam.thrower = KILL_YOU_MISSILE;
-        zappy(zap, calc_spell_power(spell, true), beam);
+        zappy(zap, calc_spell_power(spell, true, false, true, rod), beam);
     }
     else if (spell == SPELL_MEPHITIC_CLOUD)
     {
@@ -1295,7 +1298,7 @@ bool spell_no_hostile_in_range(spell_type spell, bool rod)
         beam.damage = dice_def(1, 1); // so that foe_info is populated
         beam.hit = 20;
         beam.thrower = KILL_YOU;
-        beam.ench_power = calc_spell_power(spell, true);
+        beam.ench_power = calc_spell_power(spell, true, false, true, rod);
         beam.is_beam = false;
         beam.is_explosion = true;
     }
@@ -1323,7 +1326,8 @@ bool spell_no_hostile_in_range(spell_type spell, bool rod)
             tempbeam = beam;
             tempbeam.target = *ri;
             tempbeam.fire();
-            if (tempbeam.foe_info.count > 0)
+            if (tempbeam.foe_info.count > 0
+                || neutral && tempbeam.friend_info.count > 0)
             {
                 found = true;
                 break;
