@@ -10,12 +10,15 @@
 #include "branch.h"
 #include "cio.h"
 #include "command.h"
+#include "coordit.h"
 #include "ctest.h"
 #include "database.h"
 #include "dbg-maps.h"
+#include "dbg-scan.h"
 #include "defines.h"
 #include "dlua.h"
 #include "dungeon.h"
+#include "end.h"
 #include "env.h"
 #include "exclude.h"
 #include "files.h"
@@ -34,6 +37,7 @@
 #include "message.h"
 #include "misc.h"
 #include "mon-cast.h"
+#include "mon-death.h"
 #include "mon-util.h"
 #include "mutation.h"
 #include "newgame.h"
@@ -50,7 +54,7 @@
 #include "startup.h"
 #include "state.h"
 #include "status.h"
-#include "stuff.h"
+#include "stringutil.h"
 #include "terrain.h"
 #include "tileview.h"
 #include "view.h"
@@ -63,6 +67,8 @@
  #include "tilereg-crt.h"
 #endif
 
+static void _cio_init();
+
 // Initialise a whole lot of stuff...
 static void _initialize()
 {
@@ -116,8 +122,8 @@ static void _initialize()
     // Draw the splash screen before the database gets initialised as that
     // may take awhile and it's better if the player can look at a pretty
     // screen while this happens.
-    if (!crawl_state.map_stat_gen && !crawl_state.test
-        && crawl_state.title_screen)
+    if (!crawl_state.map_stat_gen && !crawl_state.obj_stat_gen
+        && !crawl_state.test && crawl_state.title_screen)
     {
         tiles.draw_title();
         tiles.update_title_msg("Loading databases...");
@@ -158,7 +164,13 @@ static void _initialize()
     if (crawl_state.map_stat_gen)
     {
         release_cli_signals();
-        generate_map_stats();
+        mapstat_generate_stats();
+        end(0, false);
+    }
+    else if (crawl_state.obj_stat_gen)
+    {
+        release_cli_signals();
+        objstat_generate_stats();
         end(0, false);
     }
 #endif
@@ -166,7 +178,7 @@ static void _initialize()
     if (!crawl_state.test_list)
     {
         if (!crawl_state.io_inited)
-            cio_init();
+            _cio_init();
         clrscr();
     }
 
@@ -192,6 +204,42 @@ static void _initialize()
     }
 }
 
+/** KILL_RESETs all monsters in LOS.
+*
+*  Doesn't affect monsters behind glass, only those that would
+*  immediately have line-of-fire.
+*
+*  @param items_also whether to zap items as well as monsters.
+*/
+static void _zap_los_monsters(bool items_also)
+{
+    for (radius_iterator ri(you.pos(), LOS_SOLID); ri; ++ri)
+    {
+        if (items_also)
+        {
+            int item = igrd(*ri);
+
+            if (item != NON_ITEM && mitm[item].defined())
+                destroy_item(item);
+        }
+
+        // If we ever allow starting with a friendly monster,
+        // we'll have to check here.
+        monster* mon = monster_at(*ri);
+        if (mon == NULL || mons_class_flag(mon->type, M_NO_EXP_GAIN))
+            continue;
+
+        dprf("Dismissing %s",
+             mon->name(DESC_PLAIN, true).c_str());
+
+        // Do a hard reset so the monster's items will be discarded.
+        mon->flags |= MF_HARD_RESET;
+        // Do a silent, wizard-mode monster_die() just to be extra sure the
+        // player sees nothing.
+        monster_die(mon, KILL_DISMISSED, NON_MONSTER, true, true);
+    }
+}
+
 static void _post_init(bool newc)
 {
     ASSERT(strwidth(you.your_name) <= kNameLen);
@@ -248,7 +296,6 @@ static void _post_init(bool newc)
 #endif
 
     init_properties();
-    burden_change();
 
     you.redraw_stats.init(true);
     you.redraw_hit_points   = true;
@@ -256,8 +303,10 @@ static void _post_init(bool newc)
     you.redraw_armour_class = true;
     you.redraw_evasion      = true;
     you.redraw_experience   = true;
+#if TAG_MAJOR_VERSION == 34
     if (you.species == SP_LAVA_ORC)
         you.redraw_temperature = true;
+#endif
     you.redraw_quiver       = true;
     you.wield_change        = true;
 
@@ -297,14 +346,12 @@ static void _post_init(bool newc)
 
     if (newc) // start a new game
     {
-        you.friendly_pickup = Options.default_friendly_pickup;
-
         // Mark items in inventory as of unknown origin.
         origin_set_inventory(origin_set_unknown);
 
         // For a new game, wipe out monsters in LOS, and
         // for new hints mode games also the items.
-        zap_los_monsters(Hints.hints_events[HINT_SEEN_FIRST_OBJECT]);
+        _zap_los_monsters(Hints.hints_events[HINT_SEEN_FIRST_OBJECT]);
 
         if (crawl_state.game_is_zotdef())
             fully_map_level();
@@ -487,18 +534,27 @@ static void _construct_game_modes_menu(MenuScroller* menu)
     tmp->set_visible(true);
 }
 
+static void _add_newgame_button(MenuScroller* menu, int num_chars)
+{
+    // XXX: duplicates a lot of _construct_save_games_menu code. not ideal.
+#ifdef USE_TILE_LOCAL
+    SaveMenuItem* tmp = new SaveMenuItem();
+#else
+    TextItem* tmp = new TextItem();
+#endif
+    tmp->set_text("New Game");
+    tmp->set_bounds(coord_def(1, 1), coord_def(1, 2));
+    tmp->set_fg_colour(WHITE);
+    tmp->set_highlight_colour(WHITE);
+    // unique id
+    tmp->set_id(NUM_GAME_TYPE + num_chars);
+    menu->attach_item(tmp);
+    tmp->set_visible(true);
+}
+
 static void _construct_save_games_menu(MenuScroller* menu,
                                        const vector<player_save_info>& chars)
 {
-    if (chars.empty())
-    {
-        // no saves
-        return;
-    }
-
-    string text;
-
-    vector<player_save_info>::iterator it;
     for (unsigned int i = 0; i < chars.size(); ++i)
     {
 #ifdef USE_TILE_LOCAL
@@ -515,10 +571,12 @@ static void _construct_save_games_menu(MenuScroller* menu,
 #ifdef USE_TILE_LOCAL
         tmp->set_doll(chars.at(i).doll);
 #endif
-        //tmp->set_description_text("...");
         menu->attach_item(tmp);
         tmp->set_visible(true);
     }
+
+    if (!chars.empty())
+        _add_newgame_button(menu, chars.size());
 }
 
 // Should probably use some find invocation instead.
@@ -562,12 +620,13 @@ again:
     const int max_col    = get_number_of_cols();
 #endif
     const int max_line   = get_number_of_lines();
-    const int help_start = min(GAME_MODES_START_Y + num_to_lines(num_saves + num_modes) + 2,
+    int save_lines = num_saves + (num_saves ? 1 : 0); // add 1 for New Game
+    const int help_start = min(GAME_MODES_START_Y + num_to_lines(save_lines + num_modes) + 2,
                                max_line - NUM_MISC_LINES + 1);
     const int help_end   = help_start + NUM_HELP_LINES + 1;
 
     const int game_mode_bottom = GAME_MODES_START_Y + num_to_lines(num_modes);
-    const int game_save_top = help_start - 2 - num_to_lines(min(2, num_saves));
+    const int game_save_top = help_start - 2 - num_to_lines(min(2, save_lines));
     const int save_games_start_y = min<int>(game_mode_bottom, game_save_top);
 
     clrscr();
@@ -803,7 +862,10 @@ again:
 
                 default:
                     int save_number = type - NUM_GAME_TYPE;
-                    input_string = chars.at(save_number).name;
+                    if (save_number < num_saves)
+                        input_string = chars.at(save_number).name;
+                    else // new game
+                        input_string = "";
                     full_name = true;
                     break;
                 }
@@ -858,10 +920,19 @@ again:
         default:
             // It was a savegame instead
             const int save_number = id - NUM_GAME_TYPE;
-            // Save the savegame character name
-            ng_choice->name = chars.at(save_number).name;
-            ng_choice->type = chars.at(save_number).saved_game_type;
-            ng_choice->filename = chars.at(save_number).filename;
+            if (save_number < num_saves) // actual save
+            {
+                // Save the savegame character name
+                ng_choice->name = chars.at(save_number).name;
+                ng_choice->type = chars.at(save_number).saved_game_type;
+                ng_choice->filename = chars.at(save_number).filename;
+            }
+            else // "new game"
+            {
+                ng_choice->name = "";
+                ng_choice->type = GAME_TYPE_NORMAL;
+                ng_choice->filename = ""; // ?
+            }
             return;
         }
     }
@@ -978,3 +1049,14 @@ bool startup_step()
 
     return newchar;
 }
+
+
+
+static void _cio_init()
+{
+    crawl_state.io_inited = true;
+    console_startup();
+    set_cursor_enabled(false);
+    crawl_view.init_geometry();
+    textbackground(0);
+}
