@@ -43,6 +43,7 @@ game_state::game_state()
       repeat_cmd(CMD_NO_CMD),cmd_repeat_started_unsafe(false),
       lua_calls_no_turn(0), stat_gain_prompt(false),
       level_annotation_shown(false), viewport_monster_hp(false),
+      viewport_weapons(false),
 #ifndef USE_TILE_LOCAL
       mlist_targeting(false),
 #else
@@ -258,14 +259,7 @@ bool interrupt_cmd_repeat(activity_interrupt_type ai,
         if (ai == AI_FULL_MP)
             crawl_state.cancel_cmd_repeat("Magic restored.");
         else if (ai == AI_FULL_HP)
-        {
-#if TAG_MAJOR_VERSION == 34
-            string health = (you.species == SP_DJINNI ? "EP" : "HP");
-            crawl_state.cancel_cmd_repeat(health + " restored");
-#else
             crawl_state.cancel_cmd_repeat("HP restored");
-#endif
-        }
         else
             crawl_state.cancel_cmd_repeat("Command repetition interrupted.");
 
@@ -484,8 +478,10 @@ void game_state::dump()
                   "arena_suspended: %d\n",
             seen_hups, map_stat_gen, type, arena_suspended);
     if (last_winch)
+    {
         fprintf(stderr, "Last resize was %" PRId64" seconds ago.\n",
                 (int64_t)(time(0) - last_winch));
+    }
 
     fprintf(stderr, "\n");
 
@@ -529,9 +525,11 @@ void game_state::dump()
     {
         fprintf(stderr, "Other gods acting:\n");
         for (unsigned int i = 0; i < god_act_stack.size(); i++)
+        {
             fprintf(stderr, "God %s with depth %d\n",
                     god_name(god_act_stack[i].which_god).c_str(),
                     god_act_stack[i].depth);
+        }
         fprintf(stderr, "\n\n");
     }
 
@@ -546,8 +544,10 @@ void game_state::dump()
     {
         fprintf(stderr, "Others monsters acting:\n");
         for (unsigned int i = 0; i < mon_act_stack.size(); i++)
+        {
             fprintf(stderr, "    %s\n",
                     debug_mon_str(mon_act_stack[i]).c_str());
+        }
     }
 }
 
