@@ -10,8 +10,8 @@
 
 #include "dlua.h"
 #include "externs.h"
-#include "libutil.h"
 #include "monster.h"
+#include "stringutil.h"
 #include "tags.h"
 #include "travel.h"
 
