@@ -107,15 +107,11 @@ bool targetter_beam::set_aim(coord_def a)
         for (vector<coord_def>::const_iterator i = path_taken.begin();
              i != path_taken.end(); ++i)
         {
-            if (cell_is_solid(*i)
-                && tempbeam.affects_wall(grd(*i)) != MB_TRUE)
+            if (cell_is_solid(*i) && tempbeam.affects_wall(grd(*i)) != MB_TRUE)
                 break;
             tempbeam2.target = *i;
-            if (anyone_there(*i)
-                && !tempbeam.ignores_monster(monster_at(*i)))
-            {
+            if (anyone_there(*i) && !tempbeam.ignores_monster(monster_at(*i)))
                 break;
-            }
         }
         tempbeam2.use_target_as_pos = true;
         exp_map_min.init(INT_MAX);
@@ -158,7 +154,9 @@ aff_type targetter_beam::is_affected(coord_def loc)
         if (cell_is_solid(*i)
             && beam.affects_wall(grd(*i)) != MB_TRUE
             && max_expl_rad > 0)
+        {
             break;
+        }
 
         c = *i;
         if (c == loc)
@@ -196,8 +194,10 @@ aff_type targetter_beam::is_affected(coord_def loc)
         {
             coord_def centre(9,9);
             if (exp_map_min(loc - c + centre) < INT_MAX)
+            {
                 return (!cell_is_solid(loc) || aff_wall == MB_TRUE)
                        ? AFF_YES : AFF_MAYBE;
+            }
             if (exp_map_max(loc - c + centre) < INT_MAX)
                 return AFF_MAYBE;
         }
@@ -237,7 +237,9 @@ bool targetter_imb::set_aim(coord_def a)
         if (!(anyone_there(c)
               && !beam.ignores_monster((monster_at(c))))
             && c != end)
+        {
             continue;
+        }
 
         vector<coord_def> *which_splash = (first) ? &splash : &splash2;
 
@@ -507,7 +509,7 @@ aff_type targetter_cleave::is_affected(coord_def loc)
 
 targetter_cloud::targetter_cloud(const actor* act, int range,
                                  int count_min, int count_max) :
-    cnt_min(count_min), cnt_max(count_max)
+    cnt_min(count_min), cnt_max(count_max), avoid_clouds(true)
 {
     ASSERT(cnt_min > 0);
     ASSERT(cnt_max > 0);
@@ -517,11 +519,11 @@ targetter_cloud::targetter_cloud(const actor* act, int range,
     range2 = dist_range(range);
 }
 
-static bool _cloudable(coord_def loc)
+static bool _cloudable(coord_def loc, bool avoid_clouds)
 {
     return in_bounds(loc)
            && !cell_is_solid(loc)
-           && env.cgrid(loc) == EMPTY_CLOUD;
+           && (!avoid_clouds || env.cgrid(loc) == EMPTY_CLOUD);
 }
 
 bool targetter_cloud::valid_aim(coord_def a)
@@ -542,9 +544,9 @@ bool targetter_cloud::valid_aim(coord_def a)
         return notify_fail(_wallmsg(a));
     if (agent)
     {
-        if (env.cgrid(a) != EMPTY_CLOUD)
+        if (env.cgrid(a) != EMPTY_CLOUD && avoid_clouds)
             return notify_fail("There's already a cloud there.");
-        ASSERT(_cloudable(a));
+        ASSERT(_cloudable(a, avoid_clouds));
     }
     return true;
 }
@@ -570,7 +572,7 @@ bool targetter_cloud::set_aim(coord_def a)
         {
             coord_def c = queue[d1][i];
             for (adjacent_iterator ai(c); ai; ++ai)
-                if (_cloudable(*ai) && !seen.count(*ai))
+                if (_cloudable(*ai, avoid_clouds) && !seen.count(*ai))
                 {
                     unsigned int d2 = d1 + ((*ai - c).abs() == 1 ? 5 : 7);
                     if (d2 >= queue.size())
@@ -1192,6 +1194,11 @@ bool targetter_cone::valid_aim(coord_def a)
     return true;
 }
 
+static bool left_of_eq(coord_def a, coord_def b)
+{
+    return a.x * b.y >= a.y * b.x;
+}
+
 // Ripped off from targetter_thunderbolt::set_aim.
 bool targetter_cone::set_aim(coord_def a)
 {
@@ -1224,7 +1231,7 @@ bool targetter_cone::set_aim(coord_def a)
             if (sqr(x) + sqr(y) > range2)
                 continue;
             coord_def q(x, y);
-            if (left_of(a1, q) && left_of(q, a2))
+            if (left_of_eq(a1, q) && left_of_eq(q, a2))
             {
                 (p = q) += origin;
                 if (zapped[p] <= 0
