@@ -29,8 +29,7 @@ actor* actor_at(const coord_def& c);
 
 int count_neighbours_with_func(const coord_def& c, bool (*checker)(dungeon_feature_type));
 
-bool fall_into_a_pool(const coord_def& entry, bool allow_shift,
-                       dungeon_feature_type terrain);
+void fall_into_a_pool(dungeon_feature_type terrain);
 
 bool cell_is_solid(const coord_def &c);
 
@@ -42,6 +41,7 @@ bool feat_has_solid_floor(dungeon_feature_type feat);
 bool feat_has_dry_floor(dungeon_feature_type feat);
 bool feat_is_door(dungeon_feature_type feat);
 bool feat_is_closed_door(dungeon_feature_type feat);
+bool feat_is_sealed(dungeon_feature_type feat);
 bool feat_is_statue_or_idol(dungeon_feature_type feat);
 bool feat_is_rock(dungeon_feature_type feat);
 bool feat_is_permarock(dungeon_feature_type feat);
@@ -91,7 +91,8 @@ void dungeon_terrain_changed(const coord_def &pos,
                              dungeon_feature_type feat = DNGN_UNSEEN,
                              bool affect_player = true,
                              bool preserve_features = false,
-                             bool preserve_items = false);
+                             bool preserve_items = false,
+                             int colour = BLACK);
 
 // Moves everything on the level at src to dst.
 void dgn_move_entities_at(coord_def src,
@@ -119,7 +120,7 @@ const char* feat_type_name(dungeon_feature_type feat);
 dungeon_feature_type dungeon_feature_by_name(const string &name);
 vector<string> dungeon_feature_matches(const string &name);
 const char *dungeon_feature_name(dungeon_feature_type rfeat);
-void nuke_wall(const coord_def& p);
+void destroy_wall(const coord_def& p);
 void set_terrain_changed(const coord_def c);
 bool cell_is_clingable(const coord_def pos);
 bool cell_can_cling_to(const coord_def& from, const coord_def to);
