@@ -5,7 +5,7 @@
 #include "tilereg-cmd.h"
 #include "process_desc.h"
 
-#include "abl-show.h"
+#include "ability.h"
 #include "cio.h"
 #include "command.h"
 #include "process_desc.h"
@@ -185,14 +185,14 @@ static bool _command_not_applicable(const command_type cmd, bool safe)
     case CMD_REST:
     case CMD_EXPLORE:
     case CMD_INTERLEVEL_TRAVEL:
-        return (!safe);
+        return !safe;
     case CMD_DISPLAY_RELIGION:
         return you_worship(GOD_NO_GOD);
     case CMD_PRAY:
-        return (you_worship(GOD_NO_GOD)
-                && !feat_is_altar(grd(you.pos())));
+        return you_worship(GOD_NO_GOD)
+               && !feat_is_altar(grd(you.pos()));
     case CMD_USE_ABILITY:
-        return (your_talents(false).empty());
+        return your_talents(false).empty();
     case CMD_BUTCHER:
         // this logic is enormously simplistic compared to food.cc
         for (stack_iterator si(you.pos(), true); si; ++si)
