@@ -136,14 +136,15 @@ bool GridRegion::place_cursor(MouseEvent &event, unsigned int &item_idx)
     return true;
 }
 
-void GridRegion::add_quad_char(char c, int x, int y,
-                               int ofs_x, int ofs_y, bool outline)
+int GridRegion::add_quad_char(char c, int x, int y,
+                              int ofs_x, int ofs_y, bool outline)
 {
     int num = c - '0';
     ASSERT_RANGE(num, 0, 9 + 1);
     tileidx_t idx = (outline ? TILEI_NUM0_OUTLINE : TILEI_NUM0) + num;
 
     m_buf.add_icons_tile(idx, x, y, ofs_x, ofs_y);
+    return tile_icons_info(idx).width;
 }
 
 void GridRegion::render()
@@ -168,35 +169,34 @@ void GridRegion::render()
     draw_tag();
 }
 
-void GridRegion::draw_number(int x, int y, int num, bool outline)
+void GridRegion::draw_number(int x, int y, int num, bool outln)
 {
     // If you have that many, who cares.
-    if (num > 999)
-        num = 999;
+    if (num > 9999)
+        num = 9999;
 
-    const int offset_amount = TILE_X/4;
-    int offset_x = 3;
+    int offset_x = 2;
     int offset_y = 1;
 
     int help = num;
+    int c1000 = help/1000;
+    help -= c1000*1000;
+
+    if (c1000)
+        offset_x += add_quad_char('0' + c1000, x, y, offset_x, offset_y, outln);
+
     int c100 = help/100;
     help -= c100*100;
 
-    if (c100)
-    {
-        add_quad_char('0' + c100, x, y, offset_x, offset_y, outline);
-        offset_x += offset_amount;
-    }
+    if (c100 || c1000)
+        offset_x += add_quad_char('0' + c100, x, y, offset_x, offset_y, outln);
 
     int c10 = help/10;
-    if (c10 || c100)
-    {
-        add_quad_char('0' + c10, x, y, offset_x, offset_y, outline);
-        offset_x += offset_amount;
-    }
+    if (c10 || c100 || c1000)
+        offset_x += add_quad_char('0' + c10, x, y, offset_x, offset_y, outln);
 
     int c1 = help % 10;
-    add_quad_char('0' + c1, x, y, offset_x, offset_y, outline);
+    add_quad_char('0' + c1, x, y, offset_x, offset_y, outln);
 }
 
 #endif
