@@ -7,11 +7,9 @@
 
 #include "menu.h"
 #include "macro.h"
-#include "options.h"
 #include "tilebuf.h"
 #include "tilefont.h"
 #include "cio.h"
-#include "process_desc.h"
 
 PopupRegion::PopupRegion(ImageManager *im, FontWrapper *entry) :
     MenuRegion(im, entry),
@@ -56,7 +54,6 @@ void PopupRegion::place_entries()
     _place_entries(ex / 4, ey / 4, ex / 2);
 }
 
-
 void PopupRegion::run()
 {
     m_retval = getchm(KMC_CONFIRM);
