@@ -20,7 +20,7 @@
 #include "player.h"
 #include "religion.h"
 #include "state.h"
-#include "stuff.h"
+
 #include "skills2.h"
 #include "tiledef-dngn.h"
 #include "tiledef-gui.h"
@@ -199,7 +199,7 @@ void TilesFramework::finish_message()
 
         for (unsigned int i = 0; i < m_dest_addrs.size(); ++i)
         {
-            int retries = 10;
+            int retries = 30;
             ssize_t sent = 0;
             while (sent < fragment_size)
             {
@@ -732,12 +732,15 @@ void TilesFramework::_send_player(bool force_full)
     _update_int(force_full, c.poison_survival, max(0, poison_survival()),
                 "poison_survival");
 
+#if TAG_MAJOR_VERSION == 34
     if (you.species == SP_LAVA_ORC)
         _update_int(force_full, c.heat, temperature(), "heat");
+#endif
 
     _update_int(force_full, c.armour_class, you.armour_class(), "ac");
     _update_int(force_full, c.evasion, player_evasion(), "ev");
-    _update_int(force_full, c.shield_class, player_shield_class(), "sh");
+    _update_int(force_full, c.shield_class, player_displayed_shield_class(),
+                "sh");
 
     _update_int(force_full, c.strength, (int8_t) you.strength(false), "str");
     _update_int(force_full, c.strength_max, (int8_t) you.max_strength(), "str_max");
@@ -805,7 +808,7 @@ void TilesFramework::_send_player(bool force_full)
             if (!c.status[i].short_text.empty())
                 json_write_string("text", c.status[i].short_text);
             if (c.status[i].light_colour)
-                json_write_int("col", c.status[i].light_colour);
+                json_write_int("col", macro_colour(c.status[i].light_colour));
             json_close_object(true);
         }
         json_close_array();
@@ -879,7 +882,7 @@ void TilesFramework::_send_item(item_info& current, const item_info& next,
         const int current_prefcol = menu_colour(current.name(DESC_INVENTORY), current_prefix);
         const int prefcol = menu_colour(next.name(DESC_INVENTORY), prefix);
         if (force_full || current_prefcol != prefcol)
-            json_write_int("col", prefcol);
+            json_write_int("col", macro_colour(prefcol));
 
         tileidx_t tile = tileidx_item(next);
         if (force_full || tileidx_item(current) != tile)
@@ -1078,7 +1081,7 @@ void TilesFramework::_send_cell(const coord_def &gc,
          || current_sc.glyph == ' ') && glyph != ' ')
     {
         int col = next_sc.colour;
-        col = (_get_brand(col) << 4) | (col & 0xF);
+        col = (_get_brand(col) << 4) | macro_colour(col & 0xF);
         json_write_int("col", col);
     }
 
@@ -1157,8 +1160,13 @@ void TilesFramework::_send_cell(const coord_def &gc,
         if (next_pc.travel_trail != current_pc.travel_trail)
             json_write_int("travel_trail", next_pc.travel_trail);
 
+#if TAG_MAJOR_VERSION == 34
         if (next_pc.heat_aura != current_pc.heat_aura)
             json_write_int("heat_aura", next_pc.heat_aura);
+#endif
+
+        if (next_pc.gold_aura != current_pc.gold_aura)
+            json_write_int("gold_aura", next_pc.gold_aura);
 
         if (_needs_flavour(next_pc) &&
             (next_pc.flv.floor != current_pc.flv.floor
