@@ -47,7 +47,7 @@ struct player_info
 
     uint8_t form;
 
-    int hp, hp_max, real_hp_max;
+    int hp, hp_max, real_hp_max, poison_survival;
     int mp, mp_max;
     int contam;
     int heat;
@@ -65,6 +65,7 @@ struct player_info
     int gold;
     int zot_points;
     int elapsed_time;
+    int num_turns;
     int lives, deaths;
 
     string place;
@@ -131,10 +132,14 @@ public:
     void pop_menu();
     void close_all_menus();
 
+    void send_exit_reason(const string& type, const string& message = "");
+    void send_dump_info(const string& type, const string& filename);
+
+    string get_message();
     void write_message(PRINTF(1, ));
     void finish_message();
     void send_message(PRINTF(1, ));
-    void flush_messages(bool joining_only=false);
+    void flush_messages();
 
     bool has_receivers() { return !m_dest_addrs.empty(); }
     bool is_controlled_from_web() { return m_controlled_from_web; }
@@ -276,9 +281,13 @@ protected:
     player_info m_current_player_info;
 
     void _send_version();
+    void _send_options();
 
     void _send_everything();
 
+    bool m_mcache_ref_done;
+    void _mcache_ref(bool inc);
+
     void _send_cursor(cursor_type type);
     void _send_map(bool force_full = false);
     void _send_cell(const coord_def &gc,
