@@ -41,7 +41,7 @@ enum xom_event_type
     XOM_GOOD_LIGHTNING,
     XOM_GOOD_SCENERY,
     XOM_GOOD_SNAKES,
-    XOM_GOOD_INNER_FLAME,
+    XOM_GOOD_DESTRUCTION,
     XOM_GOOD_ENCHANT_MONSTER,
     XOM_LAST_GOOD_ACT = XOM_GOOD_ENCHANT_MONSTER,
 
@@ -94,6 +94,7 @@ void xom_check_lost_item(const item_def& item);
 void xom_check_destroyed_item(const item_def& item, int cause = -1);
 void xom_death_message(const kill_method_type killed_by);
 bool xom_saves_your_life(const kill_method_type death_type, const char *aux);
+void xom_new_level_noise_or_stealth();
 
 #ifdef WIZARD
 void debug_xom_effects();
